@@ -2,23 +2,8 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
- */
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
+*/
 
 /* actions.c -- A few functions for the plugins system */
 
@@ -98,65 +83,75 @@ get_plugin_path(char *action, int *status)
 }
 
 static void
-export_status_values(void)
+export_status_values(const char *fifo_path)
 {
+	setenv("CLIFM_BUS", fifo_path, 1);
+
 	if (cur_cscheme && *cur_cscheme)
 		setenv("CLIFM_COLOR_SCHEME", cur_cscheme, 1);
-	if (conf.colorize != 1)
-		setenv("CLIFM_COLORLESS", "1", 1);
-	setenv("CLIFM_CUR_WS", xitoa(cur_ws + 1), 1);
-	setenv("CLIFM_DIRS_FIRST", conf.list_dirs_first == 1 ? "1" : "0", 1);
-	setenv("CLIFM_FILES_COUNTER", conf.files_counter == 1 ? "1" : "0", 1);
+	if (conf.colorize != 1) setenv("CLIFM_COLORLESS", "1", 1);
+	if (conf.list_dirs_first == 1) setenv("CLIFM_DIRS_FIRST", "1", 1);
+	if (conf.file_counter == 1) setenv("CLIFM_FILE_COUNTER", "1", 1);
 	if (filter.str && *filter.str) {
-		setenv("CLIFM_FILES_FILTER", filter.str, 1);
-		setenv("CLIFM_FILTER_REVERSE", filter.rev == 1 ? "1" : "0", 1);
+		setenv("CLIFM_FILE_FILTER", filter.str, 1);
+		if (filter.rev == 1) setenv("CLIFM_FILTER_REVERSE", "1", 1);
 	}
-	setenv("CLIFM_FOLLOW_LINKS", conf.follow_symlinks == 1 ? "1" : "0", 1);
-	setenv("CLIFM_LIGHT_MODE", conf.light_mode == 1 ? "1" : "0", 1);
-	setenv("CLIFM_LONG_VIEW", conf.long_view == 1 ? "1" : "0", 1);
+	if (conf.follow_symlinks == 1) setenv("CLIFM_FOLLOW_LINKS", "1", 1);
+	if (conf.light_mode == 1) setenv("CLIFM_LIGHT_MODE", "1", 1);
+	if (conf.long_view == 1) setenv("CLIFM_LONG_VIEW", "1", 1);
+	if (conf.only_dirs == 1) setenv("CLIFM_ONLY_DIRS", "1", 1);
+	if (conf.trunc_names == 1) setenv("CLIFM_TRUNCATE_NAMES", "1", 1);
 	if (conf.max_files >= 0)
 		setenv("CLIFM_MAX_FILES", xitoa(conf.max_files), 1);
-	setenv("CLIFM_ONLY_DIRS", conf.only_dirs == 1 ? "1" : "0", 1);
 	if (plugins_helper_file && *plugins_helper_file)
 		setenv("CLIFM_PLUGINS_HELPER", plugins_helper_file, 1);
-	setenv("CLIFM_PROFILE", alt_profile ? alt_profile : "default", 1);
 	if (sel_file && *sel_file)
 		setenv("CLIFM_SELFILE", sel_file, 1);
 	if (sel_n > 0)
 		setenv("CLIFM_SEL_FILES", xitoa((long long)sel_n), 1);
-	char buf[MAX_INT_STR + 1];
-	snprintf(buf, sizeof(buf), "%d", conf.show_hidden);
-	setenv("CLIFM_SHOW_HIDDEN", buf, 1);
-	setenv("CLIFM_SORT_REVERSE", conf.sort_reverse == 1 ? "1" : "0", 1);
-	setenv("CLIFM_SORT_STYLE", num_to_sort_name(conf.sort, 0), 1);
+	if (conf.show_hidden > 0)
+		setenv("CLIFM_SHOW_HIDDEN", xitoa(conf.show_hidden), 1);
 	if (trash_n > 0)
 		setenv("CLIFM_TRASH_FILES", xitoa((long long)trash_n), 1);
-	setenv("CLIFM_TRUNCATE_NAMES", conf.trunc_names == 1 ? "1" : "0", 1);
+	if (conf.sort_reverse == 1) setenv("CLIFM_SORT_REVERSE", "1", 1);
+
+	setenv("CLIFM_SORT_STYLE", num_to_sort_name(conf.sort, 0), 1);
+	setenv("CLIFM_CUR_WS", xitoa(cur_ws + 1), 1);
+	setenv("CLIFM_PROFILE", alt_profile ? alt_profile : "default", 1);
 }
 
 static void
-unset_export_values(void) {
-	unsetenv("CLIFM_COLOR_SCHEME");
-	unsetenv("CLIFM_COLORLESS");
-	unsetenv("CLIFM_CUR_WS");
-	unsetenv("CLIFM_DIRS_FIRST");
-	unsetenv("CLIFM_FILES_COUNTER");
-	unsetenv("CLIFM_FILES_FILTER");
-	unsetenv("CLIFM_FILTER_REVERSE");
-	unsetenv("CLIFM_FOLLOW_LINKS");
-	unsetenv("CLIFM_LIGHT_MODE");
-	unsetenv("CLIFM_LONG_VIEW");
-	unsetenv("CLIFM_MAX_FILES");
-	unsetenv("CLIFM_ONLY_DIRS");
-	unsetenv("CLIFM_PLUGINS_HELPER");
-	unsetenv("CLIFM_PROFILE");
-	unsetenv("CLIFM_SEL_FILES");
-	unsetenv("CLIFM_SELFILE");
-	unsetenv("CLIFM_SHOW_HIDDEN");
-	unsetenv("CLIFM_SORT_REVERSE");
-	unsetenv("CLIFM_SORT_STYLE");
-	unsetenv("CLIFM_TRASH_FILES");
-	unsetenv("CLIFM_TRUNCATE_NAMES");
+run_action_output_cmd(char *cmd, int *exit_status)
+{
+	if (xargs.secure_cmds == 1
+	&& sanitize_cmd(cmd, SNT_GRAL) != FUNC_SUCCESS)
+		return;
+
+	const size_t old_args = args_n;
+	args_n = 0;
+
+	char **input = parse_input_str(cmd);
+	if (!input) {
+		args_n = old_args;
+		return;
+	}
+
+	char **alias_cmd = check_for_alias(input);
+	if (alias_cmd) {
+		*exit_status = exec_cmd_tm(alias_cmd);
+		for (size_t i = 0; alias_cmd[i]; i++)
+			free(alias_cmd[i]);
+		free(alias_cmd);
+	} else {
+		if (!(flags & FAILED_ALIAS))
+			*exit_status = exec_cmd_tm(input);
+		flags &= ~FAILED_ALIAS;
+		for (size_t i = 0; i <= args_n; i++)
+			free(input[i]);
+		free(input);
+	}
+
+	args_n = old_args;
 }
 
 int
@@ -188,8 +183,7 @@ run_action(char *action, char **args)
 	free(cmd);
 
 	/* 1.b Escape non-escaped filenames */
-	size_t i;
-	for (i = 1; args[i]; i++) {
+	for (size_t i = 1; args[i]; i++) {
 		struct stat a;
 		/* If the filename is already escaped, lstat(2) will fail, so that
 		 * it won't be reescaped. */
@@ -221,9 +215,6 @@ run_action(char *action, char **args)
 		return errno;
 	}
 
-	export_status_values();
-	setenv("CLIFM_BUS", fifo_path, 1);
-
 	if (xargs.cwd_in_title == 1)
 		set_term_title(action);
 
@@ -239,6 +230,8 @@ run_action(char *action, char **args)
 	}
 
 	if (pid == 0) {
+		export_status_values(fifo_path);
+
 		/* Child: write-only end of the pipe */
 		const int wfd = open(fifo_path, O_WRONLY | O_CLOEXEC);
 		if (wfd == -1)
@@ -296,36 +289,10 @@ run_action(char *action, char **args)
 
 	struct stat attr;
 	if (lstat(buf, &attr) != -1) { /* If a valid file, open it */
-		char *o_cmd[] = {"o", buf, NULL};
-		exit_status = open_function(o_cmd);
-
+		char *open_cmd[] = {"o", buf, NULL};
+		exit_status = open_function(open_cmd);
 	} else { /* If not a file, take it as a command */
-		if (xargs.secure_cmds == 1
-		&& sanitize_cmd(buf, SNT_GRAL) != FUNC_SUCCESS)
-			goto END;
-
-		size_t old_args = args_n;
-		args_n = 0;
-
-		char **_cmd = parse_input_str(buf);
-		if (_cmd) {
-			char **alias_cmd = check_for_alias(_cmd);
-			if (alias_cmd) {
-				exit_status = exec_cmd_tm(alias_cmd);
-				for (i = 0; alias_cmd[i]; i++)
-					free(alias_cmd[i]);
-				free(alias_cmd);
-			} else {
-				if (!(flags & FAILED_ALIAS))
-					exit_status = exec_cmd_tm(_cmd);
-				flags &= ~FAILED_ALIAS;
-				for (i = 0; i <= args_n; i++)
-					free(_cmd[i]);
-				free(_cmd);
-			}
-		}
-
-		args_n = old_args;
+		run_action_output_cmd(buf, &exit_status);
 	}
 
 END:
@@ -334,8 +301,6 @@ END:
 	if (xargs.cwd_in_title == 1)
 		set_term_title(workspaces[cur_ws].path);
 
-	unsetenv("CLIFM_BUS");
-	unset_export_values();
 	return exit_status;
 }
 
@@ -380,16 +345,14 @@ edit_actions(char *app)
 
 	/* Reload PATH commands as well to add new action(s) */
 	if (bin_commands) {
-		size_t i;
-		for (i = 0; bin_commands[i]; i++)
+		for (size_t i = 0; bin_commands[i]; i++)
 			free(bin_commands[i]);
 		free(bin_commands);
 		bin_commands = (char **)NULL;
 	}
 
 	if (paths) {
-		size_t i;
-		for (i = 0; i < path_n; i++)
+		for (size_t i = 0; i < path_n; i++)
 			free(paths[i].path);
 		free(paths);
 	}
@@ -404,10 +367,9 @@ edit_actions(char *app)
 static size_t
 get_longest_action_name(void)
 {
-	int i = (int)actions_n;
 	size_t l = 0;
-	while (--i >= 0) {
-		size_t len = strlen(usr_actions[i].name);
+	for (size_t i = actions_n; i-- > 0;) {
+		const size_t len = strlen(usr_actions[i].name);
 		if (len > l)
 			l = len;
 	}
@@ -423,8 +385,8 @@ actions_function(char **args)
 			/* Just list available actions */
 			puts(_("To run a plugin just enter its action name\n"
 				"Example: enter '//' to run the rgfind plugin"));
-			size_t i, longest_name_len = get_longest_action_name();
-			for (i = 0; i < actions_n; i++) {
+			size_t longest_name_len = get_longest_action_name();
+			for (size_t i = 0; i < actions_n; i++) {
 				printf("%-*s %s%s%s %s\n", (int)longest_name_len,
 					usr_actions[i].name, mi_c, SET_MSG_PTR,
 					df_c, usr_actions[i].value);
