@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* archives.c -- archiving functions */
@@ -738,8 +723,7 @@ compress_files(char **args)
 static int
 check_not_compressed(char **args)
 {
-	size_t i;
-	for (i = 1; args[i]; i++) {
+	for (size_t i = 1; args[i]; i++) {
 		char *deq = (char *)NULL;
 		if (strchr(args[i], '\\')) {
 			deq = unescape_str(args[i], 0);
@@ -747,10 +731,8 @@ check_not_compressed(char **args)
 			free(deq);
 		}
 
-		if (is_compressed(args[i], 1) != 0) {
-			xerror(_("archiver: '%s': Not an archive/compressed file\n"), args[i]);
+		if (is_compressed(args[i], 1) != FUNC_SUCCESS)
 			return 1;
-		}
 	}
 
 	return 0;
@@ -760,9 +742,9 @@ check_not_compressed(char **args)
 static size_t
 check_zstandard(char **args)
 {
-	size_t zst = 0, i;
+	size_t zst = 0;
 
-	for (i = 1; args[i]; i++) {
+	for (size_t i = 1; args[i]; i++) {
 		char *mime = xmagic(args[i], MIME_TYPE);
 		if (!mime || !*mime)
 			continue;
@@ -847,8 +829,7 @@ list_others(char **args)
 {
 	int exit_status = FUNC_SUCCESS;
 
-	size_t i;
-	for (i = 1; args[i]; i++) {
+	for (size_t i = 1; args[i]; i++) {
 		printf(_("%s%sFile%s: %s\n"), (i > 1) ? "\n" : "", BOLD, df_c, args[i]);
 
 		char *cmd[] = {"atool", "-l", args[i], NULL};
@@ -864,8 +845,7 @@ extract_to_dir_others(char **args)
 {
 	int exit_status = FUNC_SUCCESS;
 
-	size_t i;
-	for (i = 1; args[i]; i++) {
+	for (size_t i = 1; args[i]; i++) {
 		/* Ask for extraction path */
 		printf(_("%sFile%s: %s\n"), BOLD, df_c, args[i]);
 
@@ -1059,11 +1039,104 @@ decompress_others(char **args)
 	return FUNC_SUCCESS;
 }
 
+/* Some files, like .docx and .odt, while not properly zip files, are
+ * nonetheless zip-based. This function checks the first four bytes of the file
+ * FILE to identify zip-based files. It returns 1 if FILE is zip-based or
+ * zero otherwise.
+ * -1 is returned in case of error reading the file. */
+static int
+is_probably_zip(const char *file)
+{
+	FILE *f = fopen(file, "rb");
+	if (!f)
+		return (-1);
+
+	uint8_t sig[4];
+	if (fread(sig, 1, 4, f) != 4) {
+		fclose(f);
+		return 0;
+	}
+
+	fclose(f);
+	/* Common ZIP signatures:
+	 * local file header:   0x50 0x4B 0x03 0x04
+	 * empty archive:       0x50 0x4B 0x05 0x06 (end of central dir)
+	 * spanned archive:     0x50 0x4B 0x07 0x08 (spanned) */
+	if (sig[0] == 0x50 && sig[1] == 0x4B &&
+	((sig[2]== 0x03 && sig[3] == 0x04) ||
+	(sig[2] == 0x05 && sig[3] == 0x06) ||
+	(sig[2] == 0x07 && sig[3] == 0x08)))
+		return 1;
+
+	return 0;
+}
+
+#define ZIP_APP_NONE  0
+#define ZIP_APP_UNZIP 1
+#define ZIP_APP_7Z    2
+
+static int
+get_zip_app(void)
+{
+	if (is_cmd_in_path("unzip"))
+		return ZIP_APP_UNZIP;
+	if (is_cmd_in_path("7z"))
+		return ZIP_APP_7Z;
+	return ZIP_APP_NONE;
+}
+
+static int
+handle_zip(char **args)
+{
+	static int zip_app = -1;
+	if (zip_app == -1)
+		zip_app = get_zip_app();
+
+	int zip_found = 0;
+	int success = 0;
+	int ret = FUNC_SUCCESS;
+	char dest_dir[PATH_MAX + 2];
+
+	for (size_t i = 1; args[i]; i++) {
+		if (zip_app == ZIP_APP_NONE || is_probably_zip(args[i]) != 1) {
+			xerror(_("archiver: '%s': Not an archive/compressed file\n"), args[i]);
+			ret = FUNC_FAILURE;
+			continue;
+		}
+
+		zip_found = 1;
+
+		int retval = -1;
+		if (zip_app == ZIP_APP_UNZIP) {
+			snprintf(dest_dir, sizeof(dest_dir), "%s.extracted", args[i]);
+			char *cmd[] = {"unzip", args[i], "-d", dest_dir, NULL};
+			retval = launch_execv(cmd, FOREGROUND, E_NOFLAG);
+		} else {
+			snprintf(dest_dir, sizeof(dest_dir), "-o%s.extracted", args[i]);
+			char *cmd[] = {"7z", "x", args[i], dest_dir, NULL};
+			retval = launch_execv(cmd, FOREGROUND, E_NOFLAG);
+		}
+
+		if (retval != 0) {
+			if (success == 1 || args[i + 1])
+				press_any_key_to_continue(0);
+			ret = FUNC_FAILURE;
+		} else {
+			success = 1;
+		}
+	}
+
+	return zip_found == 0 ? FUNC_FAILURE : ret;
+}
+#undef ZIP_APP_NONE
+#undef ZIP_APP_UNZIP
+#undef ZIP_APP_7Z
+
 static int
 decompress_files(char **args)
 {
 	if (check_not_compressed(args) == 1)
-		return FUNC_FAILURE;
+		return handle_zip(args);
 
 	/* # ISO 9660 # */
 	const char *ret = strrchr(args[1], '.');
