@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* args.c -- Handle command line arguments */
@@ -84,7 +69,7 @@
 #define LOPT_RL_VI_MODE             207
 #define LOPT_MAX_DIRHIST            208
 #define LOPT_SORT_REVERSE           209
-#define LOPT_NO_FILES_COUNTER       210
+#define LOPT_NO_FILE_COUNTER        210
 #define LOPT_NO_WELCOME_MESSAGE     211
 #define LOPT_NO_CLEAR_SCREEN        212
 //#define LOPT_ENABLE_LOGS            213
@@ -239,8 +224,8 @@ static struct option const longopts[] = {
 	{"no-columns", no_argument, 0, LOPT_NO_COLUMNS},
 	{"no-dir-jumper", no_argument, 0, LOPT_NO_DIR_JUMPER},
 	{"no-file-cap", no_argument, 0, LOPT_NO_FILE_CAP},
-	{"no-files-counter", no_argument, 0, LOPT_NO_FILES_COUNTER}, /* Deprecated */
-	{"no-file-counter", no_argument, 0, LOPT_NO_FILES_COUNTER},
+	{"no-files-counter", no_argument, 0, LOPT_NO_FILE_COUNTER}, /* Deprecated */
+	{"no-file-counter", no_argument, 0, LOPT_NO_FILE_COUNTER},
 	{"no-file-ext", no_argument, 0, LOPT_NO_FILE_EXT},
 	{"no-follow-symlinks", no_argument, 0, LOPT_NO_FOLLOW_SYMLINKS},
 	{"no-fzfpreview", no_argument, 0, LOPT_NO_FZFPREVIEW},
@@ -695,11 +680,12 @@ get_home_sec_env(void)
 static int
 preview_this_file(const char *filename, const char *max_size)
 {
+	errno = 0;
 	const long s = strtol(max_size, NULL, 10);
-	if (s == 0)
+	if (s == 0 || errno == ERANGE)
 		return 0;
 
-	if (s > 0 && s <= INT_MAX) {
+	if (s > 0) {
 		struct stat a;
 		/* n >> 10 == n / 1024, i.e. n (which is in bytes) in KiB. */
 		if (stat(filename, &a) != -1 && (a.st_size >> 10) > (off_t)s)
@@ -717,17 +703,15 @@ open_reg_exit(char *filename, const int url, const int preview)
 	if (!filename)
 		exit(EXIT_FAILURE);
 
-	char *max_size =
-		(preview == 1 && url == 0 && xargs.secure_env != 1
-		&& xargs.secure_env_full != 1)
-			? getenv("CLIFM_PREVIEW_MAX_SIZE") : NULL;
+	const int sec_env = (xargs.secure_env == 1 || xargs.secure_env_full == 1);
+	char *max_size = (preview == 1 && url == 0 && sec_env == 0)
+		? getenv("CLIFM_PREVIEW_MAX_SIZE") : NULL;
 
 	if (max_size && *max_size && is_number(max_size)
 	&& preview_this_file(filename, max_size) == 0)
 		exit(EXIT_SUCCESS);
 
-	char *homedir = (xargs.secure_env == 1 || xargs.secure_env_full == 1)
-		? get_home_sec_env() : getenv("HOME");
+	char *homedir = sec_env == 1 ? get_home_sec_env() : getenv("HOME");
 	if (!homedir) {
 		xerror(_("%s: Cannot retrieve the home directory\n"), PROGRAM_NAME);
 		exit(EXIT_FAILURE);
@@ -735,8 +719,9 @@ open_reg_exit(char *filename, const int url, const int preview)
 
 	tmp_dir = savestring(P_tmpdir, P_tmpdir_len);
 
-	const char *env_preview_file = (preview == 1 && !alt_preview_file)
-		? getenv("CLIFM_ALT_PREVIEW_FILE") : NULL;
+	const char *env_preview_file =
+		(preview == 1 && !alt_preview_file && sec_env == 0)
+			? getenv("CLIFM_ALT_PREVIEW_FILE") : NULL;
 
 	if (env_preview_file && *env_preview_file) {
 		mime_file = savestring(env_preview_file, strlen(env_preview_file));
@@ -1550,7 +1535,7 @@ parse_cmdline_args(const int argc, char **argv)
 	while ((optc = getopt(argc, argv, OPTSTRING)) != EOF) {
 		switch (optc) {
 		case 'a': set_show_hidden(optarg); break;
-		case 'A': xargs.show_hidden = conf.show_hidden = 0; break;
+		case 'A': xargs.show_hidden = conf.show_hidden = HIDDEN_FALSE; break;
 		case 'b':
 			xargs.bm_file = 1;
 			set_alt_file(optarg, &alt_bm_file, "-b");
@@ -1566,7 +1551,7 @@ parse_cmdline_args(const int argc, char **argv)
 		case 'e': xargs.auto_open = conf.auto_open = 0; break;
 		case 'E': xargs.autocd = conf.autocd = 0; break;
 		case 'f': xargs.full_dir_size = conf.full_dir_size = 1; break;
-		case 'F': xargs.files_counter = conf.files_counter = 0; break;
+		case 'F': xargs.file_counter = conf.file_counter = 0; break;
 		case 'g': xargs.si = 1; break;
 		case 'G': xargs.apparent_size = conf.apparent_size = 0; break;
 		case 'h': help_function(); break; /* noreturn */
@@ -1698,7 +1683,7 @@ parse_cmdline_args(const int argc, char **argv)
 		switch (optc) {
 		/* Short options */
 		case 'a': set_show_hidden(optarg); break;
-		case 'A': xargs.show_hidden = conf.show_hidden = 0; break;
+		case 'A': xargs.show_hidden = conf.show_hidden = HIDDEN_FALSE; break;
 		case 'b':
 			xargs.bm_file = 1;
 			set_alt_file(optarg, &alt_bm_file, "-b");
@@ -1840,8 +1825,8 @@ parse_cmdline_args(const int argc, char **argv)
 			xargs.check_cap = conf.check_cap = 0; break;
 		case LOPT_NO_FILE_EXT:
 			xargs.check_ext = conf.check_ext = 0; break;
-		case LOPT_NO_FILES_COUNTER:
-			xargs.files_counter = conf.files_counter = 0; break;
+		case LOPT_NO_FILE_COUNTER:
+			xargs.file_counter = conf.file_counter = 0; break;
 		case LOPT_NO_FOLLOW_SYMLINKS:
 			xargs.follow_symlinks = conf.follow_symlinks = 0; break;
 		case LOPT_NO_FZFPREVIEW:
