@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* autocmds.c -- run cmds on a per-directory basis */
@@ -50,7 +35,7 @@ void
 reset_opts(void)
 {
 	opts.color_scheme = cur_cscheme;
-	opts.files_counter = conf.files_counter;
+	opts.file_counter = conf.file_counter;
 	opts.light_mode = conf.light_mode;
 	opts.max_files = conf.max_files;
 	opts.full_dir_size = conf.full_dir_size;
@@ -69,7 +54,7 @@ update_autocmd_opts(const int opt)
 {
 	switch (opt) {
 	case AC_COLOR_SCHEME: opts.color_scheme = cur_cscheme; break;
-	case AC_FILES_COUNTER: opts.files_counter = conf.files_counter; break;
+	case AC_FILE_COUNTER: opts.file_counter = conf.file_counter; break;
 	case AC_FULL_DIR_SIZE: opts.full_dir_size = conf.full_dir_size; break;
 	case AC_LIGHT_MODE: opts.light_mode = conf.light_mode; break;
 	case AC_LONG_VIEW: opts.long_view = conf.long_view; break;
@@ -148,7 +133,7 @@ static void
 save_current_options(void)
 {
 	opts.light_mode = conf.light_mode;
-	opts.files_counter = conf.files_counter;
+	opts.file_counter = conf.file_counter;
 	opts.full_dir_size = conf.full_dir_size;
 	opts.long_view = conf.long_view;
 	opts.max_files = conf.max_files;
@@ -168,8 +153,8 @@ set_autocmd_options(const size_t i)
 {
 	if (autocmds[i].light_mode != UNSET)
 		conf.light_mode = autocmds[i].light_mode;
-	if (autocmds[i].files_counter != UNSET)
-		conf.files_counter = autocmds[i].files_counter;
+	if (autocmds[i].file_counter != UNSET)
+		conf.file_counter = autocmds[i].file_counter;
 	if (autocmds[i].full_dir_size != UNSET)
 		conf.full_dir_size = autocmds[i].full_dir_size;
 	if (autocmds[i].long_view != UNSET)
@@ -204,11 +189,10 @@ gen_common_options(void)
 {
 	struct autocmds_t a;
 	struct autocmds_t *b = autocmds;
-	size_t i;
 
 	a.cmd = (char *)NULL;
 	a.color_scheme = (char *)NULL;
-	a.files_counter = UNSET;
+	a.file_counter = UNSET;
 	a.full_dir_size = UNSET;
 	a.light_mode = UNSET;
 	a.long_view = UNSET;
@@ -222,7 +206,7 @@ gen_common_options(void)
 	a.filter = (struct filter_t){0};
 	a.temp = 0;
 
-	for (i = 0; i < autocmds_n; i++) {
+	for (size_t i = 0; i < autocmds_n; i++) {
 		if (b[i].match == 0)
 			continue;
 
@@ -233,8 +217,8 @@ gen_common_options(void)
 			a.filter.rev = b[i].filter.rev;
 			a.filter.type = b[i].filter.type;
 		}
-		if (b[i].files_counter != UNSET)
-			a.files_counter = b[i].files_counter;
+		if (b[i].file_counter != UNSET)
+			a.file_counter = b[i].file_counter;
 		if (b[i].full_dir_size != UNSET)
 			a.full_dir_size = b[i].full_dir_size;
 		if (b[i].light_mode != UNSET)
@@ -286,8 +270,8 @@ gen_autocmd_options_list(char *buf, struct autocmds_t *a, const int print_filter
 	if (a->color_scheme != NULL)
 		len += gen_opt_entry(buf + len, "cs", a->color_scheme, &c, lm);
 
-	if (a->files_counter != UNSET)
-		len += gen_opt_entry(buf + len, "fc", xitoa(a->files_counter), &c, lm);
+	if (a->file_counter != UNSET)
+		len += gen_opt_entry(buf + len, "fc", xitoa(a->file_counter), &c, lm);
 
 	if (a->filter.str != NULL)
 		len += gen_opt_entry(buf + len, "ft",
@@ -331,8 +315,7 @@ gen_autocmd_options_list(char *buf, struct autocmds_t *a, const int print_filter
 static void
 print_autocmd_options_list_full(void)
 {
-	size_t i;
-	for (i = 0; i < autocmds_n; i++) {
+	for (size_t i = 0; i < autocmds_n; i++) {
 		if (autocmds[i].match == 0)
 			continue;
 
@@ -380,9 +363,8 @@ run_autocmds(const size_t *matches, const size_t matches_n)
 
 	int cs_last_index = UNSET;
 	int ft_last_index = UNSET;
-	size_t i;
 
-	for (i = 0; i < matches_n; i++) {
+	for (size_t i = 0; i < matches_n; i++) {
 		autocmds[matches[i]].match = 1;
 		if (autocmds[matches[i]].color_scheme != NULL)
 			cs_last_index = (int)matches[i];
@@ -402,8 +384,7 @@ run_autocmds(const size_t *matches, const size_t matches_n)
 static void
 unset_autocmd_matches(void)
 {
-	size_t i;
-	for (i = 0; i < autocmds_n; i++)
+	for (size_t i = 0; i < autocmds_n; i++)
 		autocmds[i].match = 0;
 }
 
@@ -420,9 +401,8 @@ check_autocmds(void)
 
 	size_t matches[256]; /* Store indices of matching entries */
 	size_t matches_n = 0;
-	size_t i;
 
-	for (i = 0; i < autocmds_n && matches_n < sizeof(matches); i++) {
+	for (size_t i = 0; i < autocmds_n && matches_n < sizeof(matches); i++) {
 		if (!autocmds[i].pattern || !*autocmds[i].pattern)
 			continue;
 
@@ -533,7 +513,7 @@ void
 revert_autocmd_opts(void)
 {
 	conf.light_mode = opts.light_mode;
-	conf.files_counter = opts.files_counter;
+	conf.file_counter = opts.file_counter;
 	conf.full_dir_size = opts.full_dir_size;
 	conf.long_view = opts.long_view;
 	conf.max_files = opts.max_files;
@@ -568,8 +548,7 @@ set_autocmd_color_scheme(const char *name, const size_t n)
 		return FUNC_SUCCESS;
 	}
 
-	int i = (int)cschemes_n;
-	while (--i >= 0) {
+	for (size_t i = cschemes_n; i-- > 0;) {
 		if (*color_schemes[i] == *name
 		&& strcmp(color_schemes[i], name) == 0) {
 			autocmds[n].color_scheme = color_schemes[i];
@@ -591,8 +570,7 @@ set_autocmd_sort_by_name(const char *name, const size_t n)
 		return FUNC_SUCCESS;
 	}
 
-	size_t i;
-	for (i = 0; i <= SORT_TYPES; i++) {
+	for (size_t i = 0; i <= SORT_TYPES; i++) {
 		if (*name != *sort_methods[i].name
 		|| strcmp(name, sort_methods[i].name) != 0)
 			continue;
@@ -668,7 +646,7 @@ fill_autocmd_opt(char *opt, const size_t n)
 	if (*opt == 's' && opt[1] == 't')
 		return set_autocmd_sort(*p ? p : "unset", n);
 
-	/* The below options taken only numbers (or 'unset') as values. */
+	/* The below options take only numbers (or 'unset') as values. */
 	int a = 0;
 	if (!*p) { /* 'OPTION=' amounts to 'OPTION=unset'. */
 		a = UNSET;
@@ -681,12 +659,12 @@ fill_autocmd_opt(char *opt, const size_t n)
 	}
 
 	if (*opt == 'm' && opt[1] == 'f') {
-		autocmds[n].max_files = !*p ? AC_UNSET : a;
+		autocmds[n].max_files = a == UNSET ? AC_UNSET : a;
 		return FUNC_SUCCESS;
 	}
 
 	if (*opt == 'm' && opt[1] == 'n') {
-		autocmds[n].max_name_len = !*p ? AC_UNSET : a;
+		autocmds[n].max_name_len = a == UNSET ? AC_UNSET : a;
 		return FUNC_SUCCESS;
 	}
 
@@ -694,7 +672,7 @@ fill_autocmd_opt(char *opt, const size_t n)
 		goto ERR_VAL;
 
 	if (*opt == 'f' && opt[1] == 'c')
-		autocmds[n].files_counter = a;
+		autocmds[n].file_counter = a;
 	else if (*opt == 'f' && opt[1] == 'z')
 		autocmds[n].full_dir_size = a;
 	else if (*opt == 'h' && (opt[1] == 'f' || opt[1] == 'h'))
@@ -730,7 +708,7 @@ init_autocmd_opts(const size_t n)
 {
 	autocmds[n].cmd = (char *)NULL;
 	autocmds[n].color_scheme = (char *)NULL;
-	autocmds[n].files_counter = UNSET;
+	autocmds[n].file_counter = UNSET;
 	autocmds[n].full_dir_size = UNSET;
 	autocmds[n].light_mode = UNSET;
 	autocmds[n].long_view = UNSET;
@@ -847,8 +825,8 @@ static int
 unset_tmp_autocmds(void)
 {
 	size_t found = 0;
-	size_t i;
-	for (i = 0; i < autocmds_n; i++) {
+
+	for (size_t i = 0; i < autocmds_n; i++) {
 		if (autocmds[i].temp == 1
 		&& *autocmds[i].pattern == *workspaces[cur_ws].path
 		&& strcmp(autocmds[i].pattern, workspaces[cur_ws].path) == 0) {
@@ -878,10 +856,9 @@ autocmd_dirlist_reload(void)
 static size_t
 get_longest_pattern(void)
 {
-	size_t i;
 	size_t len = 0;
 
-	for (i = 0; i < autocmds_n; i++) {
+	for (size_t i = 0; i < autocmds_n; i++) {
 		if (!autocmds[i].pattern || !*autocmds[i].pattern)
 			continue;
 
@@ -903,10 +880,9 @@ print_autocmds_list(void)
 	}
 
 	char buf[AC_BUF_SIZE];
-	size_t i;
 	const int longest_pattern = (int)get_longest_pattern();
 
-	for (i = 0; i < autocmds_n; i++) {
+	for (size_t i = 0; i < autocmds_n; i++) {
 		if (!autocmds[i].pattern || !*autocmds[i].pattern
 		|| gen_autocmd_options_list(buf, &autocmds[i], 1) <= 0)
 			continue;
@@ -962,8 +938,7 @@ add_autocmd(char **args)
 			: autocmd_dirlist_reload());
 	}
 
-	size_t i;
-	for (i = 0; i < autocmds_n; i++) {
+	for (size_t i = 0; i < autocmds_n; i++) {
 		if (autocmds[i].temp == 1
 		&& strcmp(workspaces[cur_ws].path, autocmds[i].pattern) == 0) {
 			/* Add option to an existing autocmd */
