@@ -2,23 +2,8 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
- */
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
+*/
 
 /* aux.c -- functions that do not fit in any other file */
 
@@ -1199,12 +1184,12 @@ xitoa(long long n)
 	 * (32), that is, from index 0 to 31. Index 31 is reserved for the NUL
 	 * terminator, so that we must start writing at index 30. */
 	long long i = MAX_INT_STR - 2;
+	long long rem = 0;
 
-	while (n > 0 && i > 0) {
-		long long rem = n / 10;
-		buf[i] = (char)('0' + (n - (rem * 10)));
+	while (n > 0 && i >= 0) {
+		rem = n / 10;
+		buf[i--] = (char)('0' + (n - (rem * 10)));
 		n = rem;
-		--i;
 	}
 
 	return &buf[i + 1];
