@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* bookmarks.c -- bookmarking functions */
@@ -47,8 +32,7 @@ free_bookmarks(void)
 	if (bm_n == 0)
 		return;
 
-	size_t i;
-	for (i = 0; i < bm_n; i++) {
+	for (size_t i = 0; i < bm_n; i++) {
 		free(bookmarks[i].shortcut);
 		free(bookmarks[i].name);
 		free(bookmarks[i].path);
@@ -153,9 +137,7 @@ get_longest_entries(size_t *ls, size_t *ln)
 	if (bm_n == 0 || !bookmarks)
 		return;
 
-	int i = (int)bm_n;
-
-	while (--i >= 0) {
+	for (size_t i = bm_n; i-- > 0;) {
 		if (bookmarks[i].shortcut && *bookmarks[i].shortcut) {
 			const size_t slen = strlen(bookmarks[i].shortcut);
 			if (slen > *ls)
@@ -180,12 +162,11 @@ print_bookmarks(void)
 	struct stat attr;
 	const int eln_pad = DIGINUM(bm_n);
 	size_t ls = 0, ln = 0;
-	size_t i;
 
 	get_longest_entries(&ls, &ln);
 
 	/* Print bookmarks, taking into account shortcut, name, and path. */
-	for (i = 0; i < bm_n; i++) {
+	for (size_t i = 0; i < bm_n; i++) {
 		if (!bookmarks[i].path || !*bookmarks[i].path)
 			continue;
 
@@ -222,8 +203,7 @@ edit_bookmarks_func(char **arg)
 {
 	edit_bookmarks(arg[1], BM_SCREEN);
 
-	size_t i;
-	for (i = 0; arg[i]; i++)
+	for (size_t i = 0; arg[i]; i++)
 		free(arg[i]);
 	free(arg);
 
@@ -252,8 +232,7 @@ get_bm_path(char *arg)
 	char *name = p ? p : arg;
 
 	/* If string, check shortcuts and names */
-	size_t i;
-	for (i = 0; i < bm_n; i++) {
+	for (size_t i = 0; i < bm_n; i++) {
 		if ((bookmarks[i].shortcut && *name == *bookmarks[i].shortcut
 		&& strcmp(name, bookmarks[i].shortcut) == 0)
 		|| (bookmarks[i].name && *name == *bookmarks[i].name
@@ -273,9 +252,7 @@ get_bm_path(char *arg)
 static void
 free_bm_input(char ***p)
 {
-	size_t i;
-
-	for (i = 0; (*p)[i]; i++)
+	for (size_t i = 0; (*p)[i]; i++)
 		free((*p)[i]);
 	free(*p);
 	*p = (char **)NULL;
@@ -352,8 +329,7 @@ bm_open(char **cmd)
 	if (!p)
 		p = cmd[1];
 
-	size_t i;
-	for (i = 0; i < bm_n; i++) {
+	for (size_t i = 0; i < bm_n; i++) {
 		if (!(bookmarks[i].shortcut && *p == *bookmarks[i].shortcut
 		&& strcmp(p, bookmarks[i].shortcut) == 0)
 
@@ -391,8 +367,7 @@ check_bm_path(char *file)
 	char *p = normalize_path(file, strlen(file));
 	char *new_path = p ? p : file;
 
-	int i = (int)bm_n;
-	while (--i >= 0) {
+	for (size_t i = bm_n; i-- > 0;) {
 		if (!bookmarks[i].path || strcmp(new_path, bookmarks[i].path) != 0)
 			continue;
 
@@ -444,15 +419,14 @@ check_bm_name(const char *name, const int add)
 	if (add == 1 && name_is_reserved_keyword(name) == 1)
 		return 0;
 
-	int i = (int)bm_n;
-	while (--i >= 0) {
+	for (size_t i = bm_n; i-- > 0;) {
 		if (!bookmarks[i].name || *name != *bookmarks[i].name
 		|| strcmp(name, bookmarks[i].name) != 0)
 			continue;
 
 		if (add == 1)
 			xerror(_("bookmarks: '%s': Name already in use\n"), name);
-		return i;
+		return i > INT_MAX ? INT_MAX : (int)i;
 	}
 
 	return (-1);
@@ -468,22 +442,21 @@ check_bm_shortcut(const char *shortcut, const int add)
 	if (add == 1 && name_is_reserved_keyword(shortcut) == 1)
 		return 0;
 
-	int i = (int)bm_n;
-	while (--i >= 0) {
+	for (size_t i = bm_n; i-- > 0;) {
 		if (!bookmarks[i].shortcut || *shortcut != *bookmarks[i].shortcut
 		|| strcmp(shortcut, bookmarks[i].shortcut) != 0)
 			continue;
 
 		if (add == 1)
 			xerror(_("bookmarks: '%s': Shortcut already in use\n"), shortcut);
-		return i;
+		return i > INT_MAX ? INT_MAX : (int)i;
 	}
 
 	return (-1);
 }
 
 /* Bookmark the file FILE as NAME and shortcut SHORTCUT.
- * FILE and NAME are guarranteed to be non-NULL.
+ * FILE and NAME are guaranteed to be non-NULL.
  * FILE is already dequoted. */
 static int
 bookmark_add(char *file, char *name, char *shortcut)
@@ -594,9 +567,9 @@ static size_t
 mark_bookmarks_for_deletion(char **args, int *exit_status)
 {
 	*exit_status = FUNC_SUCCESS;
-	size_t i, counter = 0;
+	size_t counter = 0;
 
-	for (i = 0; args[i]; i++) {
+	for (size_t i = 0; args[i]; i++) {
 		char *p = unescape_str(args[i], 0);
 		char *name = p ? p : args[i];
 		int index = -1;
@@ -657,9 +630,8 @@ keep_bm_line(char *line)
 
 	struct bookmarks_t bm = extract_shortcut_and_name(line);
 	int keep = 1;
-	size_t i;
 
-	for (i = 0; i < bm_n; i++) {
+	for (size_t i = 0; i < bm_n; i++) {
 		if (!bookmarks[i].path || *bookmarks[i].path) /* Not marked for deletion */
 			continue;
 
