@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* bulk_rename.c -- bulk rename files */
@@ -50,7 +35,7 @@
 
 #define BULK_RENAME_TMP_FILE_HEADER "# Clifm - Rename files in bulk\n\
 # Edit filenames, save, and quit the editor (you will be\n\
-# asked for confirmation).\n\
+# prompted to confirm).\n\
 # Quit the editor without saving to cancel the operation.\n\n"
 
 #define IS_BR_COMMENT(l) (*(l) == '#' && (l)[1] == ' ')
@@ -124,7 +109,6 @@ static int
 write_files_to_tmp(char ***args, const char *tmpfile, const int fd,
 	struct stat *attr, size_t *written)
 {
-	size_t i;
 	FILE *fp = fdopen(fd, "w");
 	if (!fp)
 		return err_open_tmp_file(tmpfile, fd);
@@ -132,7 +116,7 @@ write_files_to_tmp(char ***args, const char *tmpfile, const int fd,
 	fprintf(fp, BULK_RENAME_TMP_FILE_HEADER);
 
 	/* Copy all files to be renamed into the bulk file */
-	for (i = 1; (*args)[i]; i++) {
+	for (size_t i = 1; (*args)[i]; i++) {
 		/* Dequote filename, if necessary */
 		if (strchr((*args)[i], '\\')) {
 			char *deq_file = unescape_str((*args)[i], 0);
@@ -188,10 +172,9 @@ static size_t
 print_and_count_modified_names(char **args, char **new_names)
 {
 	size_t modified = 0;
-	size_t i;
 
 	/* Print what would be done */
-	for (i = 0; new_names[i]; i++) {
+	for (size_t i = 0; new_names[i]; i++) {
 		if (args[i] && strcmp(args[i], new_names[i]) != 0) {
 			char *a = abbreviate_file_name(args[i]);
 			char *b = abbreviate_file_name(new_names[i]);
@@ -257,10 +240,9 @@ static int
 rename_bulk_files(char **old_names, char **new_names, int *is_cwd,
 	size_t *renamed, const size_t modified)
 {
-	size_t i = 1;
 	int exit_status = FUNC_SUCCESS;
 
-	for (i = 0; new_names[i]; i++) {
+	for (size_t i = 0; new_names[i]; i++) {
 		if (!old_names[i] || strcmp(old_names[i], new_names[i]) == 0)
 			continue;
 
