@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* checks.c -- misc check functions */
@@ -239,9 +224,9 @@ check_third_party_cmds(void)
 	check_coreutils = 1;
 #endif /* CHECK_COREUTILS */
 
-	int i = (int)path_progsn;
+	size_t i = path_progsn;
 
-	while (--i >= 0) {
+	for (; i-- > 0;) {
 		if (*bin_commands[i] != 'u' && *bin_commands[i] != 'f'
 		&& *bin_commands[i] != 's'
 #if defined(USE_DU1) && !defined(HAVE_GNU_DU) && !defined(_BE_POSIX)
@@ -302,8 +287,7 @@ check_third_party_cmds(void)
 static int
 check_user_groups(const gid_t gid)
 {
-	int i;
-	for (i = 0; i < user.ngroups; i++) {
+	for (int i = 0; i < user.ngroups; i++) {
 		if (user.groups[i] == gid)
 			return 1;
 	}
@@ -440,8 +424,7 @@ is_action_name(const char *s)
 	if (actions_n == 0)
 		return 0;
 
-	int n = (int)actions_n;
-	while (--n >= 0) {
+	for (size_t n = actions_n; n-- > 0;) {
 		if (*s == *usr_actions[n].name && strcmp(s, usr_actions[n].name) == 0)
 			return 1;
 	}
@@ -473,10 +456,9 @@ is_internal_cmd(char *cmd, const int flag, const int check_hist,
 	}
 
 	const size_t clen = strlen(cmd);
-	ssize_t i = (ssize_t)internal_cmds_n;
 	int found = 0;
 
-	while (--i >= 0) {
+	for (size_t i = internal_cmds_n; i-- > 0;) {
 		if (((flag & ALL_CMDS) || (internal_cmds[i].flag & flag))
 		&& clen == internal_cmds[i].len && *cmd == *internal_cmds[i].name
 		&& strcmp(cmd + 1, internal_cmds[i].name + 1) == 0) {
@@ -516,8 +498,7 @@ is_bin_cmd(char *str)
 		index++;
 	}
 
-	size_t i;
-	for (i = 0; bin_commands[i]; i++) {
+	for (size_t i = 0; bin_commands[i]; i++) {
 		if (*q == *bin_commands[i] && q[1] == bin_commands[i][1]
 		&& strcmp(q, bin_commands[i]) == 0) {
 			if (space_index != -1)
@@ -570,9 +551,7 @@ check_for_alias(char **args)
 	|| *args[0] == '\\')
 		return (char **)NULL;
 
-	int i = (int)aliases_n;
-
-	while (--i >= 0) {
+	for (size_t i = aliases_n; i-- > 0;) {
 		if (!aliases[i].name || !aliases[i].cmd || !*aliases[i].name
 		|| !*aliases[i].cmd)
 			continue;
