@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* colors.c -- functions to control interface colors */
@@ -29,13 +14,12 @@
 #endif /* __linux__ */
 #include <errno.h>
 #include <string.h>
-#ifndef CLIFM_SUCKLESS
 # include <strings.h> /* str(n)casecmp() */
-#endif /* CLIFM_SUCKLESS */
 
 /* Only used to check the readline version */
 #ifdef __OpenBSD__
-  typedef char *rl_cpvfunc_t;
+typedef char *rl_cpvfunc_t;
+typedef void rl_macro_print_func_t (const char *, const char *, int, const char *);
 # include <ereadline/readline/readline.h>
 #else
 # include <readline/readline.h>
@@ -45,7 +29,7 @@
 #include "autocmds.h" /* update_autocmd_opts() */
 #include "checks.h"
 #include "colors.h"
-#include "config.h" /* set_div_line() */
+#include "config.h" /* get_fzf_height(), get_fzf_border_type() */
 #include "file_operations.h"
 #include "listing.h"
 #include "messages.h"
@@ -53,26 +37,13 @@
 #include "prompt.h" /* gen_color() */
 #include "properties.h" /* get_color_age(), get_color_size() */
 #include "sanitize.h"
+#include "sort.h" /* compare_string() (used by qsort(3)), QSFUNC */
 #include "spawn.h"
 
-#ifndef CLIFM_SUCKLESS
-/* qsort(3) is used only by get_colorschemes(), which is not included
- * if CLIFM_SUCKLESS is defined */
-# include "sort.h" /* compare_string() (used by qsort(3)) */
-#endif /* !CLIFM_SUCKLESS */
-
 #define ON_LSCOLORS (xargs.lscolors == LS_COLORS_GNU              \
 		? _(" (on LS_COLORS)") : (xargs.lscolors == LS_COLORS_BSD \
 		? _(" (on LSCOLORS)") : ""))
 
-#ifndef CLIFM_SUCKLESS
-/* A struct to hold color variables */
-struct colors_t {
-	char *name;
-	char *value;
-	size_t namelen;
-};
-
 /* A struct to map color codes to color variables */
 struct color_mapping_t {
 	const char *prefix; /* Color code name (e.g. "el") */
@@ -81,6 +52,14 @@ struct color_mapping_t {
 	int printable;      /* Either RL_PRINTABLE or RL_NO_PRINTABLE */
 };
 
+#ifndef CLIFM_SUCKLESS
+/* A struct to hold color variables */
+struct colors_t {
+	char *name;
+	char *value;
+	size_t namelen;
+};
+
 static struct colors_t *defs;
 static size_t defs_n = 0;
 
@@ -289,7 +268,7 @@ char *
 get_regfile_color(const char *filename, const struct stat *a, size_t *is_ext)
 {
 	*is_ext = 0;
-	if (conf.colorize == 0)
+	if (conf.colorize == 0 || conf.light_mode == 1)
 		return fi_c;
 
 	if (*nf_c && check_file_access(a->st_mode, a->st_uid, a->st_gid) == 0)
@@ -325,6 +304,9 @@ char *
 get_dir_color(const char *filename, const struct stat *a,
 	const filesn_t count)
 {
+	if (conf.file_counter == 0 && conf.light_mode == 1)
+		return di_c;
+
 	const mode_t mode = a->st_mode;
 	if (*nd_c && check_file_access(mode, a->st_uid, a->st_gid) == 0)
 		return nd_c;
@@ -606,10 +588,9 @@ check_defs(const char *str)
 	if (defs_n == 0 || !str || !*str)
 		return (char *)NULL;
 
-	int i = (int)defs_n;
 	const size_t slen = strlen(str);
 
-	while (--i >= 0) {
+	for (size_t i = defs_n; i-- > 0;) {
 		if (!defs[i].name || !defs[i].value || !*defs[i].name
 		|| !*defs[i].value)
 			continue;
@@ -630,8 +611,7 @@ clear_defs(void)
 	if (defs_n == 0)
 		goto END;
 
-	int i = (int)defs_n;
-	while (--i >= 0) {
+	for (size_t i = defs_n; i-- > 0;) {
 		free(defs[i].name);
 		free(defs[i].value);
 	}
@@ -683,15 +663,15 @@ check_ext_string(const char *ext, size_t *val_len)
 	static char tmp_ext[NAME_MAX];
 	char *ptr = tmp_ext;
 
-	int i;
+	size_t i;
 	for (i = 0; i < NAME_MAX && ext[i]; i++)
 		tmp_ext[i] = TOLOWER(ext[i]);
 	tmp_ext[i] = '\0';
 
-	const size_t len = (size_t)i;
+	const size_t len = i;
 
-	i = (int)ext_colors_n;
-	while (--i >= 0) {
+	i = ext_colors_n;
+	for (; i-- > 0;) {
 		if (!ext_colors[i].name || !*ext_colors[i].name
 		|| ext_colors[i].len != len || *ptr != TOLOWER(*ext_colors[i].name))
 			continue;
@@ -845,8 +825,7 @@ list_colorschemes(void)
 	}
 
 	const char *ptr = SET_MISC_PTR;
-	size_t i;
-	for (i = 0; color_schemes[i]; i++) {
+	for (size_t i = 0; color_schemes[i]; i++) {
 		if (cur_cscheme == color_schemes[i]) {
 			printf("%s%s%s %s%s\n", mi_c, ptr, df_c, color_schemes[i],
 				ON_LSCOLORS);
@@ -1471,8 +1450,7 @@ store_extension_line(const char *line)
 static void
 free_extension_colors(void)
 {
-	int i = (int)ext_colors_n;
-	while (--i >= 0) {
+	for (size_t i = ext_colors_n; i-- > 0;) {
 		free(ext_colors[i].name);
 		free(ext_colors[i].value);
 	}
@@ -1743,9 +1721,8 @@ static int
 get_cur_colorscheme(const char *colorscheme)
 {
 	char *def_cscheme = (char *)NULL;
-	int i = (int)cschemes_n;
 
-	while (--i >= 0) {
+	for (size_t i = cschemes_n; i-- > 0;) {
 		if (*colorscheme == *color_schemes[i]
 		&& strcmp(colorscheme, color_schemes[i]) == 0) {
 			cur_cscheme = color_schemes[i];
@@ -1983,8 +1960,7 @@ store_definition(const char *str)
 static void
 init_defs(void)
 {
-	int n = MAX_DEFS;
-	while (--n >= 0) {
+	for (size_t n = MAX_DEFS; n-- > 0;) {
 		defs[n].name = (char *)NULL;
 		defs[n].value = (char *)NULL;
 	}
@@ -2199,6 +2175,23 @@ set_cs_dir_icon_color(char *line, const ssize_t line_len)
 }
 #endif /* !_NO_ICONS */
 
+static void
+set_div_line(char *line)
+{
+	if (!line || *line < ' ') {
+		*div_line = *DEF_DIV_LINE;
+		return;
+	}
+
+	char *tmp = remove_quotes(line);
+	if (!tmp) {
+		*div_line = '\0';
+		return;
+	}
+
+	xstrsncpy(div_line, tmp, sizeof(div_line));
+}
+
 /* Get color lines from the configuration file */
 static int
 read_color_scheme_file(const char *colorscheme, char **filecolors,
@@ -2564,12 +2557,12 @@ remove_trash_ext(char **ent)
 	&& cur_comp_type != TCMP_TRASHDEL))
 		return (char *)NULL;
 
-	char *d = strrchr(*ent, '.');
-	if (d && d != *ent && d[1] == '2'
-	&& strlen(d + 1) == 14 && is_number(d + 1))
-		*d = '\0';
+	char *dot = strrchr(*ent, '.');
+	if (dot && dot != *ent && dot[1] == '2'
+	&& strlen(dot + 1) == 14 && is_number(dot + 1))
+		*dot = '\0';
 
-	return d;
+	return dot;
 }
 
 char *
@@ -2592,7 +2585,7 @@ get_entry_color(char *ent, const struct stat *a)
 		break;
 
 	case S_IFLNK: {
-		if (conf.colorize == 0) {
+		if (conf.colorize == 0 || conf.light_mode == 1) {
 			color = ln_c;
 		} else {
 			char *linkname = xrealpath(ent, NULL);
@@ -2706,8 +2699,7 @@ is_valid_colorscheme_name(char *name)
 static int
 is_duplicate_colorscheme_name(const char *name, const size_t total)
 {
-	size_t i;
-	for (i = 0; i < total; i++) {
+	for (size_t i = 0; i < total; i++) {
 		if (*color_schemes[i] == *name && strcmp(name, color_schemes[i]) == 0)
 			return 1;
 	}
