@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* dothidden.c
@@ -94,9 +79,8 @@ load_dothidden(void)
 
 		lines += gbuf.gl_pathc;
 		h = xnrealloc(h, lines, sizeof(struct dothidden_t));
-		size_t i;
 
-		for (i = 0; i < gbuf.gl_pathc; i++) {
+		for (size_t i = 0; i < gbuf.gl_pathc; i++) {
 			/* Exclude self and parent dirs, just as dot-files */
 			if (!gbuf.gl_pathv[i] || !*gbuf.gl_pathv[i]
 			|| *gbuf.gl_pathv[i] == '.')
@@ -127,9 +111,8 @@ check_dothidden(const char *restrict name, struct dothidden_t **h)
 		return 0;
 
 	const size_t namelen = strlen(name);
-	size_t i;
 
-	for (i = 0; (*h)[i].name; i++) {
+	for (size_t i = 0; (*h)[i].name; i++) {
 		if (*name == *(*h)[i].name && namelen == (*h)[i].len
 		&& strcmp(name, (*h)[i].name) == 0)
 			return 1;
@@ -145,8 +128,7 @@ free_dothidden(struct dothidden_t **h)
 	if (!*h)
 		return;
 
-	size_t i;
-	for (i = 0; (*h)[i].name; i++)
+	for (size_t i = 0; (*h)[i].name; i++)
 		free((*h)[i].name);
 
 	free(*h);
