@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* exec.c -- functions controlling the execution of programs */
@@ -33,6 +18,7 @@
 
 #ifdef __OpenBSD__
 typedef char *rl_cpvfunc_t;
+typedef void rl_macro_print_func_t (const char *, const char *, int, const char *);
 # include <ereadline/readline/readline.h>
 #else
 # include <readline/readline.h>
@@ -54,6 +40,7 @@ typedef char *rl_cpvfunc_t;
 #include "config.h"
 #include "exec.h"
 #include "file_operations.h"
+#include "fs_events.h" /* check_fs_events */
 #include "history.h"
 #include "init.h"
 #include "jump.h"
@@ -100,10 +87,9 @@ check_paths_timestamps(void)
 		return FUNC_SUCCESS;
 
 	struct stat a;
-	int i = (int)path_n;
 	int status = FUNC_SUCCESS;
 
-	while (--i >= 0) {
+	for (size_t i = path_n; i-- > 0;) {
 		if (paths[i].path && *paths[i].path && stat(paths[i].path, &a) != -1
 		&& a.st_mtime != paths[i].mtime) {
 			paths[i].mtime = a.st_mtime;
@@ -117,8 +103,8 @@ check_paths_timestamps(void)
 /* Reload the list of available commands in PATH for tab completion.
  * Why? If this list is not updated, whenever some new program is
  * installed, renamed, or removed from some of the paths in PATH
- * while in CliFM, this latter needs to be restarted in order
- * to be able to recognize the new program for tab completion */
+ * while in Clifm, this latter needs to be restarted in order
+ * to be able to recognize the new program for tab completion. */
 static void
 reload_binaries(void)
 {
@@ -126,16 +112,14 @@ reload_binaries(void)
 		return;
 
 	if (bin_commands) {
-		int j = (int)path_progsn;
-		while (--j >= 0)
+		for (size_t j = path_progsn; j-- > 0;)
 			free(bin_commands[j]);
 		free(bin_commands);
 		bin_commands = (char **)NULL;
 	}
 
 	if (paths) {
-		int j = (int)path_n;
-		while (--j >= 0)
+		for (size_t j = path_n; j-- > 0;)
 			free(paths[j].path);
 		free(paths);
 	}
@@ -162,8 +146,7 @@ export_var_function(char **args)
 	}
 
 	int status = FUNC_SUCCESS;
-	size_t i;
-	for (i = 0; args[i]; i++) {
+	for (size_t i = 0; args[i]; i++) {
 		/* ARG might have been escaped by parse_input_str(), in the command
 		 * and parameter substitution block. Let's deescape it. */
 		char *ds = unescape_str(args[i], 0);
@@ -295,8 +278,7 @@ quit_func(char **args, const int exit_status)
 		return;
 	}
 
-	int i = (int)args_n + 1;
-	while (--i >= 0)
+	for (size_t i = args_n + 1; i-- > 0;)
 		free(args[i]);
 	free(args);
 
@@ -379,11 +361,11 @@ static int
 file_counter_function(const char *arg)
 {
 	if (!arg) {
-		conf.files_counter = !conf.files_counter;
-		update_autocmd_opts(AC_FILES_COUNTER);
+		conf.file_counter = !conf.file_counter;
+		update_autocmd_opts(AC_FILE_COUNTER);
 		if (conf.autols == 1) reload_dirlist();
 		print_reload_msg(NULL, NULL, _("File counter: %s\n"),
-			conf.files_counter == 1 ? _("on") : _("off"));
+			conf.file_counter == 1 ? _("on") : _("off"));
 		return FUNC_SUCCESS;
 	}
 
@@ -393,23 +375,23 @@ file_counter_function(const char *arg)
 	}
 
 	if (*arg == 'o' && strcmp(arg, "on") == 0) {
-		conf.files_counter = 1;
-		update_autocmd_opts(AC_FILES_COUNTER);
+		conf.file_counter = 1;
+		update_autocmd_opts(AC_FILE_COUNTER);
 		if (conf.autols == 1) reload_dirlist();
 		print_reload_msg(NULL, NULL, _("File counter: on\n"));
 		return FUNC_SUCCESS;
 	}
 
 	if (*arg == 'o' && strcmp(arg, "off") == 0) {
-		conf.files_counter = 0;
-		update_autocmd_opts(AC_FILES_COUNTER);
+		conf.file_counter = 0;
+		update_autocmd_opts(AC_FILE_COUNTER);
 		if (conf.autols == 1) reload_dirlist();
 		print_reload_msg(NULL, NULL, _("File counter: off\n"));
 		return FUNC_SUCCESS;
 	}
 
 	if (*arg == 's' && strcmp(arg, "status") == 0) {
-		if (conf.files_counter == 1)
+		if (conf.file_counter == 1)
 			puts(_("The file counter is on"));
 		else
 			puts(_("The file counter is off"));
@@ -643,8 +625,7 @@ clear_msgs(void)
 		return FUNC_SUCCESS;
 	}
 
-	size_t i;
-	for (i = 0; i < msgs_n; i++)
+	for (size_t i = 0; i < msgs_n; i++)
 		free(messages[i].text);
 
 	if (conf.autols == 1)
@@ -659,8 +640,7 @@ clear_msgs(void)
 static int
 print_msgs(void)
 {
-	size_t i;
-	for (i = 0; i < msgs_n; i++) {
+	for (size_t i = 0; i < msgs_n; i++) {
 		if (i > 0 && strcmp(messages[i].text, messages[i - 1].text) == 0)
 			continue;
 		printf("%s", messages[i].text);
@@ -744,9 +724,8 @@ lightmode_function(const char *arg)
 static size_t
 get_longest_alias_name(void)
 {
-	int i = (int)aliases_n;
 	size_t l = 0;
-	while (--i >= 0) {
+	for (size_t i = aliases_n; i-- > 0;) {
 		const size_t len = strlen(aliases[i].name);
 		if (len > l)
 			l = len;
@@ -763,10 +742,9 @@ list_aliases(void)
 		return FUNC_SUCCESS;
 	}
 
-	size_t i;
 	const size_t longest_name_len = get_longest_alias_name();
 
-	for (i = 0; i < aliases_n; i++) {
+	for (size_t i = 0; i < aliases_n; i++) {
 		printf("%-*s %s%s%s %s\n", (int)longest_name_len,
 			aliases[i].name, mi_c, SET_MSG_PTR, df_c, aliases[i].cmd);
 	}
@@ -785,8 +763,7 @@ print_alias(const char *name)
 		return FUNC_SUCCESS;
 	}
 
-	int i = (int)aliases_n;
-	while (--i >= 0) {
+	for (size_t i = aliases_n; i-- > 0;) {
 		if (aliases[i].name && *name == *aliases[i].name
 		&& strcmp(name, aliases[i].name) == 0) {
 			printf("alias %s='%s'\n", aliases[i].name,
@@ -882,9 +859,9 @@ toggle_exec_func(char **args)
 		{ puts(_(TE_USAGE)); return FUNC_SUCCESS; }
 
 	int exit_status = FUNC_SUCCESS;
-	size_t i, n = 0;
+	size_t n = 0;
 
-	for (i = 1; args[i]; i++) {
+	for (size_t i = 1; args[i]; i++) {
 		struct stat attr;
 		if (strchr(args[i], '\\')) {
 			char *tmp = unescape_str(args[i], 0);
@@ -1103,8 +1080,7 @@ sort_func(char **args)
 static int
 check_pinned_file(char **args)
 {
-	int i = (int)args_n + 1;
-	while (--i >= 0) {
+	for (size_t i = args_n + 1; i-- > 0;) {
 		if (*args[i] == ',' && !args[i][1]) {
 			xerror(_("%s: No pinned file\n"), PROGRAM_NAME);
 			return FUNC_FAILURE;
@@ -1120,8 +1096,7 @@ check_actions(char **args)
 	if (actions_n == 0)
 		return (-1);
 
-	int i = (int)actions_n;
-	while (--i >= 0) {
+	for (size_t i = actions_n; i-- > 0;) {
 		if (*args[0] == *usr_actions[i].name
 		&& strcmp(args[0], usr_actions[i].name) == 0) {
 			setenv("CLIFM_PLUGIN_NAME", usr_actions[i].name, 1);
@@ -1311,7 +1286,7 @@ check_auto_second(char **args)
 	 * not ./file, and not /path/to/file */
 	if (conf.auto_open == 1 && S_ISREG(attr.st_mode)
 	&& (!(attr.st_mode & (S_IXUSR | S_IXGRP | S_IXOTH))
-	|| (!is_bin_cmd(tmp) && !(*tmp == '.' && *(tmp + 1) == '/')
+	|| (!is_bin_cmd(tmp) && !(*tmp == '.' && tmp[1] == '/')
 	&& *tmp != '/' ) ) )
 		return auto_open_file(args, tmp);
 
@@ -1444,20 +1419,19 @@ Inaccessible files:          %zu\n\
 }
 
 static int
-trash_func(char **args, int *_cont)
+trash_func(char **args, int *t_cont)
 {
 #ifndef _NO_TRASH
 	if (args[1] && IS_HELP(args[1])) {
 		puts(_(TRASH_USAGE));
-		*_cont = 0;
+		*t_cont = 0;
 		return FUNC_SUCCESS;
 	}
 
 	int exit_status = trash_function(args);
 
 	if (is_sel && sel_n > 0) { /* If 'tr sel', deselect everything */
-		int i = (int)sel_n;
-		while (--i >= 0)
+		for (size_t i = sel_n; i-- > 0;)
 			free(sel_elements[i].name);
 		sel_n = 0;
 		if (save_sel() != 0)
@@ -1468,18 +1442,18 @@ trash_func(char **args, int *_cont)
 #else
 	UNUSED(args);
 	xerror(_("%s: trash: %s\n"), PROGRAM_NAME, _(NOT_AVAILABLE));
-	*_cont = 0;
+	*t_cont = 0;
 	return FUNC_FAILURE;
 #endif /* !_NO_TRASH */
 }
 
 static int
-untrash_func(char **args, int *_cont)
+untrash_func(char **args, int *u_cont)
 {
 #ifndef _NO_TRASH
 	if (args[1] && IS_HELP(args[1])) {
 		puts(_(UNTRASH_USAGE));
-		*_cont = 0;
+		*u_cont = 0;
 		return FUNC_SUCCESS;
 	}
 
@@ -1493,7 +1467,7 @@ untrash_func(char **args, int *_cont)
 #else
 	UNUSED(args);
 	xerror("%s: trash: %s\n", PROGRAM_NAME, _(NOT_AVAILABLE));
-	*_cont = 0;
+	*u_cont = 0;
 	return FUNC_FAILURE;
 #endif /* !_NO_TRASH */
 }
@@ -1595,7 +1569,7 @@ static void
 check_zombies(void)
 {
 	int status = 0;
-	if (waitpid(-1, &status, WNOHANG) > 0)
+	if (waitpid(-1, &status, WNOHANG) > 0 && zombies > 0)
 		zombies--;
 }
 
@@ -1716,8 +1690,7 @@ unset_function(char **var)
 	}
 
 	int status = FUNC_SUCCESS;
-	size_t i;
-	for (i = 0; var[i]; i++) {
+	for (size_t i = 0; var[i]; i++) {
 		if (unsetenv(var[i]) == -1) {
 			status = errno;
 			xerror("unset: '%s': %s\n", var[i], strerror(errno));
@@ -1804,30 +1777,6 @@ run_log_cmd(char **args)
 	return FUNC_FAILURE;
 }
 
-#ifdef GENERIC_FS_MONITOR
-/* Update the current list of files if the modification time of the current
- * directory changed and if the number of files differ. Sometimes, processes
- * create temporary files (changing modification time) that are immediately
- * deleted (resulting in the same number of files), in which case there is no
- * need to update the list of files (this happens for example with 'git pull',
- * or with a command along the lines of 'touch file && rm file'). */
-static void
-check_fs_changes(void)
-{
-	if (!workspaces || cur_ws < 0 || cur_ws >= MAX_WS
-	|| !workspaces[cur_ws].path)
-		return;
-
-	const filesn_t cur_files = count_dir(workspaces[cur_ws].path, 0) - 2;
-	struct stat a;
-
-	if (curdir_mtime != 0 && stat(workspaces[cur_ws].path, &a) != -1
-	&& curdir_mtime != a.st_mtime
-	&& cur_files >= 0 && files != cur_files)
-		reload_dirlist();
-}
-#endif /* GENERIC_FS_MONITOR */
-
 /* Check the command CMD against a list of commands able to modify the
  * filesystem. Return 1 if CMD is found in the list or zero otherwise. */
 static int
@@ -1860,9 +1809,8 @@ is_write_cmd(const char *cmd)
 		wcmds_n = (sizeof(wcmds) / sizeof(wcmds[0])) - 1;
 
 	const size_t clen = strlen(cmd);
-	int i = (int)wcmds_n;
 
-	while (--i >= 0) {
+	for (size_t i = wcmds_n; i-- > 0;) {
 		if (clen == wcmds[i].len && *cmd == *wcmds[i].name
 		&& strcmp(cmd + 1, wcmds[i].name + 1) == 0) {
 			xerror(_("%s: %s: Command not allowed in read-only mode\n"),
@@ -2114,17 +2062,17 @@ exec_cmd(char **args)
 	/*         ############# (UN)TRASH ##################     */
 	else if (*args[0] == 't' && (!args[0][1]
 	|| strcmp(args[0], "trash") == 0)) {
-		int _cont = 1;
-		exit_code = trash_func(args, &_cont);
-		if (_cont == 0)
+		int t_cont = 1;
+		exit_code = trash_func(args, &t_cont);
+		if (t_cont == 0)
 			return exit_code;
 	}
 
 	else if (*args[0] == 'u' && (!args[0][1] || strcmp(args[0], "undel") == 0
 	|| strcmp(args[0], "untrash") == 0)) {
-		int _cont = 1; /* Tells whether to continue or return right here */
-		exit_code = untrash_func(args, &_cont);
-		if (_cont == 0)
+		int u_cont = 1; /* Tells whether to continue or return right here */
+		exit_code = untrash_func(args, &u_cont);
+		if (u_cont == 0)
 			return exit_code;
 	}
 
@@ -2477,19 +2425,7 @@ exec_cmd(char **args)
 	}
 
 CHECK_EVENTS:
-	if (conf.autols == 0 || (is_internal_command == 0
-	&& conf.clear_screen == CLEAR_INTERNAL_CMD_ONLY))
-		return exit_code;
-
-#if defined(LINUX_INOTIFY)
-	if (watch)
-		read_inotify();
-#elif defined(BSD_KQUEUE)
-	if (watch && event_fd >= 0)
-		read_kqueue();
-#elif defined(GENERIC_FS_MONITOR)
-	check_fs_changes();
-#endif /* LINUX_INOTIFY */
+	check_fs_events(is_internal_command);
 
 	return exit_code;
 }
@@ -2608,8 +2544,8 @@ run_profile_line(char *cmd)
 	exec_cmd(cmds);
 	no_log = 0;
 
-	int i = (int)args_n + 1;
-	while (--i >= 0)
+	size_t i = args_n + 1;
+	for (; i-- > 0;)
 		free(cmds[i]);
 	free(cmds);
 
