@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* file_operations.c -- control multiple file operations */
@@ -48,6 +33,7 @@
 #include "misc.h"
 #include "navigation.h"
 #include "readline.h"
+#include "safe_names.h" /* validate_filename */
 #include "selection.h"
 #include "spawn.h"
 
@@ -69,31 +55,6 @@ struct rm_info {
 #endif /* __OpenBSD__ || __DragonFly__ || __HAIKU__ */
 };
 
-static char *const unsafe_name_msgs[] = {
-	"Starts with a dash (-): command option flags collision",
-	"Reserved (internal: MIME/file type expansion)",
-	"Reserved (internal: ELN/range expansion)",
-	"Reserved (internal: fastback expansion)",
-	"Reserved (internal: bookmarks, tags, and selected files constructs)",
-	"Reserved shell/system keyword",
-	"Contains control characters",
-	"Contains shell meta-characters",
-	"Too long",
-	"Contains characters not in the Portable Filename Character Set"
-};
-
-#ifdef _BE_POSIX
-# define PORTABLE_CHARSET "abcdefghijklmnopqrstuvwxyz\
-ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789.-_"
-
-/* Return 0 if NAME is a portable filename. Otherwise, return 1. */
-static int
-is_portable_filename(const char *name, const size_t len)
-{
-	return len > strspn(name, PORTABLE_CHARSET);
-}
-#endif /* _BE_POSIX */
-
 /* Print/set the file creation mode mask (umask). */
 int
 umask_function(const char *arg)
@@ -128,39 +89,6 @@ ERROR:
 	return FUNC_FAILURE;
 }
 
-#ifndef _NO_LIRA
-static int
-run_mime(char *file)
-{
-	if (!file || !*file)
-		return FUNC_FAILURE;
-
-	if (xargs.preview == 1 || xargs.open == 1)
-		goto RUN;
-
-	char *p = rl_line_buffer ? rl_line_buffer : (char *)NULL;
-
-	/* Convert ELN into filename (rl_line_buffer) */
-	if (p && *p >= '1' && *p <= '9') {
-		const filesn_t a = xatof(p);
-		if (a > 0 && a <= files && file_info[a - 1].name)
-			p = file_info[a - 1].name;
-	}
-
-	if (p && ( (*p == 'i' && (strncmp(p, "import", 6) == 0
-	|| strncmp(p, "info", 4) == 0))
-	|| (*p == 'o' && (p[1] == ' ' || strncmp(p, "open", 4) == 0)) ) ) {
-		char *cmd[] = {"mm", "open", file, NULL};
-		return mime_open(cmd);
-	}
-
-RUN: {
-	char *cmd[] = {"mm", file, NULL};
-	return mime_open(cmd);
-	}
-}
-#endif /* _NO_LIRA */
-
 /* Open a file via OPENER, if set, or via LIRA. If not compiled with
  * Lira support, fallback to open (Haiku), or xdg-open. Returns zero
  * on success or one on failure. */
@@ -172,7 +100,7 @@ open_file(char *file)
 
 	int ret = FUNC_SUCCESS;
 
-	if (conf.opener) {
+	if (conf.opener && *conf.opener) {
 		if (*conf.opener == 'g' && strcmp(conf.opener, "gio") == 0) {
 			char *cmd[] = {"gio", "open", file, NULL};
 			ret = launch_execv(cmd, FOREGROUND, E_NOFLAG);
@@ -182,7 +110,8 @@ open_file(char *file)
 		}
 	} else {
 #ifndef _NO_LIRA
-		ret = run_mime(file);
+		char *cmd[] = {"mime", "open", file, NULL};
+		ret = mime_open(cmd);
 #else
 		/* Fallback to (xdg-)open */
 # if defined(__HAIKU__)
@@ -223,10 +152,11 @@ xchmod(const char *file, const char *mode_str, const int flag)
 
 	const mode_t mode = (mode_t)strtol(mode_str, 0, 8);
 	if (fchmod(fd, mode) == -1) {
+		const int saved_errno = errno;
 		close(fd);
 		err(flag == 1 ? 'e' : 0, flag == 1 ? PRINT_PROMPT : NOPRINT_PROMPT,
-			"xchmod: '%s': %s\n", file, strerror(errno));
-		return errno;
+			"xchmod: '%s': %s\n", file, strerror(saved_errno));
+		return saved_errno;
 	}
 
 	close(fd);
@@ -306,6 +236,63 @@ ERROR:
 	return dir;
 }
 
+static char *
+construct_dup_destination(char *source, const char *dest_dir)
+{
+	if (strchr(source, '\\')) {
+		char *deq_str = unescape_str(source, 0);
+		if (!deq_str) {
+			xerror(_("dup: '%s': Error unescaping filename\n"), source);
+			return NULL;
+		}
+
+		/* An unescaped filename is always <= than the original filename,
+		 * so that there's no need to reallocate the buffer. */
+		xstrsncpy(source, deq_str, strlen(deq_str) + 1);
+		free(deq_str);
+	}
+
+	/* Use source as destination filename: source.copy, and, if already
+	 * exists, source.copy-n, where N is an integer greater than zero. */
+	const size_t source_len = strlen(source);
+	int rem_slash = 0;
+	if (source_len > 1 && source[source_len - 1] == '/') {
+		source[source_len - 1] = '\0';
+		rem_slash = 1;
+	}
+
+	char *tmp = strrchr(source, '/');
+	char *source_name = (tmp && tmp[1]) ? tmp + 1 : source;
+
+	char tmp_dest[PATH_MAX + 1];
+	if (*dest_dir == '/' && !dest_dir[1]) /* Root dir */
+		snprintf(tmp_dest, sizeof(tmp_dest), "/%s.copy", source_name);
+	else
+		snprintf(tmp_dest, sizeof(tmp_dest), "%s/%s.copy",
+			dest_dir, source_name);
+
+	char bk[PATH_MAX + 11];
+	xstrsncpy(bk, tmp_dest, sizeof(bk));
+	struct stat attr;
+	size_t suffix = 0;
+	while (lstat(bk, &attr) == 0) {
+		suffix++;
+		if (suffix > MAX_FILE_CREATION_TRIES) {
+			xerror(_("dup: Cannot create unique filename for '%s': max "
+				"attempts (%d) reached\n"), source, MAX_FILE_CREATION_TRIES);
+			return NULL;
+		}
+		snprintf(bk, sizeof(bk), "%s-%zu", tmp_dest, suffix);
+	}
+
+	char *dest = savestring(bk, strnlen(bk, sizeof(bk)));
+
+	if (rem_slash == 1)
+		source[source_len - 1] = '/';
+
+	return dest;
+}
+
 int
 dup_file(char **cmd)
 {
@@ -327,60 +314,17 @@ dup_file(char **cmd)
 	const int rsync_ok = is_cmd_in_path("rsync");
 	int exit_status = FUNC_SUCCESS;
 
-	size_t i;
-	for (i = 1; cmd[i]; i++) {
+	for (size_t i = 1; cmd[i]; i++) {
 		if (!cmd[i] || !*cmd[i])
 			continue;
 
-		/* 1. Construct filenames. */
+		/* Construct destination filename. */
 		char *source = cmd[i];
-		if (strchr(source, '\\')) {
-			char *deq_str = unescape_str(source, 0);
-			if (!deq_str) {
-				xerror(_("dup: '%s': Error unescaping filename\n"), source);
-				continue;
-			}
+		char *dest = construct_dup_destination(source, dest_dir);
+		if (!dest)
+			continue;
 
-			xstrsncpy(source, deq_str, strlen(deq_str) + 1);
-			free(deq_str);
-		}
-
-		/* Use source as destination filename: source.copy, and, if already
-		 * exists, source.copy-n, where N is an integer greater than zero. */
-		const size_t source_len = strlen(source);
-		int rem_slash = 0;
-		if (strcmp(source, "/") != 0 && source_len > 0
-		&& source[source_len - 1] == '/') {
-			source[source_len - 1] = '\0';
-			rem_slash = 1;
-		}
-
-		char *tmp = strrchr(source, '/');
-		char *source_name;
-
-		source_name = (tmp && *(tmp + 1)) ? tmp + 1 : source;
-
-		char tmp_dest[PATH_MAX + 1];
-		if (*dest_dir == '/' && !dest_dir[1]) /* Root dir */
-			snprintf(tmp_dest, sizeof(tmp_dest), "/%s.copy", source_name);
-		else
-			snprintf(tmp_dest, sizeof(tmp_dest), "%s/%s.copy",
-				dest_dir, source_name);
-
-		char bk[PATH_MAX + 11];
-		xstrsncpy(bk, tmp_dest, sizeof(bk));
-		struct stat attr;
-		size_t suffix = 1;
-		while (stat(bk, &attr) == FUNC_SUCCESS) {
-			snprintf(bk, sizeof(bk), "%s-%zu", tmp_dest, suffix);
-			suffix++;
-		}
-		char *dest = savestring(bk, strnlen(bk, sizeof(bk)));
-
-		if (rem_slash == 1)
-			source[source_len - 1] = '/';
-
-		/* 2. Run command. */
+		/* Run command. */
 		if (rsync_ok == 1) {
 			char *dup_cmd[] = {"rsync", "-aczvAXHS", "--progress", "--",
 				source, dest, NULL};
@@ -454,8 +398,7 @@ find_template(const char *name)
 	if (!file_templates)
 		return 0;
 
-	filesn_t i;
-	for (i = 0; file_templates[i]; i++) {
+	for (size_t i = 0; file_templates[i]; i++) {
 		if (*name == *file_templates[i]
 		&& strcmp(name, file_templates[i]) == 0)
 			return 1;
@@ -589,9 +532,8 @@ END:
 static void
 list_created_files(char **nfiles, const filesn_t nfiles_n)
 {
-	size_t i;
 	int file_in_cwd = 0;
-	filesn_t n = workspaces[cur_ws].path
+	const filesn_t n = workspaces[cur_ws].path
 		? count_dir(workspaces[cur_ws].path, NO_CPOP) - 2 : 0;
 
 	if (n > 0 && n > files)
@@ -600,7 +542,7 @@ list_created_files(char **nfiles, const filesn_t nfiles_n)
 	if (conf.autols == 1 && file_in_cwd == 1)
 		reload_dirlist();
 
-	for (i = 0; nfiles[i]; i++) {
+	for (size_t i = 0; nfiles[i]; i++) {
 		char *f = abbreviate_file_name(nfiles[i]);
 		char *p = f ? f : nfiles[i];
 		puts((*p == '.' && p[1] == '/' && p[2]) ? p + 2 : p);
@@ -612,163 +554,6 @@ list_created_files(char **nfiles, const filesn_t nfiles_n)
 		(size_t)nfiles_n);
 }
 
-static int
-is_range(const char *str)
-{
-	if (!str || !*str)
-		return 0;
-
-	char *dash = strchr(str, '-');
-	if (!dash)
-		return 0;
-
-	*dash = '\0';
-	if (is_number(str) && (!dash[1] || is_number(dash + 1))) {
-		*dash = '-';
-		return 1;
-	}
-
-	*dash = '-';
-	return 0;
-}
-
-static int
-print_val_err(const char *name, const int msg_type)
-{
-	printf("%s: %s\n", name, unsafe_name_msgs[msg_type]);
-	return 0;
-}
-
-/* Return 1 if NAME is a safe filename, or 0 if not.
- * See https://dwheeler.com/essays/fixing-unix-linux-filenames.html */
-static int
-is_valid_filename(const char *name)
-{
-	const char *n = name;
-	/* Trailing spaces were already removed (by get_newname()) */
-
-	/* Starting with dash */
-	if (*n == '-')
-		return print_val_err(name, UNSAFE_DASH);
-
-	/* Reserved keyword (internal: MIME type and file type expansions) */
-	if ((*n == '=' && n[1] >= 'a' && n[1] <= 'z' && !n[2]) || *n == '@')
-		return print_val_err(name, UNSAFE_MIME);
-
-	/* Reserved keyword (internal: bookmarks, tags, workspaces, and
-	 * selected files constructs) */
-	if (((*n == 'b' || *n == 's') && n[1] == ':')
-	|| strcmp(n, "sel") == 0)
-		return print_val_err(name, UNSAFE_BTS_CONST);
-
-	if ((*n == 't' || *n == 'w') && n[1] == ':' && n[2])
-		return print_val_err(name, UNSAFE_BTS_CONST);
-
-	/* Reserved (internal: ELN/range expansion) */
-	if ((*n > '0' && is_number(n)) || is_range(n))
-		return print_val_err(name, UNSAFE_ELN);
-
-	/* "~" or ".": Reserved keyword */
-	if ((*n == '~' || *n == '.') && !n[1])
-		return print_val_err(name, UNSAFE_SYS_KEY);
-
-	/* ".." or "./": Reserved keyword */
-	if (*n == '.' && (n[1] == '.' || n[1] == '/') && !n[2])
-		return print_val_err(name, UNSAFE_SYS_KEY);
-
-	int only_dots = 1;
-	const char *s = name;
-	while (*s) {
-		/* Contains control characters (being not UTF-8 bytes) */
-		if (*s < ' ' && !IS_UTF8_CHAR(*s))
-			return print_val_err(name, UNSAFE_CONTROL);
-
-		/* Contains shell meta-characters */
-		if (strchr("*?[]<>|(){}&=`^!\\;$", *s))
-			return print_val_err(name, UNSAFE_META);
-
-		/* Only dots: Reserved keyword (internal: fastback expansion) */
-		if (*s != '.')
-			only_dots = 0;
-
-		s++;
-	}
-
-	if (only_dots == 1)
-		return print_val_err(name, UNSAFE_FASTBACK);
-
-	/* Name too long */
-	if (s - name >= NAME_MAX)
-		return print_val_err(name, UNSAFE_TOO_LONG);
-
-#ifdef _BE_POSIX
-	if (is_portable_filename(name, (size_t)(s - name)) != FUNC_SUCCESS)
-		return print_val_err(name, UNSAFE_NOT_PORTABLE);
-#endif /* _BE_POSIX */
-
-	return 1;
-}
-
-/* Return 0 if the file path NAME (or any component in it) does not exist and
- * is an invalid name. Otherwise, it returns 1.
- * If NAME is escaped, it is replaced by the unescaped name. */
-static int
-validate_filename(char **name, const int is_md)
-{
-	if (!*name || !*(*name))
-		return 0;
-
-	char *deq = unescape_str(*name, 0);
-	if (!deq) {
-		xerror(_("%s: '%s': Error unescaping filename\n"),
-			is_md ? "md" : "new", *name);
-		return 0;
-	}
-
-	free(*name);
-	*name = deq;
-
-	/* Skip initial slash and "~/" */
-	char *tmp = *deq != '/' ? deq : deq + 1;
-	if (*tmp == '~' && tmp[1] == '/' && tmp[2])
-		tmp += 2;
-
-	char *p = tmp, *q = tmp;
-	struct stat a;
-	int ret = 1;
-
-	while (1) {
-		if (!*q) { /* Basename */
-			if (lstat(deq, &a) == -1)
-				ret = is_valid_filename(p);
-			break;
-		}
-
-		if (*q != '/')
-			goto NEXT;
-
-		/* Path component */
-		*q = '\0';
-
-		if (lstat(deq, &a) == -1 && (ret = is_valid_filename(p)) == 0) {
-			*q = '/';
-			break;
-		}
-
-		*q = '/';
-
-		if (!q[1])
-			break;
-
-		p = q + 1;
-
-NEXT:
-		++q;
-	}
-
-	return ret;
-}
-
 static int
 format_new_filename(char **name)
 {
@@ -883,7 +668,6 @@ create_files(char **args, const int is_md)
 	}
 
 	int exit_status = FUNC_SUCCESS;
-	size_t i;
 
 	/* If no argument provided, ask the user for a filename, create it and exit. */
 	if (!args[0])
@@ -898,7 +682,7 @@ create_files(char **args, const int is_md)
 	char **new_files = xnmalloc(argsn + 1, sizeof(char *));
 	filesn_t new_files_n = 0;
 
-	for (i = 0; args[i]; i++) {
+	for (size_t i = 0; args[i]; i++) {
 		if (validate_filename(&args[i], is_md) == 0) {
 			xerror(_("%s: '%s': Unsafe filename\n"),
 				is_md ? "md" : "new", args[i]);
@@ -951,8 +735,7 @@ create_dirs(char **args)
 
 	/* Append an ending slash to all names, so that create_files() will create
 	 * them all as directories. */
-	size_t i;
-	for (i = 0; args[i]; i++) {
+	for (size_t i = 0; args[i]; i++) {
 		const size_t len = strlen(args[i]);
 		if (len > 0 && args[i][len - 1] == '/')
 			continue;
@@ -984,6 +767,55 @@ err_no_link(const char *file)
 	return saved_errno;
 }
 
+static const char *
+get_file_type_str(const int file_type)
+{
+	switch (file_type) {
+	case OPEN_BLK:  return "block device";
+	case OPEN_CHR:  return "character device";
+#ifdef __sun
+	case OPEN_DOOR: return "door";
+#endif /* __sun */
+	case OPEN_FIFO: return "FIFO/pipe";
+	case OPEN_SOCK: return "socket";
+	default:        return "unknown file type";
+	};
+}
+
+static int
+get_file_type(const mode_t mode, const char *filename)
+{
+	switch ((mode & S_IFMT)) {
+	case S_IFBLK:  return OPEN_BLK;
+	case S_IFCHR:  return OPEN_CHR;
+	case S_IFSOCK: return OPEN_SOCK;
+	case S_IFIFO:  return OPEN_FIFO;
+#ifdef __sun
+	case S_IFDOOR: return OPEN_DOOR;
+#endif /* __sun */
+	case S_IFDIR:  return OPEN_DIR;
+	case S_IFREG:  return OPEN_REG;
+
+	case S_IFLNK:
+		switch (get_link_ref(filename)) {
+		case -1:       return OPEN_LINK_ERR;
+		case S_IFDIR:  return OPEN_DIR;
+		case S_IFREG:  return OPEN_REG;
+		case S_IFBLK:  return OPEN_BLK;
+		case S_IFCHR:  return OPEN_CHR;
+		case S_IFSOCK: return OPEN_SOCK;
+		case S_IFIFO:  return OPEN_FIFO;
+#ifdef __sun
+		case S_IFDOOR: return OPEN_DOOR;
+#endif /* __sun */
+		default:       return OPEN_UNKNOWN;
+		}
+		break;
+
+	default: return OPEN_UNKNOWN;
+	}
+}
+
 int
 open_function(char **cmd)
 {
@@ -997,18 +829,16 @@ open_function(char **cmd)
 
 	const char *const errname = "open";
 
-	if (*cmd[0] == 'o' && (!cmd[0][1] || strcmp(cmd[0], "open") == 0)) {
-		if (strchr(cmd[1], '\\')) {
-			char *deq_path = unescape_str(cmd[1], 0);
-			if (!deq_path) {
-				xerror(_("%s: '%s': Error unescaping filename\n"),
-					errname, cmd[1]);
-				return FUNC_FAILURE;
-			}
-
-			xstrsncpy(cmd[1], deq_path, strlen(deq_path) + 1);
-			free(deq_path);
+	if ((*cmd[0] == 'o' && (!cmd[0][1] || strcmp(cmd[0], "open") == 0))
+	&& strchr(cmd[1], '\\')) {
+		char *deq_path = unescape_str(cmd[1], 0);
+		if (!deq_path) {
+			xerror(_("%s: '%s': Error unescaping filename\n"), errname, cmd[1]);
+			return FUNC_FAILURE;
 		}
+
+		xstrsncpy(cmd[1], deq_path, strlen(deq_path) + 1);
+		free(deq_path);
 	}
 
 	char *file = cmd[1];
@@ -1023,55 +853,16 @@ open_function(char **cmd)
 
 	/* Check file type: only directories, symlinks, and regular files
 	 * will be opened. */
-	char no_open_file = 1;
-	const char *file_type = (char *)NULL;
-	const char *const types[] = {
-		"block device",
-		"character device",
-		"socket",
-		"FIFO/pipe",
-		"unknown file type",
-#ifdef __sun
-		"door",
-#endif /* __sun */
-		NULL};
+	const int file_type = get_file_type(attr.st_mode, file);
 
-	switch ((attr.st_mode & S_IFMT)) {
-	/* Store file type to compose and print the error message, if necessary. */
-	case S_IFBLK: file_type = types[OPEN_BLK]; break;
-	case S_IFCHR: file_type = types[OPEN_CHR]; break;
-	case S_IFSOCK: file_type = types[OPEN_SOCK]; break;
-	case S_IFIFO: file_type = types[OPEN_FIFO]; break;
-#ifdef __sun
-	case S_IFDOOR: file_type = types[OPEN_DOOR]; break;
-#endif /* __sun */
-	case S_IFDIR: return cd_function(file, CD_PRINT_ERROR);
-
-	case S_IFLNK:
-		switch (get_link_ref(file)) {
-		case -1: return err_no_link(file);
-		case S_IFDIR: return cd_function(file, CD_PRINT_ERROR);
-		case S_IFREG: no_open_file = 0; break;
-		case S_IFBLK: file_type = types[OPEN_BLK]; break;
-		case S_IFCHR: file_type = types[OPEN_CHR]; break;
-		case S_IFSOCK: file_type = types[OPEN_SOCK]; break;
-		case S_IFIFO: file_type = types[OPEN_FIFO]; break;
-#ifdef __sun
-		case S_IFDOOR: file_type = types[OPEN_DOOR]; break;
-#endif /* __sun */
-		default: file_type = types[OPEN_UNKNOWN]; break;
-		}
-		break;
-
-	case S_IFREG: no_open_file = 0;	break;
-	default: file_type = types[OPEN_UNKNOWN]; break;
-	}
-
-	/* If neither directory nor regular file nor symlink (to directory
-	 * or regular file), print the corresponding error message and exit. */
-	if (no_open_file == 1) {
+	switch (file_type) {
+	case OPEN_DIR: return cd_function(file, CD_PRINT_ERROR);
+	case OPEN_LINK_ERR: return err_no_link(file);
+	case OPEN_REG: break;
+	default:
 		xerror(_("%s: '%s' (%s): Cannot open file\nTry "
-			"'APP FILE' or 'open FILE APP'\n"), errname, cmd[1], file_type);
+			"'APP FILE' or 'open FILE APP'\n"), errname, file,
+			get_file_type_str(file_type));
 		return FUNC_FAILURE;
 	}
 
@@ -1401,11 +1192,16 @@ symlink_file(char **args)
 		char *p = strrchr(target, '/');
 		snprintf(tmp, sizeof(tmp), "%s.link", (p && p[1]) ? p + 1 : target);
 
-		int suffix = 1;
-		while (lstat(tmp, &a) == 0 && suffix < INT_MAX) {
-			snprintf(tmp, sizeof(tmp), "%s.link-%d",
-				(p && p[1]) ? p + 1 : target, suffix);
+		size_t suffix = 0;
+		while (lstat(tmp, &a) == 0) {
 			suffix++;
+			if (suffix > MAX_FILE_CREATION_TRIES) {
+				xerror(_("link: Cannot create symbolic link to '%s': max "
+					"attempts (%d) reached\n"), target, MAX_FILE_CREATION_TRIES);
+				return FUNC_FAILURE;
+			}
+			snprintf(tmp, sizeof(tmp), "%s.link-%zu",
+				(p && p[1]) ? p + 1 : target, suffix);
 		}
 
 		link_name = tmp;
@@ -1646,6 +1442,15 @@ get_rename_dest_filename(char *name, int *status)
 		return (char *)NULL;
 	}
 
+	if (validate_filename(&new_name, 0) == 0) {
+		xerror(_("m: '%s': Unsafe filename\n"), new_name);
+		if (rl_get_y_or_n(_("Continue?"), 0) == 0) {
+			*status = FUNC_SUCCESS;
+			free(new_name);
+			return NULL;
+		}
+	}
+
 	return new_name;
 }
 
@@ -1732,10 +1537,16 @@ check_overwrite(char **args, const int force, size_t *skipped)
 	const int append_curdir = (sel_is_last == 1 && sel_n > 0);
 	const size_t files_num = args_n + (append_curdir == 1);
 
+	const char *cmd_name = IS_MVCMD(args[0]) ? "m" : "c";
+	if (append_curdir == 0 && validate_filename(&args[args_n], 0) == 0) {
+		xerror(_("%s: '%s': Unsafe filename\n"), cmd_name, args[args_n]);
+		if (rl_get_y_or_n(_("Continue?"), 0) == 0)
+			return 0;
+	}
+
 	if (!args || files_num <= 1 || force == 1)
 		return 1;
 
-	const char *cmd_name = IS_MVCMD(args[0]) ? "m" : "c";
 	const char *dest = append_curdir == 1 ? "." : args[args_n];
 
 	struct stat a;
@@ -1747,12 +1558,11 @@ check_overwrite(char **args, const int force, size_t *skipped)
 
 	char msg[PATH_MAX + 28];
 	char buf[PATH_MAX + 1];
-	size_t i;
 	const size_t dest_len = strlen(dest);
 	const int ends_with_slash =
 		(dest_len > 1 && dest[dest_len - 1] == '/');
 
-	for (i = 1; i < files_num; i++) {
+	for (size_t i = 1; i < files_num; i++) {
 		char *p = unescape_str(args[i], 0);
 		if (!p)
 			continue;
@@ -1791,8 +1601,7 @@ remove_dirslash_from_source(char **args)
 	if (args_n <= 1)
 		return;
 
-	size_t i;
-	for (i = 1; i < args_n; i++) {
+	for (size_t i = 1; i < args_n; i++) {
 		if (!args[i])
 			break;
 		if (!*args[i])
@@ -1855,8 +1664,7 @@ cp_mv_file(char **args, const int copy_and_rename, const int force)
 
 	ret = launch_execv(tcmd, FOREGROUND, E_NOFLAG);
 
-	size_t i;
-	for (i = 0; tcmd[i]; i++)
+	for (size_t i = 0; tcmd[i]; i++)
 		free(tcmd[i]);
 	free(tcmd);
 
@@ -1937,10 +1745,9 @@ static int
 rm_confirm(const struct rm_info *info, const size_t start, const int have_dirs)
 {
 	printf(_("File(s) to be removed%s:\n"),
-		have_dirs == 1 ? _(" (recursively)") : "");
+		have_dirs > 0 ? _(" (recursively)") : "");
 
-	size_t i;
-	for (i = start; info[i].name; i++)
+	for (size_t i = start; info[i].name; i++)
 		print_file_name(info[i].name, info[i].dir);
 
 	return rl_get_y_or_n(_("Continue?"), conf.default_answer.remove);
@@ -1951,10 +1758,9 @@ check_rm_files(const struct rm_info *info, const size_t start,
 	const char *errname)
 {
 	struct stat a;
-	size_t i;
 	int ret = FUNC_SUCCESS;
 
-	for (i = start; info[i].name; i++) {
+	for (size_t i = start; info[i].name; i++) {
 		if (lstat(info[i].name, &a) == -1)
 			continue;
 
@@ -2118,7 +1924,6 @@ export_files(char **filenames, const int open)
 		return (char *)NULL;
 	}
 
-	size_t i;
 	FILE *fp = fdopen(fd, "w");
 	if (!fp) {
 		xerror("exp: '%s': %s\n", tmp_file, strerror(errno));
@@ -2132,7 +1937,7 @@ export_files(char **filenames, const int open)
 	/* If no argument, export files in CWD. */
 	if (!filenames[1]) {
 		char buf[PATH_MAX + 1];
-		for (i = 0; file_info[i].name; i++) {
+		for (size_t i = 0; file_info[i].name; i++) {
 			char *name = file_info[i].name;
 			if (virtual_dir == 1) {
 				*buf = '\0';
@@ -2148,7 +1953,7 @@ export_files(char **filenames, const int open)
 			fprintf(fp, "%s\n", name);
 		}
 	} else {
-		for (i = 1; filenames[i]; i++) {
+		for (size_t i = 1; filenames[i]; i++) {
 			if (SELFORPARENT(filenames[i]))
 				continue;
 
@@ -2182,11 +1987,10 @@ batch_link(char **args)
 		return FUNC_SUCCESS;
 	}
 
-	size_t i;
 	size_t symlinked = 0;
 	int exit_status = FUNC_SUCCESS;
 
-	for (i = 0; args[i]; i++) {
+	for (size_t i = 0; args[i]; i++) {
 		char *filename = unescape_str(args[i], 0);
 		if (!filename) {
 			exit_status = FUNC_FAILURE;
