@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* help.c -- home of clifm's help system */
@@ -221,9 +206,8 @@ print_tips(const int all)
 	const size_t tipsn = (sizeof(TIPS) / sizeof(TIPS[0])) - 1;
 
 	if (all == 1) {
-		size_t i;
 		const int l = DIGINUM(tipsn);
-		for (i = 0; i < tipsn; i++) {
+		for (size_t i = 0; i < tipsn; i++) {
 			printf("%s%sTIP %*zu%s: %s\n",
 				conf.colorize == 1 ? df_c : "", conf.colorize == 1 ? BOLD : "",
 				l, i, conf.colorize == 1 ? df_c : "", TIPS[i]);
