@@ -2,24 +2,8 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2026 L. Abramovich <leo.clifm@outlook.com>
 */
-
 /* helpers.h -- main header file */
 
 #ifndef HELPERS_H
@@ -28,8 +12,8 @@
 #define PROGRAM_NAME_UPPERCASE "Clifm"
 #define PROGRAM_NAME "clifm"
 #define PROGRAM_DESC "The command line file manager"
-#define VERSION "1.26.3"
-#define DATE "Sep 28, 2025"
+#define VERSION "1.27"
+#define DATE "Jan 7, 2026"
 #define AUTHOR "L. Abramovich"
 #define CONTACT "https://github.com/leo-arch/clifm"
 #define LICENSE "GPL2+"
@@ -516,6 +500,9 @@ extern time_t curdir_mtime;
 #define MAX_TRASH     INT_MAX
 #define MAX_BOOKMARKS INT_MAX
 
+/* File creation attempt limit (e.g. tmp dir, dup file, or trashed file) */
+#define MAX_FILE_CREATION_TRIES 1000
+
 /* Max length of a file size in human format */
 #define MAX_HUMAN_SIZE 10 /* "1023.99YB\0" */
 
@@ -595,6 +582,12 @@ extern time_t curdir_mtime;
 #define PAGER_LONG  1
 #define PAGER_SHORT 2
 
+/* Values for SafeFilenames (conf.safe_filenames) */
+#define SAFENAMES_NOCHECK 0 /* The check is disabled */
+#define SAFENAMES_BASIC   1 /* Only basic checks are performed */
+#define SAFENAMES_STRICT  2 /* Shell metacharacters are disallowed */
+#define SAFENAMES_POSIX   3 /* Only characters in the Portable Character Set are allowed */
+
 /* ClearScreen=internal: clear screen only if command is internal */
 #define CLEAR_INTERNAL_CMD_ONLY 2
 
@@ -655,7 +648,7 @@ extern time_t curdir_mtime;
 
 /* Macros for the update_autocmd_opts() function */
 #define AC_COLOR_SCHEME  0
-#define AC_FILES_COUNTER 1
+#define AC_FILE_COUNTER  1
 #define AC_FILTER        2
 #define AC_FULL_DIR_SIZE 3
 #define AC_LIGHT_MODE    4
@@ -904,6 +897,7 @@ extern time_t curdir_mtime;
 #define JUMP_ENTRY_PERMANENT_CHR '+'
 
 #define MAX_TIME_STR 256
+#define MAX_NAMELEN_AUTO (-2) /* Macro for MaxFilenameLen=auto */
 
 #define SHADE_TYPE_UNSET     0
 #define SHADE_TYPE_8COLORS   1
@@ -1051,39 +1045,6 @@ extern time_t curdir_mtime;
 #define IS_HELP(s) (*(s) == '-' && (((s)[1] == 'h' && !(s)[2]) \
 	|| strcmp((s), "--help") == 0))
 
-/* Get the maximum value for a given data type.
- * Taken from coreutils (https://github.com/coreutils/gnulib/blob/master/lib/intprops.h) */
-/*
-#include <limits.h> // CHAR_BIT
-#define TYPE_SIGNED(t)  (!((t)0 < (t)-1))
-#define TYPE_WIDTH(t)   (sizeof(t) * CHAR_BIT)
-#define TYPE_MAXIMUM(t)                                   \
-        ((t)(!TYPE_SIGNED(t)                              \
-        ? (t)-1                                           \
-        : ((((t)1 << (TYPE_WIDTH(t) - 2)) - 1) * 2 + 1)))
-
-// Safely cast the number N to the type T. The type T is never overflowed:
-// if N is bigger than what T can hold, the maximum value T can hold is
-// returned. What about underflow?
-#define SAFECAST(n, t) ((t)(n) < 0 ? TYPE_MAXIMUM(t) : (t)(n)) */
-
-/*
-// See https://bestasciitable.com
-#define __CTRL(n) ((n) & ~(1 << 6)) // Just unset (set to zero) the seventh bit
-#define ___CTRL(n) ((n) & 0x3f) // Same as __CTRL
-#define _SHIFT(n) ((n) & ~(1 << 5)) // Unset the sixth bit
-
-// As defined by readline. Explanation:
-// 0x1ff == 0011111
-// So, this bitwise AND operation: 'n & 0x1f', means: set to zero whatever
-// bits in N that are zero in 0x1f, that is, the sixth and seventh bits
-#define _CTRL(n)  ((n) & 0x1f)
-// As defined by readline: set to one the eight bit in N
-#define _META(n)  ((n) | 0x80)
-// E.g.: 'A' == 01000001
-//     ('A' | 0x80) == 11000001 == 193 == Á
- */
-
 				/** #########################
 				 *  #    GLOBAL VARIABLES   #
 				 *  ######################### */
@@ -1159,7 +1120,7 @@ struct config_t {
 	int dirhist_map;
 	int disk_usage;
 	int ext_cmd_ok;
-	int files_counter;
+	int file_counter;
 	int follow_symlinks;
 	int follow_symlinks_long;
 	int full_dir_size;
@@ -1183,6 +1144,7 @@ struct config_t {
 	int max_files;
 	int max_log;
 	int max_name_len;
+	int max_name_len_auto;
 	int max_name_len_bk;
 	int max_printselfiles;
 	int min_jump_rank;
@@ -1213,6 +1175,7 @@ struct config_t {
 	int relative_time;
 	int restore_last_path;
 	int rm_force;
+	int safe_filenames;
 	int search_strategy;
 	int share_selbox;
 	int show_hidden;
@@ -1233,9 +1196,9 @@ struct config_t {
 	int pad1; /* Keep the struct alignment */
 	int pad2;
 #endif /* !_NO_TRASH */
+	int umask_set; /* Value set from Umask in the config file */
 	int warning_prompt;
 	int welcome_message;
-	int pad3;
 };
 
 extern struct config_t conf;
@@ -1402,7 +1365,7 @@ struct maxes_t {
 	int id_group;
 	int id_user;
 	int inode;
-	int files_counter;
+	int file_counter;
 	int links;
 	int name;
 	int size;
@@ -1426,7 +1389,7 @@ struct autocmds_t {
 	char *pattern;
 	char *color_scheme;
 	char *cmd;
-	int files_counter;
+	int file_counter;
 	int full_dir_size;
 	int long_view;
 	int light_mode;
@@ -1447,7 +1410,7 @@ extern struct autocmds_t *autocmds;
 struct opts_t {
 	struct filter_t filter;
 	char *color_scheme;
-	int files_counter;
+	int file_counter;
 	int full_dir_size;
 	int light_mode;
 	int list_dirs_first;
@@ -1496,7 +1459,7 @@ struct param_t {
 	int disk_usage_analyzer;
 	int eln_use_workspace_color;
 	int ext_cmd_ok;
-	int files_counter;
+	int file_counter;
 	int follow_symlinks;
 	int follow_symlinks_long;
 	int full_dir_size;
@@ -2002,6 +1965,9 @@ extern size_t
 extern size_t *name_icons_hashes;
 extern size_t *dir_icons_hashes;
 extern size_t *ext_icons_hashes;
+#ifndef OLD_ICON_LOOKUP
+extern size_t *ext_table;
+#endif
 #endif /* !_NO_ICONS */
 
 extern pid_t own_pid;
