@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* history.c -- functions for the history system */
@@ -322,8 +307,7 @@ log_msg(char *msg_str, const int print_prompt, const int logme,
 
 	if (add_to_msgs_list == 1) {
 		msgs_n++;
-		messages = xnrealloc(messages, (size_t)(msgs_n + 1),
-			sizeof(struct pmsgs_t));
+		messages = xnrealloc(messages, msgs_n + 1, sizeof(struct pmsgs_t));
 		messages[msgs_n - 1].text = savestring(msg_str, msg_len);
 		messages[msgs_n - 1].read = 0;
 		messages[msgs_n].text = (char *)NULL;
@@ -414,9 +398,7 @@ reload_history(void)
 	history_truncate_file(hist_file, conf.max_hist);
 
 	/* Update the history array */
-	const int ret = get_history();
-
-	return ret;
+	return get_history();
 }
 
 static int
@@ -476,17 +458,16 @@ clear_history_func(char **args)
 static int
 print_history_list(const int timestamp)
 {
-	int n = DIGINUM(current_hist_n);
-	size_t i;
-	for (i = 0; i < current_hist_n; i++) {
+	int pad = DIGINUM(current_hist_n);
+	for (size_t i = 0; i < current_hist_n; i++) {
 		if (timestamp == 1 && history[i].date != -1) {
 			char tdate[MAX_TIME_STR];
 			gen_time_str(tdate, sizeof(tdate), history[i].date);
-			printf(" %s%-*zu%s %s%s%s %s\n", el_c, n, i + 1, df_c,
+			printf(" %s%-*zu%s %s%s%s %s\n", el_c, pad, i + 1, df_c,
 				conf.colorize == 1 ? "\x1b[0;2m" : "",
 				tdate, "\x1b[0m", history[i].cmd);
 		} else {
-			printf(" %s%-*zu%s %s\n", el_c, n, i + 1, df_c, history[i].cmd);
+			printf(" %s%-*zu%s %s\n", el_c, pad, i + 1, df_c, history[i].cmd);
 		}
 	}
 
@@ -496,20 +477,22 @@ print_history_list(const int timestamp)
 static int
 print_last_items(const char *str, const int timestamp)
 {
-	int num = atoi(str);
+	int x = atoi(str);
 
-	if (num < 0 || num > (int)current_hist_n)
-		num = (int)current_hist_n;
+	/* X won't be bigger than INT_MAX, so casting is safe. */
+	size_t num = x < 0 ? current_hist_n : (size_t)x;
 
-	int n = DIGINUM(current_hist_n);
-	size_t i;
-	for (i = current_hist_n - (size_t)num; i < current_hist_n; i++) {
+	if (num > current_hist_n)
+		num = current_hist_n;
+
+	int pad = DIGINUM(current_hist_n);
+	for (size_t i = current_hist_n - num; i < current_hist_n; i++) {
 		if (timestamp == 1 && history[i].date != -1) {
 			char tdate[MAX_TIME_STR];
 			gen_time_str(tdate, sizeof(tdate), history[i].date);
 			printf(" %s# %s%s\n", "\x1b[0;2m", tdate, "\x1b[0m");
 		}
-		printf(" %s%-*zu%s %s\n", el_c, n, i + 1, df_c, history[i].cmd);
+		printf(" %s%-*zu%s %s\n", el_c, pad, i + 1, df_c, history[i].cmd);
 	}
 
 	return FUNC_SUCCESS;
@@ -587,8 +570,7 @@ get_history(void)
 	if (current_hist_n == 0) { /* Coming from main() */
 		history = xcalloc(1, sizeof(struct history_t));
 	} else { /* Only true when comming from 'history clear' */
-		size_t i;
-		for (i = 0; history[i].cmd; i++)
+		for (size_t i = 0; history[i].cmd; i++)
 			free(history[i].cmd);
 		history = xnrealloc(history, 1, sizeof(struct history_t));
 		current_hist_n = 0;
@@ -646,8 +628,7 @@ add_to_cmdhist(char *cmd)
 
 	/* Remove trailing spaces from CMD */
 	size_t cmd_len = strlen(cmd);
-	int i = (int)cmd_len;
-	while (--i >= 0 && cmd[i] == ' ') {
+	for (size_t i = cmd_len; i-- > 0 && cmd[i] == ' ';) {
 		cmd[i] = '\0';
 		cmd_len--;
 	}
