@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* init.c -- functions controlling the program initialization */
@@ -85,8 +70,7 @@ void
 get_ext_mountpoints(void)
 {
 	if (ext_mnt) {
-		int i;
-		for (i = 0; ext_mnt[i].mnt_point; i++)
+		for (size_t i = 0; ext_mnt[i].mnt_point; i++)
 			free(ext_mnt[i].mnt_point);
 		free(ext_mnt);
 		ext_mnt = (struct ext_mnt_t *)NULL;
@@ -128,10 +112,9 @@ get_ext_mountpoints(void)
 void
 init_workspaces_opts(void)
 {
-	size_t i;
-	for (i = 0; i < MAX_WS; i++) {
+	for (size_t i = 0; i < MAX_WS; i++) {
 		workspace_opts[i].color_scheme = cur_cscheme;
-		workspace_opts[i].files_counter = conf.files_counter;
+		workspace_opts[i].file_counter = conf.file_counter;
 
 		workspace_opts[i].filter.str = filter.str
 			? savestring(filter.str, strlen(filter.str)) : (char *)NULL;
@@ -158,8 +141,7 @@ init_shades(void)
 	date_shades.type = SHADE_TYPE_UNSET;
 	size_shades.type = SHADE_TYPE_UNSET;
 
-	int i = NUM_SHADES;
-	while (--i >= 0) {
+	for (size_t i = NUM_SHADES; i-- > 0;) {
 		date_shades.shades[i] = (struct rgb_t){0};
 		size_shades.shades[i] = (struct rgb_t){0};
 	}
@@ -193,7 +175,7 @@ init_conf_struct(void)
 	conf.dirhist_map = UNSET;
 	conf.disk_usage = UNSET;
 	conf.ext_cmd_ok = UNSET;
-	conf.files_counter = UNSET;
+	conf.file_counter = UNSET;
 	conf.follow_symlinks = DEF_FOLLOW_SYMLINKS;
 	conf.follow_symlinks_long = DEF_FOLLOW_SYMLINKS_LONG;
 	conf.full_dir_size = UNSET;
@@ -225,6 +207,8 @@ init_conf_struct(void)
 	conf.max_log = DEF_MAX_LOG;
 	conf.max_jump_total_rank = DEF_MAX_JUMP_TOTAL_RANK;
 	conf.max_name_len = DEF_MAX_NAME_LEN;
+	conf.max_name_len_auto = (DEF_MAX_NAME_LEN == MAX_NAMELEN_AUTO)
+		? DEF_MAX_NAMELEN_AUTO_RATIO : UNSET;
 	conf.max_name_len_bk = 0;
 	conf.max_printselfiles = DEF_MAX_PRINTSEL;
 	conf.min_jump_rank = DEF_MIN_JUMP_RANK;
@@ -255,6 +239,7 @@ init_conf_struct(void)
 	conf.relative_time = DEF_RELATIVE_TIME;
 	conf.restore_last_path = UNSET;
 	conf.rm_force = DEF_RM_FORCE;
+	conf.safe_filenames = DEF_SAFE_FILENAMES;
 	conf.search_strategy = DEF_SEARCH_STRATEGY;
 	conf.share_selbox = UNSET;
 	conf.show_hidden = UNSET;
@@ -272,6 +257,7 @@ init_conf_struct(void)
 	conf.tr_as_rm = UNSET;
 	conf.trash_force = DEF_TRASH_FORCE;
 #endif /* !_NO_TRASH */
+	conf.umask_set = UNSET;
 	conf.warning_prompt = UNSET;
 	conf.welcome_message = UNSET;
 
@@ -393,8 +379,7 @@ set_prop_fields(const char *line)
 	prop_fields = (struct props_t){0};
 	prop_fields.len = 2; /* Two spaces between filename and props string */
 
-	size_t i;
-	for (i = 0; i < PROP_FIELDS_SIZE && line[i]; i++) {
+	for (size_t i = 0; i < PROP_FIELDS_SIZE && line[i]; i++) {
 		switch (line[i]) {
 		case 'B': prop_fields.blocks = 1; break;
 		case 'f': prop_fields.counter = 1; break;
@@ -507,8 +492,7 @@ void
 init_workspaces(void)
 {
 	workspaces = xnmalloc(MAX_WS, sizeof(struct ws_t));
-	int i = MAX_WS;
-	while (--i >= 0) {
+	for (size_t i = MAX_WS; i-- > 0;) {
 		workspaces[i].path = (char *)NULL;
 		workspaces[i].name = (char *)NULL;
 	}
@@ -610,8 +594,7 @@ is_secure_env(void)
 	if (!argv_bk)
 		return 0;
 
-	size_t i;
-	for (i = 0; argv_bk[i]; i++) {
+	for (size_t i = 0; argv_bk[i]; i++) {
 		if (*argv_bk[i] == '-'
 #ifndef _BE_POSIX
 		&& (strncmp(argv_bk[i], "--secure-", 9) == 0))
@@ -691,7 +674,7 @@ check_etc_shells(const char *file, const char *shells_file, int *tmp_errno)
 		if (*line != '/')
 			continue;
 
-		size_t len = strnlen(line, sizeof(line));
+		const size_t len = strnlen(line, sizeof(line));
 		if (len > 0 && line[len - 1] == '\n')
 			line[len - 1] = '\0';
 
@@ -976,9 +959,7 @@ load_tags(void)
  *
  * One of the drawbacks of this approach is that IT ONLY RETRIEVES NEW ENTRIES
  * BUT WON'T UPDATE EXISTING ONES with values coming from the second instance:
- * they're lost.
- *
-*/
+ * they're lost. */
 static void
 sync_jumpdb_with_dirhist(void)
 {
@@ -986,7 +967,6 @@ sync_jumpdb_with_dirhist(void)
 		return;
 
 	int i = dirhist_total_index;
-	size_t j = 0;
 
 	while (--i >= 0) {
 		if (!old_pwd[i] || !*old_pwd[i])
@@ -995,7 +975,7 @@ sync_jumpdb_with_dirhist(void)
 		const size_t old_pwd_len = strlen(old_pwd[i]);
 
 		int found = 0;
-		for (j = 0; j < jump_n; j++) {
+		for (size_t j = 0; j < jump_n; j++) {
 			if (!jump_db[j].path || !*jump_db[j].path
 			|| old_pwd[i][1] != jump_db[j].path[1]
 			|| old_pwd_len != jump_db[j].len
@@ -1315,8 +1295,7 @@ load_actions(void)
 
 	/* Free the actions struct array */
 	if (actions_n > 0) {
-		int i = (int)actions_n;
-		while (--i >= 0) {
+		for (size_t i = actions_n; i-- > 0;) {
 			free(usr_actions[i].name);
 			free(usr_actions[i].value);
 		}
@@ -1434,7 +1413,7 @@ load_remotes(void)
 			char *tmp = (char *)NULL;
 			if (*ret == '~')
 				tmp = tilde_expand(ret);
-			size_t mnt_len = tmp ? strlen(tmp) : ret_len;
+			const size_t mnt_len = tmp ? strlen(tmp) : ret_len;
 			remotes[n].mountpoint = xnrealloc(remotes[n].mountpoint,
 				mnt_len + 1, sizeof(char));
 			xstrsncpy(remotes[n].mountpoint, tmp ? tmp : ret, mnt_len + 1);
@@ -1447,7 +1426,7 @@ load_remotes(void)
 			if (remotes[n].mountpoint) {
 				char *rep = replace_substr(ret, "%m", remotes[n].mountpoint);
 				if (rep) {
-					size_t rep_len = strlen(rep);
+					const size_t rep_len = strlen(rep);
 					remotes[n].mount_cmd = xnrealloc(
 						remotes[n].mount_cmd, rep_len + 1, sizeof(char));
 					xstrsncpy(remotes[n].mount_cmd, rep, rep_len + 1);
@@ -1467,7 +1446,7 @@ load_remotes(void)
 			if (remotes[n].mountpoint) {
 				char *rep = replace_substr(ret, "%m", remotes[n].mountpoint);
 				if (rep) {
-					size_t rep_len = strlen(rep);
+					const size_t rep_len = strlen(rep);
 					remotes[n].unmount_cmd = xnrealloc(
 						remotes[n].unmount_cmd, rep_len + 1, sizeof(char));
 					xstrsncpy(remotes[n].unmount_cmd, rep, rep_len + 1);
@@ -1498,7 +1477,7 @@ load_remotes(void)
 	fclose(fp);
 
 	if (remotes[n].name) {
-		++n;
+		n++;
 		remotes[n].name = (char *)NULL;
 	}
 
@@ -1522,7 +1501,7 @@ set_prompts_file(void)
 
 	struct stat a;
 
-	size_t len = strlen(config_dir_gral) + 15;
+	const size_t len = strlen(config_dir_gral) + 15;
 	char *f = xnmalloc(len, sizeof(char));
 	snprintf(f, len, "%s/prompts.clifm", config_dir_gral);
 
@@ -1666,7 +1645,7 @@ load_prompts(void)
 				name = (char *)NULL;
 				continue;
 			}
-			size_t name_len = strlen(name);
+			const size_t name_len = strlen(name);
 			prompts[n].name = xnrealloc(prompts[n].name,
 				name_len + 1, sizeof(char));
 			xstrsncpy(prompts[n].name, name, name_len + 1);
@@ -1765,9 +1744,8 @@ set_sel_devino(void)
 	free(sel_devino);
 	sel_devino = xnmalloc(sel_n + 1, sizeof(struct devino_t));
 
-	size_t i;
 	struct stat a;
-	for (i = 0; i < sel_n; i++) {
+	for (size_t i = 0; i < sel_n; i++) {
 		const char *name = sel_elements[i].name;
 		if (fstatat(XAT_FDCWD, name, &a, AT_SYMLINK_NOFOLLOW) == -1)
 			continue;
@@ -1792,8 +1770,7 @@ get_sel_files(void)
 	const size_t selnbk = sel_n;
 	/* First, clear the sel array, in case it was already used. */
 	if (sel_n > 0) {
-		int i = (int)sel_n;
-		while (--i >= 0)
+		for (size_t i = sel_n; i-- > 0;)
 			free(sel_elements[i].name);
 	}
 	sel_n = 0;
@@ -1843,7 +1820,7 @@ get_sel_files(void)
 	if (sel_n > 0)
 		set_sel_devino();
 
-	/* If previous and current number of sel files don't match (mostly
+	/* If previous and current number of selected files don't match (mostly
 	 * because some selected files were removed), recreate the selections
 	 * file to reflect the current state. */
 	if (selnbk != sel_n)
@@ -1870,8 +1847,8 @@ get_cdpath(void)
 		return 0;
 
 	/* Get each path in CDPATH */
-	size_t i, n = 0, len = 0;
-	for (i = 0; t[i]; i++) {
+	size_t n = 0, len = 0;
+	for (size_t i = 0; t[i]; i++) {
 		/* Store path in CDPATH in a tmp buffer */
 		char buf[PATH_MAX + 1];
 		while (t[i] && t[i] != ':' && len < sizeof(buf) - 1) {
@@ -1906,8 +1883,7 @@ get_paths_timestamps(const size_t n)
 		return;
 
 	struct stat a;
-	int i = (int)n;
-	while (--i >= 0) {
+	for (size_t i = n; i-- > 0;) {
 		if (paths[i].path && *paths[i].path && stat(paths[i].path, &a) != -1)
 			paths[i].mtime = a.st_mtime;
 		else
@@ -1977,8 +1953,7 @@ get_path_env(const int check_timestamps)
 			}
 
 			/* Skip duplicate entries */
-			size_t i;
-			for (i = 0; i < n; i++) {
+			for (size_t i = 0; i < n; i++) {
 				if (strcmp(paths[i].path, p) == 0)
 					goto CONT;
 			}
@@ -2180,8 +2155,7 @@ skip_this_path(const char *name)
 	if (!rpath)
 		return 1;
 
-	size_t i;
-	for (i = 0; paths[i].path; i++) {
+	for (size_t i = 0; paths[i].path; i++) {
 		if (*paths[i].path && strcmp(paths[i].path, rpath) == 0) {
 			free(rpath);
 			return 1;
@@ -2192,7 +2166,7 @@ skip_this_path(const char *name)
 	return 0;
 }
 
-/* Get the list of files in PATH, plus CliFM internal commands, aliases, and
+/* Get the list of files in PATH, plus Clifm internal commands, aliases, and
  * action names, and store them in an array (bin_commands) to be read by
  * my_rl_completion(). */
 void
@@ -2201,7 +2175,9 @@ get_path_programs(void)
 	if (xargs.list_and_quit == 1)
 		return;
 
-	int i, l = 0, total_cmd = 0;
+	int total_cmd = 0;
+	size_t l = 0;
+	size_t i = 0;
 	int *cmd_n = (int *)0;
 	struct dirent ***commands_bin = (struct dirent ***)NULL;
 
@@ -2209,8 +2185,7 @@ get_path_programs(void)
 		commands_bin = xnmalloc(path_n, sizeof(struct dirent));
 		cmd_n = xnmalloc(path_n, sizeof(int));
 
-		i = (int)path_n;
-		while (--i >= 0) {
+		for (i = path_n; i-- > 0;) {
 			cmd_n[i] = 0;
 			commands_bin[i] = (struct dirent **)NULL;
 
@@ -2236,8 +2211,7 @@ get_path_programs(void)
 	bin_commands = xnmalloc((size_t)total_cmd
 		+ internal_cmds_n + aliases_n + actions_n + 2, sizeof(char *));
 
-	i = (int)internal_cmds_n;
-	while (--i >= 0) {
+	for (i = internal_cmds_n; i-- > 0;) {
 		bin_commands[l] = savestring(internal_cmds[i].name,
 			internal_cmds[i].len);
 		l++;
@@ -2245,8 +2219,7 @@ get_path_programs(void)
 
 	/* Now add aliases, if any */
 	if (aliases_n > 0) {
-		i = (int)aliases_n;
-		while (--i >= 0) {
+		for (i = aliases_n; i-- > 0;) {
 			bin_commands[l] = savestring(aliases[i].name,
 				strlen(aliases[i].name));
 			l++;
@@ -2255,8 +2228,7 @@ get_path_programs(void)
 
 	/* And user defined actions too, if any */
 	if (actions_n > 0) {
-		i = (int)actions_n;
-		while (--i >= 0) {
+		for (i = actions_n; i-- > 0;) {
 			bin_commands[l] = savestring(usr_actions[i].name,
 				strlen(usr_actions[i].name));
 			l++;
@@ -2265,13 +2237,11 @@ get_path_programs(void)
 
 	if (total_cmd > 0) {
 		/* And finally, add commands in PATH */
-		i = (int)path_n;
-		while (--i >= 0) {
+		for (i = path_n; i-- > 0;) {
 			if (cmd_n[i] <= 0 || !commands_bin[i])
 				continue;
 
-			int j = cmd_n[i];
-			while (--j >= 0) {
+			for (int j = cmd_n[i]; j-- > 0;) {
 #ifdef _DIRENT_HAVE_D_TYPE
 				if (SELFORPARENT(commands_bin[i][j]->d_name)
 				|| (commands_bin[i][j]->d_type != DT_REG
@@ -2300,16 +2270,14 @@ get_path_programs(void)
 
 	free(commands_bin);
 	free(cmd_n);
-	path_progsn = (size_t)l;
+	path_progsn = l;
 	bin_commands[l] = (char *)NULL;
 }
 
 static void
 free_aliases(void)
 {
-	int i = (int)aliases_n;
-
-	while (--i >= 0) {
+	for (size_t i = aliases_n; i-- > 0;) {
 		free(aliases[i].name);
 		free(aliases[i].cmd);
 	}
@@ -2346,9 +2314,7 @@ write_alias(const char *s, char *p)
 static int
 alias_exists(const char *s)
 {
-	int i = (int)aliases_n;
-
-	while (--i >= 0) {
+	for (size_t i = aliases_n; i-- > 0;) {
 		if (!aliases[i].name)
 			continue;
 		if (*s == *aliases[i].name && strcmp(s, aliases[i].name) == 0)
@@ -2385,7 +2351,7 @@ get_aliases(void)
 				continue;
 
 			char *p = strchr(s, '=');
-			if (!p || !*(p + 1))
+			if (!p || !p[1])
 				continue;
 
 			*p = '\0';
@@ -2465,8 +2431,7 @@ load_dirhist(void)
 static void
 free_prompt_cmds(void)
 {
-	size_t i;
-	for (i = 0; i < prompt_cmds_n; i++)
+	for (size_t i = 0; i < prompt_cmds_n; i++)
 		free(prompt_cmds[i]);
 	free(prompt_cmds);
 	prompt_cmds = (char **)NULL;
@@ -2499,7 +2464,7 @@ get_prompt_cmds(void)
 			continue;
 		if (line[line_len - 1] == '\n')
 			line[line_len - 1] = '\0';
-		if (!(*line + 10))
+		if (!line[10])
 			continue;
 		prompt_cmds = xnrealloc(prompt_cmds, prompt_cmds_n + 1, sizeof(char *));
 		prompt_cmds[prompt_cmds_n] = savestring(
@@ -2833,8 +2798,8 @@ check_options(void)
 	if (conf.show_hidden == UNSET)
 		conf.show_hidden = SETOPT(xargs.show_hidden, DEF_SHOW_HIDDEN);
 
-	if (conf.files_counter == UNSET)
-		conf.files_counter = SETOPT(xargs.files_counter, DEF_FILES_COUNTER);
+	if (conf.file_counter == UNSET)
+		conf.file_counter = SETOPT(xargs.file_counter, DEF_FILE_COUNTER);
 
 	if (conf.long_view == UNSET)
 		conf.long_view = SETOPT(xargs.long_view, DEF_LONG_VIEW);
