@@ -2,23 +2,8 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
- */
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
+*/
 
 /* jump.c -- functions for Kangaroo, the directory jumper function */
 
@@ -84,11 +69,12 @@ struct jump_entry_t {
  * its current rank. */
 static int
 calculate_base_credit(const int days_since_first, const int hours_since_last,
-	const int visits, int *keep)
+	const size_t visits, int *keep)
 {
+	const int ivisits = visits > INT_MAX ? INT_MAX : (int)visits;
 	int rank = days_since_first > 1
-		? ((int)visits * VISIT_BONUS) / days_since_first
-		: ((int)visits * VISIT_BONUS);
+		? (ivisits * VISIT_BONUS) / days_since_first
+		: (ivisits * VISIT_BONUS);
 
 	/* Credit or penalty based on last directory access. */
 	int tmp_rank = rank;
@@ -125,8 +111,7 @@ calculate_bonus_credit(const char *entry, const char *query, int *keep)
 			bonus += BASENAME_BONUS;
 	}
 
-	int i = (int)bm_n;
-	while (--i >= 0) {
+	for (size_t i = bm_n; i-- > 0;) {
 		if (bookmarks[i].path && *bookmarks[i].path
 		&& bookmarks[i].path[1] == entry[1]
 		&& strcmp(bookmarks[i].path, entry) == 0) {
@@ -142,8 +127,7 @@ calculate_bonus_credit(const char *entry, const char *query, int *keep)
 		bonus += PINNED_BONUS;
 	}
 
-	i = MAX_WS;
-	while (--i >= 0) {
+	for (size_t i = MAX_WS; i-- > 0;) {
 		if (workspaces[i].path && *workspaces[i].path
 		&& workspaces[i].path[1] == entry[1]
 		&& strcmp(workspaces[i].path, entry) == 0) {
@@ -162,7 +146,7 @@ calculate_bonus_credit(const char *entry, const char *query, int *keep)
  * "https://github.com/ajeetdsouza/zoxide/wiki/Algorithm#aging"
  * "https://github.com/skywind3000/z.lua#aging" */
 static int
-rank_entry(const int i, const time_t now, int *days_since_first,
+rank_entry(const size_t i, const time_t now, int *days_since_first,
 	int *hours_since_last)
 {
 	/* 86400 = 60 secs / 60 mins / 24 hours */
@@ -172,7 +156,7 @@ rank_entry(const int i, const time_t now, int *days_since_first,
 
 	int keep = 0;
 	int rank = calculate_base_credit(*days_since_first, *hours_since_last,
-		(int)jump_db[i].visits, &keep);
+		jump_db[i].visits, &keep);
 
 	rank += calculate_bonus_credit(jump_db[i].path, (char *)NULL, &keep);
 	if (jump_db[i].keep == JUMP_ENTRY_PERMANENT)
@@ -186,9 +170,7 @@ rank_entry(const int i, const time_t now, int *days_since_first,
 static void
 free_jump_database(void)
 {
-	int i = (int)jump_n;
-
-	while (--i >= 0)
+	for (size_t i = jump_n; i-- > 0;)
 		free(jump_db[i].path);
 
 	free(jump_db);
@@ -240,8 +222,8 @@ add_to_jumpdb(char *dir)
 		jump_n = 0;
 	}
 
-	int i = (int)jump_n, new_entry = 1;
-	while (--i >= 0) {
+	int new_entry = 1;
+	for (size_t i = jump_n; i-- > 0;) {
 		/* Jump entries are all absolute paths, so that they all start with
 		 * a slash. Let's start comparing them from the second char. */
 		if (!IS_VALID_JUMP_ENTRY(i) || dir_len != jump_db[i].len
@@ -278,12 +260,11 @@ save_jumpdb(void)
 	if (!fp)
 		return;
 
-	int i, reduce = 0, total_rank = 0;
+	int reduce = 0, total_rank = 0;
 	const time_t now = time(NULL);
 
 	/* Calculate both total rank sum, and rank for each entry. */
-	i = (int)jump_n;
-	while (--i >= 0) {
+	for (size_t i = jump_n; i-- > 0;) {
 		if (!IS_VALID_JUMP_ENTRY(i))
 			continue;
 
@@ -302,10 +283,10 @@ save_jumpdb(void)
 
 	char perm_chr_str[2] = "";
 
-	for (i = 0; i < (int)jump_n; i++) {
+	for (size_t i = 0; i < jump_n; i++) {
 		if (total_rank > conf.max_jump_total_rank) {
 			if (reduce) {
-				int tmp_rank = jump_db[i].rank;
+				const int tmp_rank = jump_db[i].rank;
 				jump_db[i].rank = tmp_rank / reduce;
 			}
 		}
@@ -393,9 +374,13 @@ save_jump_suggestion(const char *str)
 }
 
 static char *
-get_directory_color(const char *filename, const struct stat *a)
+get_directory_color(const char *filename)
 {
-	if (S_ISLNK(a->st_mode)) {
+	struct stat a;
+	if (lstat(filename, &a) == -1)
+		return uf_c;
+
+	if (S_ISLNK(a.st_mode)) {
 		char *linkname = xrealpath(filename, NULL);
 		if (linkname) {
 			free(linkname);
@@ -404,7 +389,7 @@ get_directory_color(const char *filename, const struct stat *a)
 		return or_c;
 	}
 
-	return get_dir_color(filename, a, -1);
+	return get_dir_color(filename, &a, -1);
 }
 
 /* Compare ranks A and B (used to sort jump entries by rank). */
@@ -426,8 +411,9 @@ rank_cmp(const void *a, const void *b)
 static void
 print_jump_table_header(void)
 {
-	char item[10]; /* BOLD and NC are 4 bytes each */
-	snprintf(item, sizeof(item), "%s*%s", conf.colorize == 1 ? BOLD : "", NC);
+	char item[16]; /* BOLD and NC are 4 bytes each */
+	snprintf(item, sizeof(item), "%s%s%s", BOLD,
+		term_caps.unicode == 1 ? "•" : "*", NC);
 
 	printf(_("%s First time access is displayed in days, while last "
 		"time access is displayed in hours.\n"), item);
@@ -449,8 +435,7 @@ print_jump_table_header(void)
 			"removed at program exit.\n"), item, conf.min_jump_rank);
 	}
 
-	printf(_("\n %sOrder\tVisits\tFirst\tLast\tRank\tDirectory%s\n"),
-		conf.colorize == 1 ? BOLD : "", NC);
+	printf(_("\n%sVisits\tFirst\tLast\tRank\tDirectory%s\n"), BOLD, NC);
 }
 
 /* Print the jump database, field by field, incuding the current rank.
@@ -470,21 +455,20 @@ print_jump_table(const int reduce, const time_t now)
 	HIDE_CURSOR;
 	print_jump_table_header();
 
-	size_t i;
-	int ranks_sum = 0, visits_sum = 0;
+	int ranks_sum = 0;
+	size_t visits_sum = 0;
 	int max_rank = 0, max_visits = 0, max_first = 0, max_last = 0;
-	const int max_order = DIGINUM(jump_n);
 
 	struct jump_t *tmp_jump = xnmalloc(jump_n + 1, sizeof(struct jump_t));
 
-	for (i = 0; i < jump_n; i++) {
+	for (size_t i = 0; i < jump_n; i++) {
 		if (!IS_VALID_JUMP_ENTRY(i)) {
 			tmp_jump[i].path = (char *)NULL;
 			continue;
 		}
 
 		int days_since_first = 0, hours_since_last = 0;
-		int rank = rank_entry((int)i, now, &days_since_first, &hours_since_last);
+		int rank = rank_entry(i, now, &days_since_first, &hours_since_last);
 
 		if (reduce) {
 			const int tmp_rank = rank;
@@ -492,7 +476,7 @@ print_jump_table(const int reduce, const time_t now)
 		}
 
 		ranks_sum += rank;
-		visits_sum += (int)jump_db[i].visits;
+		visits_sum += jump_db[i].visits;
 
 		tmp_jump[i].path = jump_db[i].path;
 		tmp_jump[i].keep = jump_db[i].keep;
@@ -520,7 +504,7 @@ print_jump_table(const int reduce, const time_t now)
 	/* Sort entries by rank (from less to more). */
 	qsort(tmp_jump, jump_n, sizeof(*tmp_jump), rank_cmp);
 
-	for (i = 0; i < jump_n; i++) {
+	for (size_t i = 0; i < jump_n; i++) {
 		if (!tmp_jump[i].path)
 			continue;
 
@@ -528,22 +512,16 @@ print_jump_table(const int reduce, const time_t now)
 		&& workspaces[cur_ws].path[1] == tmp_jump[i].path[1]
 		&& strcmp(workspaces[cur_ws].path, tmp_jump[i].path) == 0) ? mi_c : df_c;
 
-		struct stat a;
-		if (lstat(tmp_jump[i].path, &a) == -1)
-			color = uf_c;
-
-		const char *dir_color = color == uf_c ? uf_c
-			: get_directory_color(tmp_jump[i].path, &a);
+		const char *dir_color = get_directory_color(tmp_jump[i].path);
 		const int keep = tmp_jump[i].keep;
 		const char keep_char = keep == 1 ? '*'
 			: ((keep == JUMP_ENTRY_PERMANENT)
 			? JUMP_ENTRY_PERMANENT_CHR : 0);
 
-		printf(" %s%*zu\t%*zu\t%*d\t%*d\t%s%*d%s%s%c%s\t%c%s%s%s\n",
-			color != uf_c ? color : df_c, max_order, i + 1,
-			max_visits, tmp_jump[i].visits,
-			max_first, (int)tmp_jump[i].first_visit,
-			max_last, (int)tmp_jump[i].last_visit,
+		printf("%s%*zu\t%*jd\t%*jd\t%s%*d%s%s%c%s\t%c%s%s%s\n",
+			color != uf_c ? color : df_c, max_visits, tmp_jump[i].visits,
+			max_first, (intmax_t)tmp_jump[i].first_visit,
+			max_last, (intmax_t)tmp_jump[i].last_visit,
 		    conf.colorize == 1 ? BOLD : "", max_rank, tmp_jump[i].rank,
 		    color != uf_c ? color : "",
 		    keep == 1 ? li_c : (keep == 2 ? mi_c : ""),
@@ -555,7 +533,7 @@ print_jump_table(const int reduce, const time_t now)
 
 	free(tmp_jump);
 
-	printf(_("\nTotal rank: %d/%d\nTotal visits: %d\n"), ranks_sum,
+	printf(_("\nTotal rank: %d/%d\nTotal visits: %zu\n"), ranks_sum,
 	    conf.max_jump_total_rank, visits_sum);
 
 	UNHIDE_CURSOR;
@@ -565,11 +543,10 @@ print_jump_table(const int reduce, const time_t now)
 static int
 purge_invalid_entries(void)
 {
-	int i = (int)jump_n;
 	int c = 0;
 
 	struct stat a;
-	while (--i >= 0) {
+	for (size_t i = jump_n; i-- > 0;) {
 		if (!IS_VALID_JUMP_ENTRY(i))
 			continue;
 
@@ -596,11 +573,10 @@ purge_invalid_entries(void)
 static int
 purge_low_ranked_entries(const int limit)
 {
-	int i = (int)jump_n;
 	int c = 0;
 	const time_t now = time(NULL);
 
-	while (--i >= 0) {
+	for (size_t i = jump_n; i-- > 0;) {
 		if (!IS_VALID_JUMP_ENTRY(i))
 			continue;
 
@@ -741,7 +717,7 @@ rank_tmp_entry(const struct jump_entry_t *entry, const time_t now,
 
 	int keep = 0;
 	int rank = calculate_base_credit(days_since_first, hours_since_last,
-		(int)entry->visits, &keep);
+		entry->visits, &keep);
 
 	rank += calculate_bonus_credit(entry->match, query, &keep);
 	if (entry->keep == JUMP_ENTRY_PERMANENT)
@@ -838,13 +814,12 @@ dirjump(char **args, const int mode)
 		return ret;
 
 	/* Find the best ranked directory using ARGS as filter(s). */
-	size_t i;
-	int j, match = 0;
+	size_t j, match = 0;
 
 	struct jump_entry_t *entry =
 		xnmalloc(jump_n + 1, sizeof(struct jump_entry_t));
 
-	for (i = 1; args[i]; i++) {
+	for (size_t i = 1; args[i]; i++) {
 		/* 1) Using the first parameter, get a list of matches in the
 		 * database. */
 
@@ -855,8 +830,7 @@ dirjump(char **args, const int mode)
 		const int segment = mark_target_segment(args[i]);
 
 		if (match == 0) {
-			j = (int)jump_n;
-			while (--j >= 0) {
+			for (j = jump_n; j-- > 0;) {
 				if (!IS_VALID_JUMP_ENTRY(j))
 					continue;
 
@@ -912,8 +886,7 @@ dirjump(char **args, const int mode)
 		 * matching process, that is, excluding non-matches,
 		 * using subsequent parameters. */
 		else {
-			j = match;
-			while (--j >= 0) {
+			for (j = match; j-- > 0;) {
 				if (!entry[j].match || !*entry[j].match) {
 					entry[j].match = (char *)NULL;
 					continue;
@@ -940,9 +913,7 @@ dirjump(char **args, const int mode)
 	int found = 0, exit_status = FUNC_FAILURE, max = -1;
 	char *best_ranked = (char *)NULL;
 
-	j = match;
-
-	while (--j >= 0) {
+	for (j = match; j-- > 0;) {
 		if (!entry[j].match)
 			continue;
 
