@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* keybinds.c -- handle keybindings */
@@ -26,6 +11,7 @@
 
 #ifdef __OpenBSD__
 typedef char *rl_cpvfunc_t;
+typedef void rl_macro_print_func_t (const char *, const char *, int, const char *);
 # include <ereadline/readline/readline.h>
 #else
 # include <readline/readline.h>
@@ -317,8 +303,7 @@ check_clifm_kb(const char *kb, const char *func_name)
 {
 	int conflicts = 0;
 
-	size_t i;
-	for (i = 0; i < kbinds_n; i++) {
+	for (size_t i = 0; i < kbinds_n; i++) {
 		if (!kbinds[i].key || strcmp(kb, kbinds[i].key) != 0)
 			continue;
 
@@ -348,7 +333,6 @@ check_clifm_kb(const char *kb, const char *func_name)
 static int
 check_rl_kbinds(const char *kb)
 {
-	size_t i, j;
 	char *name = (char *)NULL;
 	char **names = (char **)rl_funmap_names();
 	int conflicts = 0;
@@ -356,13 +340,13 @@ check_rl_kbinds(const char *kb)
 	if (!names)
 		return FUNC_SUCCESS;
 
-	for (i = 0; (name = names[i]); i++) {
+	for (size_t i = 0; (name = names[i]); i++) {
 		rl_command_func_t *function = rl_named_function(name);
 		char **keys = rl_invoking_keyseqs(function);
 		if (!keys)
 			continue;
 
-		for (j = 0; keys[j]; j++) {
+		for (size_t j = 0; keys[j]; j++) {
 			if (kb == NULL) {
 				conflicts += check_clifm_kb(keys[j], name);
 			} else {
@@ -392,9 +376,8 @@ check_kbinds_conflict(void)
 	}
 
 	int ret = FUNC_SUCCESS;
-	size_t i, j;
-	for (i = 0; i < kbinds_n; i++) {
-		for (j = i + 1; j < kbinds_n; j++) {
+	for (size_t i = 0; i < kbinds_n; i++) {
+		for (size_t j = i + 1; j < kbinds_n; j++) {
 			if (strcmp(kbinds[i].key, kbinds[j].key) == 0) {
 				fprintf(stderr, _("kb: '%s' conflicts with '%s'\n"),
 					kbinds[i].function, kbinds[j].function);
@@ -416,12 +399,11 @@ find_key(const char *function)
 	if (kbinds_n == 0)
 		return (char *)NULL;
 
-	int n = (int)kbinds_n;
-	while (--n >= 0) {
-		if (*function != *kbinds[n].function)
+	for (size_t i = kbinds_n; i-- > 0;) {
+		if (*function != *kbinds[i].function)
 			continue;
-		if (strcmp(function, kbinds[n].function) == 0)
-			return kbinds[n].key;
+		if (strcmp(function, kbinds[i].function) == 0)
+			return kbinds[i].key;
 	}
 
 	return (char *)NULL;
@@ -732,14 +714,13 @@ list_kbinds(void)
 	}
 
 	size_t flen = 0;
-	size_t i;
-	for (i = 0; i < kbinds_n; i++) {
+	for (size_t i = 0; i < kbinds_n; i++) {
 		const size_t l = kbinds[i].function ? strlen(kbinds[i].function) : 0;
 		if (l > flen)
 			flen = l;
 	}
 
-	for (i = 0; i < kbinds_n; i++) {
+	for (size_t i = 0; i < kbinds_n; i++) {
 		if (!kbinds[i].key || !kbinds[i].function)
 			continue;
 
@@ -755,7 +736,6 @@ list_kbinds(void)
 static int
 list_rl_kbinds(void)
 {
-	size_t i, j;
 	char *name = (char *)NULL;
 	char **names = (char **)rl_funmap_names();
 
@@ -763,13 +743,13 @@ list_rl_kbinds(void)
 		return FUNC_SUCCESS;
 
 	size_t flen = 0;
-	for (i = 0; (name = names[i]); i++) {
+	for (size_t i = 0; (name = names[i]); i++) {
 		rl_command_func_t *function = rl_named_function(name);
 		char **keys = rl_invoking_keyseqs(function);
 		if (!keys)
 			continue;
 
-		for (j = 0; keys[j]; j++)
+		for (size_t j = 0; keys[j]; j++)
 			free(keys[j]);
 		free(keys);
 
@@ -780,7 +760,7 @@ list_rl_kbinds(void)
 
 	char prev[KBUF_SIZE] = "";
 
-	for (i = 0; (name = names[i]); i++) {
+	for (size_t i = 0; (name = names[i]); i++) {
 		if ((*name == 's' && strcmp(name, "self-insert") == 0)
 		|| (*name == 'd' && strcmp(name, "do-lowercase-version") == 0))
 			continue;
@@ -792,7 +772,7 @@ list_rl_kbinds(void)
 
 		printf("%-*s ", (int)flen, name);
 
-		for (j = 0; keys[j]; j++) {
+		for (size_t j = 0; keys[j]; j++) {
 			const char *t = xtranslate_key(keys[j]);
 
 			/* Skip consecutive duplicates. */
@@ -865,9 +845,7 @@ load_keybinds(void)
 
 	/* Free the keybinds struct array */
 	if (kbinds_n > 0) {
-		int i = (int)kbinds_n;
-
-		while (--i >= 0) {
+		for (size_t i = kbinds_n; i-- > 0;) {
 			free(kbinds[i].function);
 			free(kbinds[i].key);
 		}
@@ -985,8 +963,7 @@ keybind_exec_cmd(char *str)
 		if (kbind_busy == 1)
 			kbind_busy = 0;
 
-		int i = (int)args_n + 1;
-		while (--i >= 0)
+		for (size_t i = args_n + 1; i-- > 0;)
 			free(cmd[i]);
 		free(cmd);
 
@@ -1059,8 +1036,11 @@ rl_toggle_max_filename_len(int count, int key)
 	if (conf.max_name_len == UNSET) {
 		print_reload_msg(NULL, NULL, _("Max name length unset\n"));
 	} else {
-		print_reload_msg(NULL, NULL, _("Max name length set to %d\n"),
-			conf.max_name_len);
+		char auto_perc[MAX_INT_STR + 5] = "";
+		if (conf.max_name_len_auto != UNSET)
+			snprintf(auto_perc, sizeof(auto_perc), " (%d%%)", conf.max_name_len_auto);
+		print_reload_msg(NULL, NULL, _("Max name length set to %d%s\n"),
+			conf.max_name_len, auto_perc);
 	}
 
 	xrl_reset_line_state();
@@ -1133,7 +1113,7 @@ rl_prepend_sudo(int count, int key)
 
 #ifndef _NO_SUGGESTIONS
 	if (suggestion.offset == 0 && suggestion_buf) {
-		int r = rl_point;
+		const int r = rl_point;
 		rl_point = rl_end;
 		clear_suggestion(CS_FREEBUF);
 		rl_point = r;
@@ -1142,7 +1122,7 @@ rl_prepend_sudo(int count, int key)
 
 #ifndef _NO_HIGHLIGHT
 	if (conf.highlight == 1) {
-		int r = rl_point;
+		const int r = rl_point;
 		rl_point = 0;
 		recolorize_line();
 		rl_point = r;
@@ -1183,13 +1163,12 @@ my_insert_text(char *text, char *s, const char _s)
 		fputs(tx_c, stdout);
 		cur_color = tx_c;
 		char *t = text;
-		size_t i;
 
 		/* We only need to redisplay first suggested word if it contains
 		 * a highlighting char and it is not preceded by a space */
 		int redisplay = 0;
 		if (accept_first_word == 1) {
-			for (i = 0; t[i]; i++) {
+			for (size_t i = 0; t[i]; i++) {
 				if (t[i] >= '0' && t[i] <= '9') {
 					if (i == 0 || t[i - 1] != ' ') {
 						redisplay = 1;
@@ -1227,7 +1206,7 @@ my_insert_text(char *text, char *s, const char _s)
 
 		char q[PATH_MAX + 1];
 		int l = 0;
-		for (i = 0; t[i]; i++) {
+		for (size_t i = 0; t[i]; i++) {
 			rl_highlight(t, i, SET_COLOR);
 			if ((signed char)t[i] < 0) {
 				q[l] = t[i];
@@ -1254,7 +1233,7 @@ my_insert_text(char *text, char *s, const char _s)
 			 * In other words, if we correctly print colors, we lose the
 			 * suggestion.
 			 * As a workaround, let's reprint the suggestion */
-			size_t slen = strlen(suggestion_buf);
+			const size_t slen = strlen(suggestion_buf);
 			*s = _s ? _s : ' ';
 			print_suggestion(suggestion_buf, slen, suggestion.color);
 			*s = '\0';
@@ -1363,8 +1342,8 @@ rl_accept_suggestion(int count, int key)
 	case FUZZY_FILENAME: /* fallthrough */
 	case FILE_SUG: {
 		char *tmp = (char *)NULL;
-		size_t i, isquote = 0, backslash = 0;
-		for (i = 0; suggestion_buf[i]; i++) {
+		size_t isquote = 0, backslash = 0;
+		for (size_t i = 0; suggestion_buf[i]; i++) {
 			if (is_quote_char(suggestion_buf[i]))
 				isquote = 1;
 
@@ -1810,6 +1789,14 @@ rl_deselect_all(int count, int key)
 	return run_kb_cmd("ds *", 0);
 }
 
+static int
+rl_invert_selection(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	exec_prompt_cmds = 1;
+	return run_kb_cmd("s --invert", 0);
+}
+
 static int
 rl_bookmarks(int count, int key)
 {
@@ -1925,7 +1912,7 @@ rl_sort_previous(int count, int key)
 
 	conf.sort--;
 	if (conf.sort < 0)
-		conf.sort = conf.light_mode == 1 ? SINO : SORT_TYPES;
+		conf.sort = SORT_TYPES;
 
 	if (conf.autols == 1) {
 		sort_switch = 1;
@@ -2103,8 +2090,7 @@ rl_quit(int count, int key)
 static void
 get_cur_prof(int *cur, int *total)
 {
-	int i;
-	for (i = 0; profile_names[i]; i++) {
+	for (int i = 0; profile_names[i]; i++) {
 		(*total)++;
 
 		if (!alt_profile) {
@@ -2410,6 +2396,35 @@ rl_ws4(int count, int key)
 	return rl_switch_workspace(4);
 }
 
+static int
+rl_ws5(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return rl_switch_workspace(5);
+}
+
+static int
+rl_ws6(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return rl_switch_workspace(6);
+}
+
+static int
+rl_ws7(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return rl_switch_workspace(7);
+}
+
+static int
+rl_ws8(int count, int key)
+{
+	UNUSED(count); UNUSED(key);
+	return rl_switch_workspace(8);
+}
+
+
 static int
 run_plugin(const int num)
 {
@@ -2579,15 +2594,13 @@ print_highlight_string(char *s, const int insert_point)
 	if (!s || !*s)
 		return;
 
-	size_t i, l = 0;
-
 	rl_delete_text(insert_point, rl_end);
 	rl_point = rl_end = insert_point;
 	fputs(tx_c, stdout);
 	cur_color = tx_c;
 
 	char q[PATH_MAX + 1];
-	for (i = 0; s[i]; i++) {
+	for (size_t i = 0, l = 0; s[i]; i++) {
 		rl_highlight(s, i, SET_COLOR);
 
 		if ((signed char)s[i] < 0) {
@@ -2613,17 +2626,17 @@ print_highlight_string(char *s, const int insert_point)
 #endif /* !_NO_HIGHLIGHT */
 
 static int
-print_cmdhist_line(int n, int beg_line)
+print_cmdhist_line(const size_t n, const int beg_line)
 {
 #ifndef _NO_SUGGESTIONS
 	if (wrong_cmd == 1)
 		recover_from_wrong_cmd();
 #endif /* !_NO_SUGGESTIONS */
 
-	curhistindex = (size_t)n;
+	curhistindex = n;
 
 	HIDE_CURSOR;
-	int rl_point_bk = rl_point;
+	const int rl_point_bk = rl_point;
 
 #ifndef _NO_HIGHLIGHT
 	if (conf.highlight == 1)
@@ -2645,16 +2658,16 @@ print_cmdhist_line(int n, int beg_line)
 static inline int
 handle_cmdhist_beginning(int key)
 {
-	int p = (int)curhistindex;
+	size_t p = curhistindex;
 	cmdhist_flag = 1;
 
 	if (key == 65) { /* Up arrow key */
-		if (--p < 0)
-			return FUNC_FAILURE;
+		if (p == 0) return FUNC_FAILURE;
+		p--;
 	} else { /* Down arrow key */
 		if (rl_end == 0)
 			return FUNC_SUCCESS;
-		if (++p >= (int)current_hist_n) {
+		if (++p >= current_hist_n) {
 			rl_replace_line("", 1);
 			curhistindex++;
 			return FUNC_SUCCESS;
@@ -2664,7 +2677,7 @@ handle_cmdhist_beginning(int key)
 	if (!history[p].cmd)
 		return FUNC_FAILURE;
 
-	curhistindex = (size_t)p;
+	curhistindex = p;
 
 	return print_cmdhist_line(p, 1);
 }
@@ -2672,23 +2685,27 @@ handle_cmdhist_beginning(int key)
 static inline int
 handle_cmdhist_middle(int key)
 {
-	int found = 0, p = (int)curhistindex;
+	int found = 0;
+	const size_t s_rl_point = rl_point < 0 ? 0 : (size_t)rl_point;
+	size_t p = curhistindex;
 
 	if (key == 65) { /* Up arrow key */
-		if (--p < 0) return FUNC_FAILURE;
+		if (p == 0) return FUNC_FAILURE;
+		p--;
 
-		while (p >= 0 && history[p].cmd) {
-			if (strncmp(rl_line_buffer, history[p].cmd, (size_t)rl_point) == 0
+		while (history[p].cmd) {
+			if (strncmp(rl_line_buffer, history[p].cmd, s_rl_point) == 0
 			&& strcmp(rl_line_buffer, history[p].cmd) != 0) {
 				found = 1; break;
 			}
+			if (p == 0) break;
 			p--;
 		}
 	} else { /* Down arrow key */
-		if (++p >= (int)current_hist_n)	return FUNC_FAILURE;
+		if (++p >= current_hist_n) return FUNC_FAILURE;
 
 		while (history[p].cmd) {
-			if (strncmp(rl_line_buffer, history[p].cmd, (size_t)rl_point) == 0
+			if (strncmp(rl_line_buffer, history[p].cmd, s_rl_point) == 0
 			&& strcmp(rl_line_buffer, history[p].cmd) != 0) {
 				found = 1; break;
 			}
@@ -2811,15 +2828,15 @@ rl_del_last_word(int count, int key)
 	char *b = rl_line_buffer;
 
 	if (b[rl_point - 1] == '/' || b[rl_point - 1] == ' ') {
-		--rl_point;
+		rl_point--;
 		b[rl_point] = '\0';
-		--rl_end;
+		rl_end--;
 	}
 
 	int n = 0;
 	char *p = xstrrpbrk(b, WORD_DELIMITERS);
 	if (p)
-		n = (int)(p - b) + (*(p + 1) ? 1 : 0);
+		n = (int)(p - b) + (p[1] ? 1 : 0);
 
 	rl_begin_undo_group();
 	rl_delete_text(n, rl_end);
@@ -2984,6 +3001,8 @@ set_keybinds_from_file(void)
 		{"home-dir", rl_dir_home}, {"root-dir", rl_dir_root},
 		{"workspace1", rl_ws1}, {"workspace2", rl_ws2},
 		{"workspace3", rl_ws3}, {"workspace4", rl_ws4},
+		{"workspace5", rl_ws5}, {"workspace6", rl_ws6},
+		{"workspace7", rl_ws7}, {"workspace8", rl_ws8},
 
 		{"create-file", rl_create_file}, {"archive-sel", rl_archive_sel},
 		{"open-sel", rl_open_sel}, {"export-sel", rl_export_sel},
@@ -3009,6 +3028,7 @@ set_keybinds_from_file(void)
 		{"toggle-long", rl_toggle_long_view},
 		{"toggle-follow-links-long", rl_toggle_follow_link_long},
 		{"toggle-light", rl_toggle_light_mode},
+		{"invert-selection", rl_invert_selection},
 		{"dirs-first", rl_toggle_dirs_first},
 		{"sort-previous", rl_sort_previous}, {"sort-next", rl_sort_next},
 		{"only-dirs", rl_toggle_only_dirs},
@@ -3066,12 +3086,15 @@ set_default_keybinds(void)
 		{"\\M-p", rl_dir_pinned},
 		{"\\M-1", rl_ws1}, {"\\M-2", rl_ws2},
 		{"\\M-3", rl_ws3}, {"\\M-4", rl_ws4},
+		{"\\M-5", rl_ws5}, {"\\M-6", rl_ws6},
+		{"\\M-7", rl_ws7}, {"\\M-8", rl_ws8},
 		/* Operations on files */
 		{"\\M-n", rl_create_file}, {"\\C-\\M-a", rl_archive_sel},
 		{"\\C-\\M-e", rl_export_sel}, {"\\C-\\M-r", rl_rename_sel},
 		{"\\C-\\M-d", rl_remove_sel}, {"\\C-\\M-t", rl_trash_sel},
 		{"\\C-\\M-v", rl_paste_sel}, {"\\M-a", rl_select_all},
-		{"\\M-d", rl_deselect_all}, {"\\M-v", rl_prepend_sudo},
+		{"\\M-d", rl_deselect_all}, {"\\e[Z", rl_invert_selection},
+		{"\\M-v", rl_prepend_sudo},
 		/* Config files */
 		{"\\e[17~", rl_open_mime}, {"\\e[18~", rl_open_preview},
 		{"\\e[19~", rl_open_cscheme}, {"\\e[20~", rl_open_keybinds},
@@ -3151,8 +3174,7 @@ disable_rl_conflicting_kbinds(void)
 		"\\e\\", "\\e\\e", "\\eb", "\\e.", "\\et", "\\ey", "\\e-",
 		"\\eu", "\\M-5", "\\M-6", "\\M-7", "\\M-8", "\\M-9", NULL};
 
-	size_t i;
-	for (i = 0; keys[i]; i++)
+	for (size_t i = 0; keys[i]; i++)
 		rl_bind_keyseq(keys[i], do_nothing);
 }
 
