@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* long_view.c -- Construct entries in long view mode */
@@ -568,7 +553,7 @@ print_entry_props(const struct fileinfo *props, const struct maxes_t *maxes,
 		have_xattr == 1 ? (props->xattr == 1 ? XATTR_CHAR : ' ') : 0;
 	const size_t prop_fields_gap = (size_t)conf.prop_fields_gap;
 	const int file_counter =
-		(conf.files_counter != 0 && maxes->files_counter != 0);
+		(conf.file_counter != 0 && maxes->file_counter != 0);
 
 	construct_and_print_filename(props, maxes->name);
 
@@ -584,7 +569,7 @@ print_entry_props(const struct fileinfo *props, const struct maxes_t *maxes,
 		case 'B': len += gen_blocks(props, buf + len, maxes->blocks); break;
 		case 'f':
 			if (file_counter == 1)
-				len += gen_filecounter(props, buf + len, maxes->files_counter);
+				len += gen_filecounter(props, buf + len, maxes->file_counter);
 			break;
 		case 'd': len += gen_inode(props, buf + len, maxes->inode); break;
 		case 'p': /* fallthrough */
