@@ -2,23 +2,8 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
- */
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
+*/
 
 /* main.c -- Main file for Clifm */
 
@@ -234,6 +219,9 @@ size_t
 size_t *name_icons_hashes = (size_t *)0;
 size_t *dir_icons_hashes = (size_t *)0;
 size_t *ext_icons_hashes = (size_t *)0;
+#ifndef OLD_ICON_LOOKUP
+size_t *ext_table = (size_t *)0;
+#endif
 #endif /* !_NO_ICONS */
 
 char
@@ -768,6 +756,8 @@ const struct nameslist_t param_str[] = {
 	{"prompt unset", 12},
 	{"r -f", 4},
 	{"r --force", 9},
+	{"s --invert", 10},
+	{"sel --invert", 12},
 	{"st none", 7},
 	{"st name", 7},
 	{"st size", 7},
@@ -836,6 +826,7 @@ const struct nameslist_t kb_cmds[] = {
 	{"edit-color-scheme", 17},
 	{"export-sel", 10},
 	{"home-dir", 8},
+	{"invert-selection", 16},
 	{"launch-view", 11},
 	{"lock", 4},
 	{"mountpoints", 11},
@@ -900,6 +891,10 @@ const struct nameslist_t kb_cmds[] = {
 	{"workspace2", 10},
 	{"workspace3", 10},
 	{"workspace4", 10},
+	{"workspace5", 10},
+	{"workspace6", 10},
+	{"workspace7", 10},
+	{"workspace8", 10},
 	{NULL, 0}
 };
 
@@ -947,7 +942,6 @@ run_and_exit(void)
 # endif /* !_NO_TRASH */
 
 	/* 1) Parse input string. */
-	int i = 0;
 	char **cmd = parse_input_str(cmd_line_cmd);
 	if (!cmd)
 		exit(EXIT_FAILURE);
@@ -959,7 +953,7 @@ run_and_exit(void)
 		 * ALIAS_CMD in its place to be executed by exec_cmd_tm(). */
 		exec_cmd_tm(alias_cmd);
 
-		for (i = 0; alias_cmd[i]; i++)
+		for (size_t i = 0; alias_cmd[i]; i++)
 			free(alias_cmd[i]);
 		free(alias_cmd);
 		exit(exit_code);
@@ -969,7 +963,7 @@ run_and_exit(void)
 		exec_cmd_tm(cmd);
 	flags &= ~FAILED_ALIAS;
 
-	for (i = 0; cmd[i]; i++)
+	for (size_t i = 0; cmd[i]; i++)
 		free(cmd[i]);
 	free(cmd);
 
@@ -994,7 +988,6 @@ run_main_loop(void)
 		run_and_exit(); /* No return */
 #endif /* RUN_CMD */
 
-	int i;
 	/* 1) Infinite loop to keep the program running. */
 	while (1) {
 		/* 2) Grab the input string from the command prompt. */
@@ -1016,7 +1009,7 @@ run_main_loop(void)
 			 * ALIAS_CMD in its place to be executed by exec_cmd_tm(). */
 			exec_cmd_tm(alias_cmd);
 
-			for (i = 0; alias_cmd[i]; i++)
+			for (size_t i = 0; alias_cmd[i]; i++)
 				free(alias_cmd[i]);
 			free(alias_cmd);
 			continue;
@@ -1026,8 +1019,7 @@ run_main_loop(void)
 			exec_cmd_tm(cmd);
 		flags &= ~FAILED_ALIAS;
 
-		i = (int)args_n + 1;
-		while (--i >= 0)
+		for (size_t i = 0; i <= args_n; i++)
 			free(cmd[i]);
 		free(cmd);
 	}
@@ -1388,8 +1380,9 @@ main(int argc, char *argv[])
 	init_workspaces_opts();
 	load_user_mimetypes();
 
-	/* Restore user umask */
-	umask(old_mask); /* flawfinder: ignore */
+	/* Restore user umask (if not set via Umask in the config file) */
+	if (conf.umask_set != 1)
+		umask(old_mask); /* flawfinder: ignore */
 
 	/* # 2. MAIN PROGRAM LOOP # */
 	run_main_loop();
