@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* media.c -- functions to manage local filesystems */
@@ -82,9 +67,9 @@ get_block_devices(void)
 		return (char **)NULL;
 
 	char **bd = (char **)NULL;
-	size_t i, n = 0;
+	size_t n = 0;
 
-	for (i = 0; (int)i < block_n; i++) {
+	for (int i = 0; i < block_n; i++) {
 # ifndef _DIRENT_HAVE_D_TYPE
 		char bpath[PATH_MAX + 1];
 		snprintf(bpath, sizeof(bpath), "/dev/%s", blockdev[i]->d_name);
@@ -176,9 +161,8 @@ get_dev_label(void)
 		return (char *)NULL;
 
 	char *label = (char *)NULL;
-	int i;
 
-	for (i = 0; i < ln; i++) {
+	for (int i = 0; i < ln; i++) {
 		if (label) {
 			free(labels[i]);
 			continue;
@@ -217,7 +201,6 @@ get_dev_label(void)
 static void
 list_unmounted_devs(void)
 {
-	int i;
 	const size_t mp_n_bk = mp_n;
 	char **unm_devs = get_block_devices();
 	if (!unm_devs)
@@ -225,11 +208,10 @@ list_unmounted_devs(void)
 
 	printf(_("\n%sUnmounted devices%s\n\n"), BOLD, df_c);
 
-	for (i = 0; unm_devs[i]; i++) {
+	for (int i = 0; unm_devs[i]; i++) {
 		int skip = 0;
-		size_t j;
 		/* Skip already mounted devices */
-		for (j = 0; j < mp_n_bk; j++) {
+		for (size_t j = 0; j < mp_n_bk; j++) {
 			if (strcmp(media[j].dev, unm_devs[i]) == 0)
 				skip = 1;
 		}
@@ -386,8 +368,7 @@ mount_dev(const int n)
 static void
 free_media(void)
 {
-	int i = (int)mp_n;
-	while (--i >= 0) {
+	for (size_t i = mp_n; i-- > 0;) {
 		free(media[i].mnt);
 		free(media[i].dev);
 		free(media[i].label);
@@ -426,9 +407,9 @@ list_mountpoints_bsd(struct statvfs *fslist)
 list_mountpoints_bsd(struct statfs *fslist)
 # endif /* __NetBSD__ */
 {
-	size_t i, j = 0;
+	size_t j = 0;
 
-	for (i = 0; i < mp_n; i++) {
+	for (size_t i = 0; i < mp_n; i++) {
 		/* Do not list all mountpoints, but only those corresponding
 		 * to a block device (/dev) */
 		if (strncmp(fslist[i].f_mntfromname, "/dev/", 5) != 0)
