@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* messages.h - Usage and help messages for Clifm */
@@ -1097,7 +1082,7 @@ injection. To enable this mode, use the --secure-cmds command line switch."
 
 #define SEL_USAGE "Select one or multiple files\n\n\
 \x1b[1mUSAGE\x1b[22m\n\
-  s, sel FILE... [[!]PATTERN] [-FILETYPE] [:PATH]\n\n\
+  s, sel [--invert] [FILE...] [(!)PATTERN] [-(d|f|l|s|p|b|c)] [:PATH]\n\n\
 Recognized file types: (d)irectory, regular (f)ile, symbolic (l)ink,\n\
 (s)ocket, fifo/(p)ipe, (b)lock device, (c)haracter device\n\n\
 \x1b[1mEXAMPLES\x1b[22m\n\
@@ -1116,6 +1101,8 @@ Recognized file types: (d)irectory, regular (f)ile, symbolic (l)ink,\n\
     s /media/*<TAB>\n\
 - List currently selected files\n\
     sb\n\
+- Invert (toggle) selection in the current directory\n\
+    s --invert (or Shift+Tab)\n\
 - Copy selected files to the current directory:\n\
     c sel\n\
 - Move selected files to the directory whose ELN is 24\n\
@@ -1397,7 +1384,7 @@ c: Quit paging (printing remaining files)\n"
 #ifdef _BE_POSIX
 #define OPTIONS_LIST "\
 \n -a[VAL]  List hidden files ('first', 'last', 'true', or 'false')\
-\n -A       Do not list hidden files\
+\n -A       Do not list hidden files (same as -afalse)\
 \n -b FILE  Set an alternative bookmarks file\
 \n -B NUM   Set TAB-completion mode (NUM=[0-3])\
 \n -c FILE  Set an alternative main configuration file\
@@ -1449,8 +1436,8 @@ c: Quit paging (printing remaining files)\n"
 \n -Z NUM   List only up to NUM files"
 #else
 #define SHORT_OPTIONS "\
-\n  -a, --show-hidden[=VAL]\t Show hidden files ('first', 'last', 'true', or 'false')\
-\n  -A, --no-hidden\t\t Do not show hidden files\
+\n  -a, --show-hidden[=VALUE]\t Show hidden files ('first', 'last', 'true', or 'false'). If VALUE is omitted, 'true' is assumed.\
+\n  -A, --no-hidden\t\t Do not show hidden files (same as --show-hidden=false)\
 \n  -b, --bookmarks-file=FILE\t Set an alternative bookmarks file\
 \n  -c, --config-file=FILE\t Set an alternative configuration file\
 \n  -D, --config-dir=DIR\t\t Set an alternative configuration directory\
@@ -1493,7 +1480,7 @@ database (via the 'j' command)\
 \n      --color-links-as-target\t Colorize symbolic links according to the target file\
 \n      --cwd-in-title\t\t Print the current directory in the terminal window title\
 \n      --data-dir=PATH\t\t Use PATH as data directory (e.g.: /usr/local/share)\
-\n      --desktop-notifications\t Set the desktop notifications style: 'kitty', 'system', or 'false' (default)\
+\n      --desktop-noti=STYLE\t Set the desktop notification style: 'kitty', 'system', or 'false' (default)\
 \n      --disk-usage\t\t Show disk usage (FREE/TOTAL (FREE %) TYPE DEVICE)\
 \n      --full-dir-size\t\t Display recursive directory sizes (long view only)\
 \n      --fuzzy-algo=NUM\t\t Set fuzzy algorithm for fuzzy matching (1 or 2)\
@@ -1502,7 +1489,7 @@ and paths\
 \n      --fzfpreview-hidden\t Enable file previews for tab completion (fzf mode only) with the preview window hidden (toggle with Alt+p)\
 \n      --icons\t\t\t Enable icons\
 \n      --icons-use-file-color\t Icon colors follow file colors\
-\n      --int-vars\t\t Enable the use internal variables\
+\n      --int-vars\t\t Enable the use of internal variables\
 \n      --kitty-keys\t\t Ask the terminal to enable the kitty keyboard protocol\
 \n      --list-and-quit\t\t List files and quit\
 \n      --ls\t\t\t Short for --list-and-quit\
@@ -1555,7 +1542,7 @@ PropFields in the config file)\
 \n      --sel-file=FILE\t\t Set FILE as custom selections file\
 \n      --share-selbox\t\t Make the Selection Box common to different profiles\
 \n      --shotgun-file=FILE\t Set FILE as shotgun's configuration file\
-\n      --si\t\t\t Display file sizes in SI units (powers of 1000) instead of 1024\
+\n      --si\t\t\t Display file sizes in powers of 1000 (SI units) instead of 1024\
 \n      --sort-reverse\t\t Sort in reverse order, e.g., z-a instead of a-z\
 \n      --stat FILE...\t\t Run the 'p' command on FILE(s) and exit\
 \n      --stat-full FILE...\t Run the 'pp' command on FILE(s) and exit\
@@ -1690,7 +1677,7 @@ For more information about a specific command run 'CMD -h' or 'CMD --help'.\n"
  Alt+p              Change to the pinned directory\n\
  Alt+v              Toggle prepend sudo\n\
  Alt+0              Run the file pager\n\
- Alt+[1-4]          Switch to workspace 1-4\n\
+ Alt+[1-8]          Switch to workspace 1-8\n\
  Ctrl+Alt+o         Switch to previous profile\n\
  Ctrl+Alt+p         Switch to next profile\n\
  Ctrl+Alt+a         Archive selected files\n\
