@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* mime.c -- functions controlling Lira, the file opener */
@@ -47,6 +32,7 @@
 # include "aux.h"
 # include "checks.h"
 # include "config.h"
+# include "fs_events.h" /* check_fs_events */
 # include "listing.h"
 # include "messages.h"
 # include "mime.h"
@@ -73,7 +59,7 @@ static char *g_mime_type = (char *)NULL;
 static char *
 check_user_mimetypes(const char *file)
 {
-	char *ext = strrchr(file, '.');
+	const char *ext = strrchr(file, '.');
 	if (!ext || ext == file || !*(++ext))
 		return (char *)NULL;
 
@@ -673,7 +659,7 @@ mime_edit(char **args)
 	const time_t prev = a.st_mtime;
 
 	if (!args[2]) {
-		char *cmd[] = {"mime", mime_file, NULL};
+		char *cmd[] = {"mime", "open", mime_file, NULL};
 		open_in_foreground = 1;
 		if (mime_open(cmd) != 0) {
 			fputs(_("Try 'mm edit APPLICATION'\n"), stderr);
@@ -1347,8 +1333,7 @@ join_and_run(char **args, char *name)
 
 	const int ret = run_cmd_plus_args(ss, name);
 
-	size_t i;
-	for (i = 0; ss[i]; i++)
+	for (size_t i = 0; ss[i]; i++)
 		free(ss[i]);
 	free(ss);
 
@@ -1419,8 +1404,7 @@ mime_open_with(char *filename, char **args)
 	g_mime_type = (char *)NULL;
 	free(mime);
 
-	size_t i;
-	for (i = 0; apps[i]; i++)
+	for (size_t i = 0; apps[i]; i++)
 		free(apps[i]);
 	free(apps);
 	free(name);
@@ -1646,6 +1630,9 @@ run_archiver(char **fpath, char **app, char **mime_type)
 	free(*app);
 	free(*mime_type);
 
+	exit_code = exit_status;
+	check_fs_events(1);
+
 	return exit_status;
 }
 #endif /* _NO_ARCHIVING */
@@ -1676,8 +1663,11 @@ mime_open(char **args)
 		return mime_edit(args);
 
 	char *file_path = (char *)NULL;
-	const int info = (*args[1] == 'i' && strcmp(args[1], "info") == 0);
-	const int file_index = info == 1 ? 2 : 1;
+	const int info =
+		(*args[1] == 'i' && strcmp(args[1], "info") == 0 && args[2]);
+	const int open_arg =
+		(*args[1] == 'o' && strcmp(args[1], "open") == 0 && args[2]);
+	const int file_index = (info == 1 || open_arg == 1) ? 2 : 1;
 
 	if (info == 1) {
 		const int ret = check_mime_info_file(args[2], &file_path);
