@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* misc.c -- functions that do not fit in any other file */
@@ -47,6 +32,7 @@
 
 #ifdef __OpenBSD__
 typedef char *rl_cpvfunc_t;
+typedef void rl_macro_print_func_t (const char *, const char *, int, const char *);
 # include <ereadline/readline/readline.h>
 #else
 # include <readline/readline.h>
@@ -83,7 +69,7 @@ gen_diff_str(const int diff)
 	if (diff == 3)
 		return "\x1b[3C";
 
-	static char diff_str[14];
+	static char diff_str[MAX_INT_STR + 4];
 	snprintf(diff_str, sizeof(diff_str), "\x1b[%dC", diff);
 
 	return diff_str;
@@ -317,181 +303,6 @@ print_reload_msg(const char *ptr, const char *color, const char *msg, ...)
 	return FUNC_SUCCESS;
 }
 
-#ifdef LINUX_INOTIFY
-void
-reset_inotify(void)
-{
-	watch = 0;
-
-	if (inotify_wd >= 0) {
-		inotify_rm_watch(inotify_fd, inotify_wd);
-		inotify_wd = -1;
-	}
-
-	if (inotify_fd != UNSET)
-		close(inotify_fd);
-	inotify_fd = inotify_init1(IN_NONBLOCK);
-	if (inotify_fd < 0) {
-		err('w', PRINT_PROMPT, "%s: inotify: %s\n",
-			PROGRAM_NAME, strerror(errno));
-		return;
-	}
-
-	/* If CWD is a symlink to a directory and it does not end with a slash,
-	 * inotify_add_watch(3) fails with ENOTDIR. */
-	char rpath[PATH_MAX + 1];
-	snprintf(rpath, sizeof(rpath), "%s/", workspaces[cur_ws].path);
-
-	inotify_wd = inotify_add_watch(inotify_fd, rpath, INOTIFY_MASK);
-	if (inotify_wd > 0)
-		watch = 1;
-	else
-		err('w', PRINT_PROMPT, "%s: inotify: '%s': %s\n",
-			PROGRAM_NAME, rpath, strerror(errno));
-}
-
-void
-read_inotify(void)
-{
-	if (inotify_fd == UNSET)
-		return;
-
-	int i;
-	struct inotify_event *event;
-	char inotify_buf[EVENT_BUF_LEN];
-
-	memset((void *)inotify_buf, '\0', sizeof(inotify_buf));
-	i = (int)read(inotify_fd, inotify_buf, sizeof(inotify_buf)); /* flawfinder: ignore */
-
-	if (i <= 0) {
-# ifdef INOTIFY_DEBUG
-		puts("INOTIFY_RETURN");
-# endif /* INOTIFY_DEBUG */
-		return;
-	}
-
-	int ignore_event = 0;
-	int refresh = 0;
-
-	for (char *ptr = inotify_buf;
-	ptr + ((struct inotify_event *)ptr)->len < inotify_buf + i;
-	ptr += sizeof(struct inotify_event) + event->len) {
-		event = (struct inotify_event *)ptr;
-
-# ifdef INOTIFY_DEBUG
-		printf("%s (%u:%d): ", *event->name
-			? event->name : NULL, event->len, event->wd);
-# endif /* INOTIFY_DEBUG */
-
-		if (!event->wd) {
-# ifdef INOTIFY_DEBUG
-			puts("INOTIFY_BREAK");
-# endif /* INOTIFY_DEBUG */
-			break;
-		}
-
-		if (event->mask & IN_CREATE) {
-# ifdef INOTIFY_DEBUG
-			puts("IN_CREATE");
-# endif /* INOTIFY_DEBUG */
-			struct stat a;
-			if (event->len && lstat(event->name, &a) != 0) {
-				/* The file was created, but doesn't exist anymore */
-				ignore_event = 1;
-			}
-		}
-
-		/* A file was renamed */
-		if (event->mask & IN_MOVED_TO) {
-# ifdef INOTIFY_DEBUG
-			puts("IN_MOVED_TO");
-# endif /* INOTIFY_DEBUG */
-			filesn_t j = files;
-			while (--j >= 0) {
-				if (*file_info[j].name == *event->name
-				&& strcmp(file_info[j].name, event->name) == 0)
-					break;
-			}
-
-			/* If destiny filename is already in the file list (j >= 0),
-			 * ignore this event. */
-			ignore_event = (j < 0) ? 0 : 1;
-		}
-
-		if (event->mask & IN_DELETE) {
-# ifdef INOTIFY_DEBUG
-			puts("IN_DELETE");
-# endif /* INOTIFY_DEBUG */
-			struct stat a;
-			if (event->len && lstat(event->name, &a) == 0)
-				/* The file was removed, but is still there (recreated) */
-				ignore_event = 1;
-		}
-
-# ifdef INOTIFY_DEBUG
-		if (event->mask & IN_DELETE_SELF)
-			puts("IN_DELETE_SELF");
-		if (event->mask & IN_MOVE_SELF)
-			puts("IN_MOVE_SELF");
-		if (event->mask & IN_MOVED_FROM)
-			puts("IN_MOVED_FROM");
-		if (event->mask & IN_MOVED_TO)
-			puts("IN_MOVED_TO");
-		if (event->mask & IN_IGNORED)
-			puts("IN_IGNORED");
-# endif /* INOTIFY_DEBUG */
-
-		if (ignore_event == 0 && (event->mask & INOTIFY_MASK))
-			refresh = 1;
-	}
-
-	if (refresh == 1 && exit_code == FUNC_SUCCESS) {
-# ifdef INOTIFY_DEBUG
-		puts("INOTIFY_REFRESH");
-# endif /* INOTIFY_DEBUG */
-		reload_dirlist();
-	} else {
-# ifdef INOTIFY_DEBUG
-		puts("INOTIFY_RESET");
-# endif /* INOTIFY_DEBUG */
-		/* Reset the inotify watch list */
-		reset_inotify();
-	}
-}
-#elif defined(BSD_KQUEUE)
-/* Insert the following lines in the for loop to debug kqueue:
-if (event_data[i].fflags & NOTE_DELETE)
-	puts("NOTE_DELETE");
-if (event_data[i].fflags & NOTE_WRITE)
-	puts("NOTE_WRITE");
-if (event_data[i].fflags & NOTE_EXTEND)
-	puts("NOTE_EXTEND");
-if (event_data[i].fflags & NOTE_ATTRIB)
-	puts("NOTE_ATTRIB");
-if (event_data[i].fflags & NOTE_LINK)
-	puts("NOTE_LINK");
-if (event_data[i].fflags & NOTE_RENAME)
-	puts("NOTE_RENAME");
-if (event_data[i].fflags & NOTE_REVOKE)
-	puts("NOTE_REVOKE"); */
-void
-read_kqueue(void)
-{
-	struct kevent event_data[NUM_EVENT_SLOTS];
-	memset((void *)event_data, '\0', sizeof(struct kevent) * NUM_EVENT_SLOTS);
-
-	int i;
-	const int count = kevent(kq, NULL, 0, event_data, 4096, &timeout);
-
-	for (i = 0; i < count; i++) {
-		if (event_data[i].fflags & KQUEUE_FFLAGS) {
-			reload_dirlist();
-			return;
-		}
-	}
-}
-#endif /* LINUX_INOTIFY */
-
 void
 set_filter_type(const char c)
 {
@@ -1098,10 +909,10 @@ void
 free_autocmds(const int keep_temp)
 {
 	UNUSED(keep_temp);
-/*	int i = (int)autocmds_n;
+/*	size_t i = autocmds_n;
 
 	if (keep_temp == 1) {
-		while (--i >= 0) {
+		for (; i-- > 0;) {
 			if (autocmds[i].temp == 1) {
 				keep_temp_autocmds();
 				return;
@@ -1109,8 +920,7 @@ free_autocmds(const int keep_temp)
 		}
 	} */
 
-	int i = (int)autocmds_n;
-	while (--i >= 0) {
+	for (size_t i = autocmds_n; i-- > 0;) {
 		free(autocmds[i].pattern);
 		free(autocmds[i].cmd);
 		free(autocmds[i].filter.str);
@@ -1126,8 +936,7 @@ free_autocmds(const int keep_temp)
 void
 free_tags(void)
 {
-	int i = (int)tags_n;
-	while (--i >= 0)
+	for (size_t i = tags_n; i-- > 0;)
 		free(tags[i]);
 	free(tags);
 	tags = (char **)NULL;
@@ -1165,8 +974,7 @@ expand_prompt_name(char *name)
 	if (!p || !*p || strchr(p, '\\')) /* Exclude prompt codes. */
 		return FUNC_FAILURE;
 
-	int i = (int)prompts_n;
-	while (--i >= 0) {
+	for (size_t i = prompts_n; i-- > 0;) {
 		if (*p != *prompts[i].name || strcmp(p, prompts[i].name) != 0)
 			continue;
 
@@ -1207,8 +1015,7 @@ expand_prompt_name(char *name)
 void
 free_prompts(void)
 {
-	int i = (int)prompts_n;
-	while (--i >= 0) {
+	for (size_t i = prompts_n; i-- > 0;) {
 		free(prompts[i].name);
 		free(prompts[i].regular);
 		free(prompts[i].warning);
@@ -1356,8 +1163,8 @@ free_file_templates(void)
 	if (!file_templates)
 		return;
 
-	filesn_t i;
-	for (i = 0; file_templates[i]; i++)
+	/* Max file_templates is filesn_t (ssize_t), <= size_t. */
+	for (size_t i = 0; file_templates[i]; i++)
 		free(file_templates[i]);
 
 	free(file_templates);
@@ -1369,7 +1176,7 @@ free_file_templates(void)
 void
 free_stuff(void)
 {
-	int i = 0;
+	size_t i = 0;
 
 	free(alt_config_dir);
 	free(alt_trash_dir);
@@ -1415,6 +1222,9 @@ free_stuff(void)
 	free(name_icons_hashes);
 	free(dir_icons_hashes);
 	free(ext_icons_hashes);
+#ifndef OLD_ICON_LOOKUP
+	free(ext_table);
+#endif
 #endif /* !_NO_ICONS */
 
 	free(conf.time_str);
@@ -1457,15 +1267,13 @@ free_stuff(void)
 
 	remove_virtual_dir();
 
-	i = (int)cschemes_n;
-	while (i-- > 0)
+	for (i = cschemes_n; i-- > 0;)
 		free(color_schemes[i]);
 	free(color_schemes);
 	free(conf.usr_cscheme);
 
 	if (jump_db) {
-		i = (int)jump_n;
-		while (--i >= 0)
+		for (i = jump_n; i-- > 0;)
 			free(jump_db[i].path);
 		free(jump_db);
 	}
@@ -1497,91 +1305,79 @@ free_stuff(void)
 	}
 
 	if (sel_n > 0) {
-		i = (int)sel_n;
-		while (--i >= 0)
+		for (i = sel_n; i-- > 0;)
 			free(sel_elements[i].name);
 		free(sel_elements);
 	}
 	free(sel_devino);
 
 	if (bin_commands) {
-		i = (int)path_progsn;
-		while (--i >= 0)
+		for (i = path_progsn; i-- > 0;)
 			free(bin_commands[i]);
 		free(bin_commands);
 	}
 
 	if (paths) {
-		i = (int)path_n;
-		while (--i >= 0)
+		for (i = path_n; i-- > 0;)
 			free(paths[i].path);
 		free(paths);
 	}
 
 	if (cdpaths) {
-		i = (int)cdpath_n;
-		while (--i >= 0)
+		for (i = cdpath_n; i-- > 0;)
 			free(cdpaths[i]);
 		free(cdpaths);
 	}
 
 	if (history) {
-		i = (int)current_hist_n;
-		while (--i >= 0)
+		for (i = current_hist_n; i-- > 0;)
 			free(history[i].cmd);
 		free(history);
 	}
 
 	if (dirhist_total_index) {
-		i = dirhist_total_index;
-		while (--i >= 0)
+		i = dirhist_total_index > 0 ? (size_t)dirhist_total_index : 0;
+		for (; i-- > 0;)
 			free(old_pwd[i]);
 		free(old_pwd);
 	}
 
-	i = (int)aliases_n;
-	while (--i >= 0) {
+	for (i = aliases_n; i-- > 0;) {
 		free(aliases[i].name);
 		free(aliases[i].cmd);
 	}
 	free(aliases);
 
-	i = (int)kbinds_n;
-	while (--i >= 0) {
+	for (i = kbinds_n; i-- > 0;) {
 		free(kbinds[i].function);
 		free(kbinds[i].key);
 	}
 	free(kbinds);
 
-	i = (int)usrvar_n;
-	while (--i >= 0) {
+	for (i = usrvar_n; i-- > 0;) {
 		free(usr_var[i].name);
 		free(usr_var[i].value);
 	}
 	free(usr_var);
 
-	i = (int)actions_n;
-	while (--i >= 0) {
+	for (i = actions_n; i-- > 0;) {
 		free(usr_actions[i].name);
 		free(usr_actions[i].value);
 	}
 	free(usr_actions);
 
-	i = (int)prompt_cmds_n;
-	while (--i >= 0)
+	for (i = prompt_cmds_n; i-- > 0;)
 		free(prompt_cmds[i]);
 	free(prompt_cmds);
 
 	if (msgs_n > 0) {
-		i = (int)msgs_n;
-		while (--i >= 0)
+		for (i = msgs_n; i-- > 0;)
 			free(messages[i].text);
 		free(messages);
 	}
 
 	if (ext_colors_n) {
-		i = (int)ext_colors_n;
-		while (--i >= 0) {
+		for (i = ext_colors_n; i-- > 0;) {
 			free(ext_colors[i].name);
 			free(ext_colors[i].value);
 		}
@@ -1589,8 +1385,7 @@ free_stuff(void)
 	}
 
 	if (workspaces && workspaces[0].path) {
-		i = MAX_WS;
-		while (--i >= 0) {
+		for (i = MAX_WS; i-- > 0;) {
 			free(workspaces[i].path);
 			free(workspaces[i].name);
 		}
@@ -1664,6 +1459,25 @@ free_stuff(void)
 		UNSET_KITTY_KEYS;
 }
 
+/* Dynamically set MaxFilenameLen based on the current number of terminal
+ * columns. */
+static void
+set_max_filename_len_auto(void)
+{
+	if (conf.max_name_len_auto == UNSET || conf.max_name_len == UNSET)
+		return;
+
+	if ((conf.columned == 0 || files == 1) && conf.long_view == 0) {
+		/* Displaying in a single column or there is just one file in the list:
+		 * Do not truncate names. */
+		conf.max_name_len = term_cols;
+		return;
+	}
+
+	const int n = (int)(term_cols * conf.max_name_len_auto / 100);
+	conf.max_name_len = n < conf.min_name_trunc ? conf.min_name_trunc : n;
+}
+
 /* Get current terminal dimensions and store them in TERM_COLS and
  * TERM_LINES (globals). These values will be updated upon SIGWINCH.
  * In case of error, we fallback to 80x24. */
@@ -1672,15 +1486,17 @@ get_term_size(void)
 {
 	struct winsize w;
 	if (ioctl(STDOUT_FILENO, TIOCGWINSZ, &w) == -1) {
-		term_cols = 80;
-		term_lines = 24;
+		term_cols = DEFAULT_WIN_COLS;
+		term_lines = DEFAULT_WIN_ROWS;
 	} else {
-		term_cols =  w.ws_col > 0 ? w.ws_col : 80;
-		term_lines = w.ws_row > 0 ? w.ws_row : 24;
+		term_cols =  w.ws_col > 0 ? w.ws_col : DEFAULT_WIN_COLS;
+		term_lines = w.ws_row > 0 ? w.ws_row : DEFAULT_WIN_ROWS;
 	}
 
-	if (xargs.secure_env == 1 || xargs.secure_env_full == 1)
+	if (xargs.secure_env == 1 || xargs.secure_env_full == 1) {
+		set_max_filename_len_auto();
 		return;
+	}
 
 	char *env = getenv("CLIFM_COLUMNS");
 	int value = env ? atoi(env) : -1;
@@ -1691,6 +1507,8 @@ get_term_size(void)
 	value = env ? atoi(env) : -1;
 	if (value > 0 && value <= USHRT_MAX)
 		term_lines = (unsigned short)value;
+
+	set_max_filename_len_auto();
 }
 
 static int
@@ -1809,7 +1627,7 @@ gen_symlink(char *file, const char *cwd)
 	char dest[PATH_MAX + 32];
 	snprintf(dest, sizeof(dest), "%s/%s", stdin_tmp_dir, name);
 
-	int suffix = 0;
+	size_t suffix = 0;
 
 	while (1) {
 		errno = 0;
@@ -1824,12 +1642,15 @@ gen_symlink(char *file, const char *cwd)
 		}
 
 		suffix++;
-		if (suffix == INT_MAX) {
+		if (suffix > MAX_FILE_CREATION_TRIES) {
+			err('w', PRINT_PROMPT, _("%s: Cannot create symbolic "
+				"link to '%s': max attempts (%d) reached\n"),
+				PROGRAM_NAME, stdin_tmp_dir, name, MAX_FILE_CREATION_TRIES);
 			free(name);
 			return 0;
 		}
 
-		snprintf(dest, sizeof(dest), "%s/%s-%d", stdin_tmp_dir,
+		snprintf(dest, sizeof(dest), "%s/%s-%zu", stdin_tmp_dir,
 			name, suffix);
 	}
 
