@@ -1,23 +1,8 @@
-/* 
+/*
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* name_cleaner.c -- functions to sanitize filenames */
@@ -501,8 +486,8 @@ bleach_files(char **names)
 	int do_edit = 0, edited_names = 0;
 	struct bleach_t *bfiles = (struct bleach_t *)NULL;
 
-	size_t f = 0, i = 1;
-	for (; names[i]; i++) {
+	size_t f = 0;
+	for (size_t i = 1; names[i]; i++) {
 		char *dstr = unescape_str(names[i], 0);
 		if (!dstr) {
 			xerror(_("bleach: '%s': Error unescaping filename\n"), names[i]);
@@ -518,12 +503,12 @@ bleach_files(char **names)
 		}
 
 		char *sl = strrchr(names[i], '/');
-		char *p = clean_file_name((sl && *(sl + 1)) ? sl + 1 : names[i]);
+		char *p = clean_file_name((sl && sl[1]) ? sl + 1 : names[i]);
 		if (!p)
 			continue;
 
 		/* Nothing to clean. Skip this one */
-		char *n = (sl && *(sl + 1)) ? sl + 1 : names[i];
+		char *n = (sl && sl[1]) ? sl + 1 : names[i];
 		if (*n == *p && strcmp(n, p) == 0) {
 			free(p);
 			continue;
@@ -610,7 +595,7 @@ CONFIRM:
 
 	if (edited_names == -1 || quit_func == 1) { /* ERROR or quit */
 		if (bfiles) {
-			for (i = 0; i < f; i++) {
+			for (size_t i = 0; i < f; i++) {
 				free(bfiles[i].original);
 				free(bfiles[i].replacement);
 			}
@@ -626,7 +611,7 @@ CONFIRM:
 		printf(_("%zu filename(s) will be bleached\n"), f);
 		if (rl_get_y_or_n(_("Continue?"), 0) != 1) {
 			if (bfiles) {
-				for (i = 0; i < f; i++) {
+				for (size_t i = 0; i < f; i++) {
 					free(bfiles[i].original);
 					free(bfiles[i].replacement);
 				}
@@ -644,7 +629,7 @@ CONFIRM:
 	size_t rep_suffix = 1;
 	int exit_status = FUNC_SUCCESS;
 
-	for (i = 0; i < f; i++) {
+	for (size_t i = 0; i < f; i++) {
 		char *o = (bfiles && bfiles[i].original)
 			? bfiles[i].original : (char *)NULL;
 		char *r = (bfiles && bfiles[i].replacement)
