@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* profiles.c -- functions for manipulating user profiles */
@@ -39,7 +24,7 @@
 #include "bookmarks.h"
 #include "checks.h"
 #include "config.h"
-#include "exec.h" // exec_profile
+#include "exec.h" /* exec_profile */
 #include "history.h"
 #include "init.h"
 #include "listing.h"
@@ -148,8 +133,6 @@ profile_set(const char *prof)
 		return FUNC_SUCCESS;
 	}
 
-	int i;
-
 	if (conf.restore_last_path == 1)
 		save_last_path(NULL);
 
@@ -163,8 +146,8 @@ profile_set(const char *prof)
 	if (*prof != 'd' || strcmp(prof, "default") != 0)
 		alt_profile = savestring(prof, strlen(prof));
 
-	i = MAX_WS;
-	while (--i >= 0) {
+	size_t i = MAX_WS;
+	for (; i-- > 0;) {
 		free(workspaces[i].path);
 		workspaces[i].path = (char *)NULL;
 		free(workspaces[i].name);
@@ -175,15 +158,15 @@ profile_set(const char *prof)
 	/* Reset everything */
 	reload_config();
 
-	i = (int)usrvar_n;
-	while (--i >= 0) {
+	i = usrvar_n;
+	for (; i-- > 0;) {
 		free(usr_var[i].name);
 		free(usr_var[i].value);
 	}
 	usrvar_n = 0;
 
-	i = (int)actions_n;
-	while (--i >= 0) {
+	i = actions_n;
+	for (; i-- > 0;) {
 		free(usr_actions[i].name);
 		free(usr_actions[i].value);
 	}
@@ -229,8 +212,8 @@ profile_set(const char *prof)
 	}
 
 	if (paths) {
-		i = (int)path_n;
-		while (--i >= 0)
+		i = path_n;
+		for (; i-- > 0;)
 			free(paths[i].path);
 		free(paths);
 	}
