@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* properties.c -- Home of the p/pp, pc, oc, and stats commands */
@@ -308,8 +293,7 @@ validate_octal_perms(const char *s, const size_t l)
 		return FUNC_FAILURE;
 	}
 
-	size_t i;
-	for (i = 0; s[i]; i++) {
+	for (size_t i = 0; s[i]; i++) {
 		if (s[i] < '0' || s[i] > '7') {
 			xerror(_("pc: '%c': Invalid digit. Values in the range 0-7 "
 				"are expected for each field\n"), s[i]);
@@ -325,8 +309,7 @@ validate_octal_perms(const char *s, const size_t l)
 static int
 validate_symbolic_perms(const char *s)
 {
-	size_t i;
-	for (i = 0; i < 9; i++) {
+	for (size_t i = 0; i < 9; i++) {
 		switch (i) {
 		case 0: /* fallthrough */
 		case 3: /* fallthrough */
@@ -471,8 +454,8 @@ get_common_perms(char **s, int *diff)
 	p.ux = p.gx = p.ox = 'x';
 	int suid = 1, sgid = 1, sticky = 1;
 
-	int i, stat_ready = 0;
-	for (i = 0; s[i]; i++) {
+	int stat_ready = 0;
+	for (size_t i = 0; s[i]; i++) {
 		if (stat(s[i], &a) == -1)
 			continue;
 		if (stat_ready == 1 && a.st_mode != b.st_mode)
@@ -549,8 +532,7 @@ set_file_perms(char **args)
 		return FUNC_SUCCESS;
 	}
 
-	size_t i;
-	for (i = 1; args[i]; i++) {
+	for (size_t i = 1; args[i]; i++) {
 		if (!strchr(args[i], '\\'))
 			continue;
 		char *t = unescape_str(args[i], 0);
@@ -581,7 +563,7 @@ set_file_perms(char **args)
 	int ret = FUNC_SUCCESS;
 	size_t n = 0;
 	const mode_t mode = (mode_t)strtol(octal_str, 0, 8);
-	for (i = 1; args[i]; i++) {
+	for (size_t i = 1; args[i]; i++) {
 		if (fchmodat(XAT_FDCWD, args[i], mode, 0) == FUNC_SUCCESS) {
 			n++;
 		} else {
@@ -649,9 +631,8 @@ get_common_ownership(char **args, int *exit_status, int *diff)
 
 	int common_uid = 1, common_gid = 1;
 	struct stat b;
-	size_t i;
 
-	for (i = 1; args[i]; i++) {
+	for (size_t i = 1; args[i]; i++) {
 		if (stat(args[i], &b) == -1) {
 			xerror("oc: '%s': %s\n", args[i], strerror(errno));
 			*exit_status = errno;
@@ -755,9 +736,9 @@ set_file_owner(char **args)
 
 	/* Change ownership */
 	struct stat a;
-	size_t new_o = 0, new_g = 0, i;
+	size_t new_o = 0, new_g = 0;
 
-	for (i = 1; args[i]; i++) {
+	for (size_t i = 1; args[i]; i++) {
 		if (stat(args[i], &a) == -1) {
 			xerror("stat: '%s': %s\n", args[i], strerror(errno));
 			free(new_own);
@@ -897,8 +878,7 @@ get_color_age(const time_t t, char *str, const size_t len)
 static int
 xattr_val_is_printable(const char *val, const size_t len)
 {
-	size_t i;
-	for (i = 0; i < len; i++)
+	for (size_t i = 0; i < len; i++)
 		if (val[len] < ' ') /* Control char (== non-printable) */
 			return 0;
 
@@ -1608,6 +1588,7 @@ get_total_size(char *filename, int *status)
 		fputs(df_c, stdout);
 		fflush(stdout);
 	}
+#undef SCANNING_MSG
 
 	return total_size;
 }
@@ -1724,6 +1705,7 @@ print_dir_items(const char *dir, const int file_perm)
 		fputs(df_c, stdout);
 		fflush(stdout);
 	}
+#undef COUNTING_MSG
 
 	char read_err[5 + (MAX_COLOR * 2)]; *read_err = '\0';
 	if (info.status != 0)
