@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* remote.c -- functions to manage remotes */
@@ -48,8 +33,7 @@ remotes_list(void)
 		return FUNC_SUCCESS;
 	}
 
-	size_t i;
-	for (i = 0; i < remotes_n; i++) {
+	for (size_t i = 0; i < remotes_n; i++) {
 		if (!remotes[i].name)
 			continue;
 		printf(_("Name: %s%s%s\n"), BOLD, remotes[i].name, df_c);
@@ -102,10 +86,10 @@ get_remote(char *name)
 	if (dequote_remote_name(name) == FUNC_FAILURE)
 		return (-1);
 
-	int i = (int)remotes_n,
-		found = 0;
+	size_t i = remotes_n;
+	int found = 0;
 
-	while (--i >= 0) {
+	for (; i-- > 0;) {
 		if (*name == *remotes[i].name && strcmp(name, remotes[i].name) == 0) {
 			found = 1;
 			break;
@@ -122,7 +106,7 @@ get_remote(char *name)
 		return (-1);
 	}
 
-	return i;
+	return i > INT_MAX ? INT_MAX : (int)i;
 }
 
 static int
@@ -352,10 +336,9 @@ automount_remotes(void)
 	if (remotes_n == 0)
 		return FUNC_SUCCESS;
 
-	int i = (int)remotes_n;
 	int exit_status = FUNC_SUCCESS;
 
-	while (--i >= 0) {
+	for (size_t i = remotes_n; i-- > 0;) {
 		if (remotes[i].name && remotes[i].auto_mount == 1
 		&& remotes[i].mountpoint && remotes[i].mount_cmd) {
 
@@ -395,9 +378,9 @@ autounmount_remotes(void)
 	if (remotes_n == 0)
 		return FUNC_SUCCESS;
 
-	int i = (int)remotes_n, exit_status = FUNC_SUCCESS;
+	int exit_status = FUNC_SUCCESS;
 
-	while (--i >= 0) {
+	for (size_t i = remotes_n; i-- > 0;) {
 		if (remotes[i].name && remotes[i].auto_unmount == 1
 		&& remotes[i].mountpoint && remotes[i].unmount_cmd) {
 
