@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* search.c -- functions for the search system */
@@ -269,11 +254,10 @@ get_glob_matches(char **gfiles, const char *search_path,
 {
 	struct search_t *matches = xnmalloc(g + 1, sizeof(struct search_t));
 
-	size_t i;
 	int n = 0;
 	struct stat attr;
 
-	for (i = 0; gfiles[i]; i++) {
+	for (size_t i = 0; gfiles[i]; i++) {
 		if (SELFORPARENT(gfiles[i]))
 			continue;
 
@@ -299,8 +283,8 @@ get_glob_matches(char **gfiles, const char *search_path,
 		/* No search_path */
 		/* If searching in CWD, take into account the file's ELN
 		 * when calculating its length. */
-		size_t j, f = 0;
-		for (j = 0; file_info[j].name; j++) {
+		size_t f = 0;
+		for (size_t j = 0; file_info[j].name; j++) {
 			if (!matches[n].name || *matches[n].name != *file_info[j].name
 			|| strcmp(matches[n].name, file_info[j].name) != 0)
 				continue;
@@ -383,13 +367,13 @@ get_glob_matches_invert(char **gfiles, const char *search_path,
 	if (search_path)
 		return get_non_matches_from_search_path(search_path, gfiles, file_type);
 
-	filesn_t i, j, n = 0;
+	filesn_t n = 0;
 	struct search_t *matches = xnmalloc((size_t)files + 1, sizeof(struct search_t));
 
-	for (i = 0; file_info[i].name; i++) {
+	for (filesn_t i = 0; file_info[i].name; i++) {
 		int f = 0;
 
-		for (j = 0; gfiles[j]; j++) {
+		for (filesn_t j = 0; gfiles[j]; j++) {
 			if (*gfiles[j] == *file_info[i].name
 			&& strcmp(gfiles[j], file_info[i].name) == 0) {
 				f = 1;
@@ -418,8 +402,7 @@ get_glob_longest(struct search_t *matches, int *longest_eln,
 {
 	int search_path = (*eln_pad == -1);
 
-	size_t i;
-	for (i = 0; matches[i].name; i++) {
+	for (size_t i = 0; matches[i].name; i++) {
 		if (matches[i].len <= *longest_match)
 			continue;
 
@@ -436,7 +419,7 @@ get_glob_longest(struct search_t *matches, int *longest_eln,
 		*longest_match += (size_t)ICON_LEN;
 
 	int longest_name = 0;
-	for (i = 0; matches[i].name; i++) {
+	for (size_t i = 0; matches[i].name; i++) {
 		if (matches[i].eln > longest_name)
 			longest_name = matches[i].eln;
 	}
@@ -480,9 +463,10 @@ calculate_glob_output_columns(const size_t flongest, const int found)
 {
 	int columns_n = 0;
 
+	unsigned short tcols = DEFAULT_WIN_COLS;
 	struct winsize w;
-	ioctl(STDOUT_FILENO, TIOCGWINSZ, &w);
-	unsigned short tcols = w.ws_col;
+	if (ioctl(STDOUT_FILENO, TIOCGWINSZ, &w) != -1 && w.ws_col > 0)
+		tcols = w.ws_col;
 
 	if (flongest == 0 || flongest > tcols)
 		columns_n = 1;
@@ -624,8 +608,7 @@ search_glob(char **args)
 
 	/* Free stuff */
 	if (list) {
-		size_t i;
-		for (i = 0; list[i].name; i++)
+		for (size_t i = 0; list[i].name; i++)
 			free(list[i].name);
 		free(list);
 	}
@@ -785,8 +768,9 @@ static size_t
 calc_columns(const size_t longest_file_len, const size_t matches)
 {
 	struct winsize w;
-	ioctl(STDOUT_FILENO, TIOCGWINSZ, &w);
-	unsigned short termcols = w.ws_col > 0 ? w.ws_col : 80;
+	unsigned short termcols = DEFAULT_WIN_COLS;
+	if (ioctl(STDOUT_FILENO, TIOCGWINSZ, &w) != -1 && w.ws_col > 0)
+		termcols = w.ws_col;
 
 	size_t columns;
 	if (longest_file_len == 0 || longest_file_len > termcols)
@@ -835,8 +819,7 @@ print_regex_matches(const mode_t file_type, struct dirent **reg_dirlist,
 
 	size_t matches = 0; /* Number of filtered matches */
 
-	int i = (int)total;
-	while (--i >= 0) {
+	for (size_t i = total; i-- > 0;) {
 		int index = regex_index[i];
 
 		if (file_type != 0 && check_regex_file_type(reg_dirlist,
@@ -859,8 +842,7 @@ print_regex_matches(const mode_t file_type, struct dirent **reg_dirlist,
 
 	size_t last_col = 0, cur_col = 0;
 
-	i = (int)matches;
-	while (--i >= 0) {
+	for (size_t i = matches; i-- > 0;) {
 		cur_col++;
 		count++;
 
@@ -911,7 +893,7 @@ search_regex(char **args)
 		return FUNC_SUCCESS;
 
 	struct dirent **reg_dirlist = (struct dirent **)NULL;
-	int tmp_files = - 1;
+	int tmp_files = -1;
 
 	if (search_path && *search_path) {
 		if (chdir_search_path(&search_path, args[1]) == FUNC_FAILURE)
@@ -933,8 +915,6 @@ search_regex(char **args)
 	search_query = construct_regex_query(&args[0], invert, &regex_found);
 
 	/* Get matches */
-	size_t i;
-
 	regex_t regex_files;
 	int reg_flags = conf.case_sens_search == 1 ? (REG_NOSUB | REG_EXTENDED)
 		: (REG_NOSUB | REG_EXTENDED | REG_ICASE);
@@ -953,7 +933,7 @@ search_regex(char **args)
 	const size_t max =
 		(search_path && *search_path) ? (size_t)tmp_files : (size_t)files;
 
-	for (i = 0; i < max; i++) {
+	for (size_t i = 0; i < max; i++) {
 		char *name = (search_path && *search_path) ? reg_dirlist[i]->d_name
 		: file_info[i].name;
 
