@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* selection.c -- files selection functions */
@@ -82,8 +67,7 @@ save_sel(void)
 		return FUNC_FAILURE;
 	}
 
-	size_t i;
-	for (i = 0; i < sel_n; i++) {
+	for (size_t i = 0; i < sel_n; i++) {
 		fputs(sel_elements[i].name, fp);
 		fputc('\n', fp);
 	}
@@ -196,7 +180,7 @@ load_matches_invert_nocwd(glob_t *gbuf, struct dirent **ent,
 #endif /* !_DIRENT_HAVE_D_TYPE */
 			continue;
 
-		int j = (int)gbuf->gl_pathc;
+		int j = gbuf->gl_pathc > INT_MAX ? INT_MAX : (int)gbuf->gl_pathc;
 		while (--j >= 0) {
 			if (*ent[i]->d_name == *gbuf->gl_pathv[j]
 			&& strcmp(ent[i]->d_name, gbuf->gl_pathv[j]) == 0)
@@ -233,8 +217,7 @@ load_matches(glob_t *gbuf, const mode_t filetype, int *matches)
 	char **list = xnmalloc(gbuf->gl_pathc + 2, sizeof(char *));
 	const mode_t type = convert_filetype_mask(filetype);
 
-	int i = (int)gbuf->gl_pathc;
-	while (--i >= 0) {
+	for (size_t i = gbuf->gl_pathc; i-- > 0;) {
 		char *basename = strrchr(gbuf->gl_pathv[i], '/');
 		if (!basename && SELFORPARENT(gbuf->gl_pathv[i]))
 			continue;
@@ -410,8 +393,8 @@ sel_regex_nocwd(regex_t regex, const char *sel_path, const mode_t filetype,
 
 	const mode_t type = convert_filetype_mask(filetype);
 
-	int i = (int)filesn;
-	while (--i >= 0) {
+	size_t i = filesn >= 0 ? (size_t)filesn : 0;
+	for (; i-- > 0;) {
 		if (filetype != 0) {
 			struct stat attr;
 			if (lstat(list[i]->d_name, &attr) != -1
@@ -481,7 +464,7 @@ sel_regex(char *str, const char *sel_path, const mode_t filetype)
 /* Convert file type into a macro that can be decoded by stat(3).
  * If file type is specified, matches will be checked against
  * this value. */
-static mode_t
+static int
 convert_filetype(mode_t *filetype)
 {
 	switch (*filetype) {
@@ -777,6 +760,88 @@ select_pattern(char *arg, const char *dir, const mode_t filetype, int *err)
 	return ret;
 }
 
+/* Reconstruct the list of selections excluding those located in the current
+ * directory. */
+static void
+deselect_files_in_cwd(void)
+{
+	/* Free data about selected files. It will be reconstructed later
+	 * by get_sel_files(). */
+	free(sel_devino);
+	sel_devino = (struct devino_t *)NULL;
+
+	struct sel_t *sel = NULL;
+	size_t n = 0;
+
+	for (size_t i = 0; i < sel_n; i++) {
+		if (!is_file_in_cwd(sel_elements[i].name)) {
+			sel = xnrealloc(sel, n + 2, sizeof(sel[0]));
+			sel[n].name =
+				savestring(sel_elements[i].name, strlen(sel_elements[i].name));
+			sel[n].size = (off_t)UNSET;
+			n++;
+		}
+	}
+
+	if (n == 0) { /* All selections are in the current directory. */
+		deselect_all();
+		return;
+	}
+
+	sel[n].name = NULL;
+	sel[n].size = (off_t)UNSET;
+
+	for (size_t i = 0; i < sel_n; i++)
+		free(sel_elements[i].name);
+	free(sel_elements);
+	sel_n = n;
+	sel_elements = sel;
+}
+
+static void
+print_inversion_results(const int new_sel, const int desel, const int errors)
+{
+	if (new_sel > 0) {
+		print_sel_results(new_sel, NULL, NULL, errors);
+		return;
+	}
+
+	save_sel();
+
+	if (errors == 0 && conf.autols == 1)
+		reload_dirlist();
+
+	print_reload_msg(SET_SUCCESS_PTR, xs_cb,
+		_("%zu file(s) deselected\n"), desel);
+	print_reload_msg(NULL, NULL, _("%zu total selected file(s)\n"), sel_n);
+}
+
+/* Invert the list of selections in the current directory. */
+static int
+invert_selection(void)
+{
+	if (sel_n > 0)
+		deselect_files_in_cwd();
+
+	int new_sel = 0;
+	int errors = 0;
+	int desel = 0;
+
+	for (filesn_t i = 0; i < files; i++) {
+		if (file_info[i].sel == 0) {
+			new_sel += select_filename(file_info[i].name, NULL, &errors);
+			file_info[i].sel = 1;
+		} else {
+			file_info[i].sel = 0;
+			desel++;
+		}
+	}
+
+	print_inversion_results(new_sel, desel, errors);
+
+	return (errors != 0);
+}
+
 int
 sel_function(char **args)
 {
@@ -787,6 +852,9 @@ sel_function(char **args)
 		return FUNC_SUCCESS;
 	}
 
+	if (*args[1] == '-' && strcmp(args[1], "--invert") == 0)
+		return invert_selection();
+
 	mode_t filetype = 0;
 	int i, ifiletype = 0, isel_path = 0, new_sel = 0, err = 0, f = 0;
 
@@ -853,8 +921,7 @@ list_selected_files(void)
 	if (ioctl(STDOUT_FILENO, TIOCGWINSZ, &w) == -1)
 		w.ws_row = 24;
 
-	int t_lines = w.ws_row > 0 ? (int)w.ws_row : 24;
-	t_lines -= 2;
+	const int t_lines = (w.ws_row > 0 ? (int)w.ws_row : DEFAULT_WIN_ROWS) - 2;
 
 	size_t counter = 0;
 	size_t i;
@@ -867,7 +934,6 @@ list_selected_files(void)
 
 	flags |= IN_SELBOX_SCREEN;
 	for (i = 0; i < sel_n; i++) {
-		/* if (pager && counter > (term_lines-2)) { */
 		if (conf.pager && counter > (size_t)t_lines) {
 			switch (xgetchar()) {
 			/* Advance one line at a time */
@@ -879,8 +945,7 @@ list_selected_files(void)
 			case 126:
 				counter = 0; /* Page Down */
 				break;
-			/* Stop paging (and set a flag to reenable the pager
-			 * later) */
+			/* Stop paging (and set a flag to reenable the pager later) */
 			case 99: /* fallthrough */  /* 'c' */
 			case 112: /* fallthrough */ /* 'p' */
 			case 113:
@@ -972,17 +1037,17 @@ deselect_entries(char **desel_path, const size_t desel_n, int *error,
 	int i = (int)desel_n;
 
 	while (--i >= 0) {
-		int j, k, desel_index = -1;
+		int j, desel_index = -1;
 
 		if (!desel_path[i])
 			continue;
 
 		/* Search the sel array for the path of the entry to be deselected and
 		 * store its index. */
-		k = (int)sel_n;
-		while (--k >= 0) {
+		size_t k = sel_n;
+		for (; k-- > 0;) {
 			if (strcmp(sel_elements[k].name, desel_path[i]) == 0) {
-				desel_index = k;
+				desel_index = k > INT_MAX ? INT_MAX : (int)k;
 				break;
 			}
 		}
@@ -1029,12 +1094,12 @@ static int
 desel_entries(char **desel_elements, const size_t desel_n, const int desel_screen)
 {
 	char **desel_path = (char **)NULL;
-	int i = (int)desel_n;
+	size_t i = desel_n;
 
 	/* Get entries to be deselected */
 	if (desel_screen == 1) { /* Coming from the deselect screen */
 		desel_path = xnmalloc(desel_n, sizeof(char *));
-		while (--i >= 0) {
+		for (; i-- > 0;) {
 			const int desel_int = atoi(desel_elements[i]);
 			if (desel_int == INT_MIN) {
 				desel_path[i] = (char *)NULL;
@@ -1061,8 +1126,8 @@ desel_entries(char **desel_elements, const size_t desel_n, const int desel_scree
 		sel_elements = xnrealloc(sel_elements, sel_n, sizeof(struct sel_t));
 
 	/* Deallocate local arrays. */
-	i = (int)desel_n;
-	while (--i >= 0) {
+	i = desel_n;
+	for (; i-- > 0;) {
 		if (desel_screen == 1)
 			free(desel_path[i]);
 		free(desel_elements[i]);
@@ -1088,8 +1153,8 @@ desel_entries(char **desel_elements, const size_t desel_n, const int desel_scree
 int
 deselect_all(void)
 {
-	int i = (int)sel_n;
-	while (--i >= 0) {
+	size_t i = sel_n;
+	for (; i-- > 0;) {
 		free(sel_elements[i].name);
 		sel_elements[i].name = (char *)NULL;
 		sel_elements[i].size = (off_t)UNSET;
@@ -1162,14 +1227,14 @@ get_desel_input(size_t *n)
 static inline void
 free_desel_elements(const size_t desel_n, char ***desel_elements)
 {
-	int i = (int)desel_n;
-	while (--i >= 0)
+	size_t i = desel_n;
+	for (; i-- > 0;)
 		free((*desel_elements)[i]);
 	free(*desel_elements);
 }
 
 static int
-handle_alpha_entry(const int i, const size_t desel_n, char **desel_elements)
+handle_alpha_entry(const size_t i, const size_t desel_n, char **desel_elements)
 {
 	if (*desel_elements[i] == 'e' && !desel_elements[i][1]) {
 		free_desel_elements(desel_n, &desel_elements);
@@ -1197,7 +1262,7 @@ handle_alpha_entry(const int i, const size_t desel_n, char **desel_elements)
 }
 
 static int
-valid_desel_eln(const int i, const size_t desel_n, char **desel_elements)
+valid_desel_eln(const size_t i, const size_t desel_n, char **desel_elements)
 {
 	const int n = atoi(desel_elements[i]);
 
@@ -1298,8 +1363,8 @@ deselect(char **args)
 	size_t desel_n = 0;
 	char **desel_elements = get_desel_input(&desel_n);
 
-	int i = (int)desel_n;
-	while (--i >= 0) {
+	size_t i = desel_n;
+	for (; i-- > 0;) {
 		if (!is_number(desel_elements[i])) /* Only for 'q', 'e', and '*' */
 			return handle_alpha_entry(i, desel_n, desel_elements);
 
