@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* settings.h - User settings default values */
@@ -511,7 +496,7 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
  * and QUOTING_STYLE_DOUBLE_QUOTES */
 #define DEF_QUOTING_STYLE QUOTING_STYLE_BACKSLASH
 #define DEF_EXT_CMD_OK 1
-#define DEF_FILES_COUNTER 1
+#define DEF_FILE_COUNTER 1
 #define DEF_FOLLOW_SYMLINKS 1
 #define DEF_FOLLOW_SYMLINKS_LONG 0
 #define DEF_FULL_DIR_SIZE 0
@@ -536,7 +521,10 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #define DEF_LONG_VIEW 0
 #define DEF_MAX_DIRHIST 100
 #define DEF_MAX_FILES UNSET
-#define DEF_MAX_NAME_LEN 20
+/* Either UNSET, a positive integer, or
+ * MAX_NAMELEN_AUTO (term_columns * MAX_NAMELEN_AUTO_RATIO) */
+#define DEF_MAX_NAME_LEN MAX_NAMELEN_AUTO
+#define DEF_MAX_NAMELEN_AUTO_RATIO 25 /* 25% of terminal columns */
 #define DEF_MAX_HIST 1000
 #define DEF_MAX_JUMP_TOTAL_RANK 100000
 #define DEF_MAX_LOG 1000
@@ -575,6 +563,12 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #define DEF_REPORT_CWD 0 /* Report CWD to terminal via OSC-7 escape sequence */
 #define DEF_RESTORE_LAST_PATH 1
 #define DEF_RL_EDIT_MODE 1
+/* Check filenames safety with 'n' and 'm' commands. Allowed values:
+ * SAFENAMES_NOCHECK: no check is performed
+ * SAFENAMES_BASIC: basic checks such as leading/trailing whitespaces, ctrl chars, etc
+ * SAFENAMES_STRICT: basic + disallow shell metacharacters
+ * SAFENAMES_POSIX: basic + allow only chars in the POSIX Portable Filename Character Set */
+#define DEF_SAFE_FILENAMES SAFENAMES_BASIC
 #define DEF_SECURE_CMDS 0
 #define DEF_SECURE_ENV 0
 #define DEF_SECURE_ENV_FULL 0
@@ -639,6 +633,9 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #define MIN_SCREEN_WIDTH 20
 #define MIN_SCREEN_HEIGHT 5
 
+#define DEFAULT_WIN_COLS 80
+#define DEFAULT_WIN_ROWS 24
+
 /* If running colorless, let's try to use this prompt. If not available,
  * fallback to DEFAULT_PROMPT_NO_COLOR. */
 #define DEF_PROMPT_NO_COLOR_NAME "clifm-no-color"
