@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* sort.c -- functions used to sort files */
@@ -381,8 +366,7 @@ re_sort_files_list(void)
 static inline int
 set_sort_by_name(char **arg)
 {
-	size_t i;
-	for (i = 0; i <= SORT_TYPES; i++) {
+	for (size_t i = 0; i <= SORT_TYPES; i++) {
 		if (*(*arg) == *sort_methods[i].name
 		&& strcmp(*arg, sort_methods[i].name) == 0) {
 			if (conf.light_mode == 1
