@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* strings.c -- misc string manipulation functions */
@@ -48,6 +33,7 @@
 
 #if defined(__OpenBSD__)
 typedef char *rl_cpvfunc_t;
+typedef void rl_macro_print_func_t (const char *, const char *, int, const char *);
 # include <ereadline/readline/readline.h>
 #else
 # include <readline/readline.h>
@@ -142,11 +128,11 @@ count_chars(const char *restrict s, const char c)
 size_t
 count_words(size_t *start_word, size_t *full_word)
 {
-	size_t words = 0, i = 0, first_non_space = 0;
+	size_t words = 0, first_non_space = 0;
 	char quote = 0;
 	char *b = rl_line_buffer;
 
-	for (; b[i]; i++) {
+	for (size_t i = 0; b[i]; i++) {
 		/* Keep track of open quotes. */
 		if (b[i] == '\'' || b[i] == '"')
 			quote = quote == b[i] ? 0 : b[i];
@@ -244,9 +230,8 @@ xstrrpbrk(char *s, const char *accept)
 
 	const size_t l = strlen(s);
 
-	int i = (int)l, j;
-	while (--i >= 0) {
-		for (j = 0; accept[j]; j++) {
+	for (size_t i = l; i-- > 0;) {
+		for (size_t j = 0; accept[j]; j++) {
 			if (s[i] == accept[j])
 				return s + i;
 		}
@@ -363,14 +348,14 @@ xstrverscmp(const char *s1, const char *s2)
 
 	if (!conf.case_sens_list) {
 		c1 = (unsigned char)TOLOWER(*p1);
-		++p1;
+		p1++;
 		c2 = (unsigned char)TOLOWER(*p2);
-		++p2;
+		p2++;
 	} else {
 		c1 = *p1;
 		c2 = *p2;
-		++p1;
-		++p2;
+		p1++;
+		p2++;
 	}
 
 	/* Hint: '0' is a digit too */
@@ -383,14 +368,14 @@ xstrverscmp(const char *s1, const char *s2)
 		state = next_state[state];
 		if (!conf.case_sens_list) {
 			c1 = (unsigned char)TOLOWER(*p1);
-			++p1;
+			p1++;
 			c2 = (unsigned char)TOLOWER(*p2);
-			++p2;
+			p2++;
 		} else {
 			c1 = *p1;
 			c2 = *p2;
-			++p1;
-			++p2;
+			p1++;
+			p2++;
 		}
 		state += (c1 == '0') + (IS_DIGIT(c1) != 0);
 	}
@@ -401,10 +386,10 @@ xstrverscmp(const char *s1, const char *s2)
 	case VCMP: return diff;
 	case VLEN:
 		while (*p1 && IS_DIGIT(*p1)) {
-			++p1;
+			p1++;
 			if (!*p2 || !IS_DIGIT(*p2))
 				return 1;
-			++p2;
+			p2++;
 		}
 		return (*p2 && IS_DIGIT(*p2)) ? -1 : diff;
 
@@ -459,11 +444,11 @@ u8truncstr(char *restrict str, const size_t max)
 	if (mbstowcs(buf, str, NAME_BUF_SIZE) == (size_t)-1)
 		return 0;
 
-	int i, bmax = (int)max;
+	int bmax = (int)max;
 	if (bmax < 0)
 		bmax = conf.max_name_len;
 
-	for (i = 0; buf[i]; i++) {
+	for (size_t i = 0; buf[i]; i++) {
 		int l = wcwidth(buf[i]);
 		if (len + l > bmax) {
 			buf[i] = L'\0';
@@ -665,18 +650,14 @@ strbfrlst(char *str, const char c)
 	*q = '\0';
 
 	const size_t buf_len = (size_t)(q - str);
-	char *buf = malloc(buf_len + 1);
-	if (!buf) {
-		*q = c;
-		return (char *)NULL;
-	}
+	char *buf = xnmalloc(buf_len + 1, sizeof(char));
 
 	xstrsncpy(buf, str, buf_len + 1);
 	*q = c;
 	return buf;
 }
 
-/* Returns the string between first ocurrence of A and the first
+/* Return the string between the first ocurrence of A and the first
  * ocurrence of B in STR, or NULL if: there is nothing between A and
  * B, or A and/or B are not found. */
 char *
@@ -703,12 +684,7 @@ strbtw(char *str, const char a, const char b)
 	*pb = '\0';
 
 	const size_t buf_len = (size_t)(pb - pa);
-	char *buf = malloc(buf_len + 1);
-
-	if (!buf) {
-		*pb = b;
-		return (char *)NULL;
-	}
+	char *buf = xnmalloc(buf_len + 1, sizeof(char));
 
 	xstrsncpy(buf, pa + 1, buf_len + 1);
 	*pb = b;
@@ -765,7 +741,7 @@ gen_rand_str(const size_t len)
 	char *p = xnmalloc(len + 1, sizeof(char));
 	char *str = p;
 
-	int x = (int)len;
+	int x = len > INT_MAX ? INT_MAX : (int)len;
 	while (x--) {
 #ifndef HAVE_ARC4RANDOM
 		const long i = random() % (int)(sizeof(charset) - 1);
@@ -829,8 +805,7 @@ remove_quotes(char *str)
 static void
 init_quoted_words(void)
 {
-	size_t i;
-	for (i = 0; i < QWORDS_ARRAY_LEN; i++)
+	for (size_t i = 0; i < QWORDS_ARRAY_LEN; i++)
 		quoted_words[i] = -1;
 }
 
@@ -849,8 +824,7 @@ update_quoted_words_index(const size_t start, const size_t added_items)
 	const size_t s = start + 1;
 	const size_t n = added_items - (added_items > 0 ? 1 : 0);
 
-	size_t i;
-	for (i = 0; i < QWORDS_ARRAY_LEN; i++)
+	for (size_t i = 0; i < QWORDS_ARRAY_LEN; i++)
 		if (quoted_words[i] > -1 && (size_t)quoted_words[i] >= s)
 			quoted_words[i] += (int)n;
 }
@@ -859,8 +833,7 @@ update_quoted_words_index(const size_t start, const size_t added_items)
 static int
 is_quoted_word(const size_t index)
 {
-	size_t i;
-	for (i = 0; i < QWORDS_ARRAY_LEN; i++)
+	for (size_t i = 0; i < QWORDS_ARRAY_LEN; i++)
 		if (index == (size_t)quoted_words[i])
 			return 1;
 
@@ -967,9 +940,9 @@ split_str(char *str, const int update_args)
 				xerror(_("%s: Missing '%c'\n"), PROGRAM_NAME, close);
 				free(buf);
 				buf = (char *)NULL;
-				int i = (int)words;
+				size_t i = words;
 
-				while (--i >= 0)
+				for (; i-- > 0;)
 					free(substr[i]);
 				free(substr);
 
@@ -1033,9 +1006,9 @@ split_str(char *str, const int update_args)
 				/* Free stuff and return. */
 				free(buf);
 				buf = (char *)NULL;
-				int i = (int)words;
+				size_t i = words;
 
-				while (--i >= 0)
+				for (; i-- > 0;)
 					free(substr[i]);
 				free(substr);
 				return (char **)NULL;
@@ -1266,8 +1239,7 @@ check_shell_functions(const char *str)
 		NULL
 	};
 
-	size_t i;
-	for (i = 0; funcs[i]; i++) {
+	for (size_t i = 0; funcs[i]; i++) {
 		const size_t f_len = strlen(funcs[i]);
 		if (*str == *funcs[i] && strncmp(str, funcs[i], f_len) == 0)
 			return 1;
@@ -1412,11 +1384,11 @@ expand_tag(char ***args, const int tag_index)
 static void
 expand_tags(char ***substr)
 {
-	size_t ntags = 0, i;
+	size_t ntags = 0;
 	int *tag_index = (int *)NULL;
 	struct stat a;
 
-	for (i = 0; (*substr)[i]; i++) {
+	for (size_t i = 0; (*substr)[i]; i++) {
 		if (*(*substr)[i] == 't' && *((*substr)[i] + 1) == ':'
 		&& lstat((*substr)[i], &a) == -1) {
 			tag_index = xnrealloc(tag_index, ntags + 2, sizeof(int));
@@ -1429,7 +1401,7 @@ expand_tags(char ***substr)
 	if (ntags == 0)
 		return;
 
-	for (i = 0; i < ntags; i++) {
+	for (size_t i = 0; i < ntags; i++) {
 		const size_t tn = expand_tag(substr, tag_index[i]);
 		/* TN is the number of files tagged as SUBSTR[TAG_INDEX[I]]
 		 * Let's update the index of the next tag expression using this
@@ -1456,8 +1428,8 @@ expand_mime_type_filter(const char *pattern)
 	char **t = xnmalloc((size_t)files + 1, sizeof(char *));
 	char buf[PATH_MAX + 1];
 
-	filesn_t i, n = 0;
-	for (i = 0; i < files; i++) {
+	filesn_t n = 0;
+	for (filesn_t i = 0; i < files; i++) {
 		char *name = file_info[i].name;
 		if (virtual_dir == 1) {
 			*buf = '\0';
@@ -1596,9 +1568,9 @@ insert_fields(char ***dst, char ***src, const size_t i, size_t *num)
 	char **tail = args_n > i /* Substraction must be bigger than zero */
 		? xnmalloc(args_n - i + 1, sizeof(char *)) : (char **)NULL;
 
-	size_t t, n = 0;
+	size_t n = 0;
 	if (tail) {
-		for (t = i + 1; (*dst)[t]; t++)
+		for (size_t t = i + 1; (*dst)[t]; t++)
 			tail[n++] = strdup((*dst)[t]);
 		tail[n] = (char *)NULL;
 	}
@@ -1689,12 +1661,10 @@ eln_expand(char ***substr, const size_t i)
 static void
 expand_sel(char ***substr)
 {
-	size_t i = 0;
-
 	if (sel_n == 0)
 		return;
 
-	size_t j = 0;
+	size_t i = 0, j = 0;
 	char **sel_array = xnmalloc(args_n + sel_n + 2, sizeof(char *));
 
 	/* 1. Copy all words before 'sel' */
@@ -1744,9 +1714,8 @@ expand_sel_keyword(char ***substr)
 		return;
 
 	struct stat a;
-	size_t i;
 
-	for (i = 1; (*substr)[i]; i++) {
+	for (size_t i = 1; (*substr)[i]; i++) {
 		if (*(*substr)[i] != 's')
 			continue;
 
@@ -1762,7 +1731,7 @@ expand_sel_keyword(char ***substr)
 	}
 
 	/* If "sel" is last, and there are selected elements, and the command
-	 * is either "cp" or "mv", emulate "c" or "m" respectivelly: later,
+	 * is either "cp" or "mv", emulate "c" or "m" respectively: later,
 	 * and final "." will be added to the command, so that we avoid
 	 * overwriting files. */
 	if (sel_n == 0 || is_sel == 0 || sel_is_last == 0)
@@ -1794,8 +1763,8 @@ expand_workspace(char **name)
 
 	char *deq_str = unescape_str(ws_name, 0);
 	char *tmp_name = deq_str ? deq_str : ws_name;
-	size_t i = 0;
-	for (i = 0; i < MAX_WS; i++) {
+
+	for (size_t i = 0; i < MAX_WS; i++) {
 		if (!workspaces[i].path || !workspaces[i].name
 		|| *tmp_name != *workspaces[i].name
 		|| strcmp(tmp_name, workspaces[i].name) != 0)
@@ -1821,12 +1790,11 @@ expand_workspace(char **name)
 static int
 expand_bm_name(char **name)
 {
-	size_t j;
 	int bm_exp = FUNC_FAILURE;
 	char *p = unescape_str(*name + 2, 0);
 	char *n = p ? p : *name + 2;
 
-	for (j = 0; j < bm_n; j++) {
+	for (size_t j = 0; j < bm_n; j++) {
 		if (!bookmarks[j].name || *n != *bookmarks[j].name
 		|| strcmp(n, bookmarks[j].name) != 0)
 			continue;
@@ -1852,8 +1820,7 @@ expand_int_var(char **name)
 {
 	char *var_name = (*name) + 1;
 
-	int j = (int)usrvar_n;
-	while (--j >= 0) {
+	for (size_t j = usrvar_n; j-- > 0;) {
 		if (*var_name != *usr_var[j].name
 		|| strcmp(var_name, usr_var[j].name) != 0 || !usr_var[j].value)
 			continue;
@@ -1874,13 +1841,12 @@ expand_file_type(char ***substr)
 	&& (*substr)[0][1] == 't' && !(*substr)[0][2]))
 		return;
 
-	size_t i = 0;
 	struct stat a;
 
 	int *file_type_array = xnmalloc(INT_ARRAY_MAX, sizeof(int));
 	size_t file_type_n = 0;
 
-	for (i = 0; (*substr)[i] && file_type_n < INT_ARRAY_MAX; i++) {
+	for (size_t i = 0; (*substr)[i] && file_type_n < INT_ARRAY_MAX; i++) {
 		if (*(*substr)[i] != '=' || !(*substr)[i][1])
 			continue;
 
@@ -1898,7 +1864,7 @@ expand_file_type(char ***substr)
 	}
 
 	size_t old_ft = 0;
-	for (i = 0; i < file_type_n; i++) {
+	for (size_t i = 0; i < file_type_n; i++) {
 		int index = file_type_array[i] + (int)old_ft;
 
 		char **p =
@@ -1909,13 +1875,12 @@ expand_file_type(char ***substr)
 		if (p) {
 			char **ret = insert_fields(substr, &p, (size_t)index, &c);
 
-			size_t n;
-			for (n = 0; p[n]; n++)
+			for (size_t n = 0; p[n]; n++)
 				free(p[n]);
 			free(p);
 
 			if (ret) {
-				for (n = 0; n <= args_n; n++)
+				for (size_t n = 0; n <= args_n; n++)
 					free((*substr)[n]);
 				free((*substr));
 
@@ -1935,12 +1900,11 @@ expand_file_type(char ***substr)
 static void
 expand_mime_type(char ***substr)
 {
-	size_t i = 0;
 	int *mime_type_array = xnmalloc(INT_ARRAY_MAX, sizeof(int));
 	size_t mime_type_n = 0;
 	struct stat a;
 
-	for (i = 0; (*substr)[i] && mime_type_n < INT_ARRAY_MAX; i++) {
+	for (size_t i = 0; (*substr)[i] && mime_type_n < INT_ARRAY_MAX; i++) {
 		if (*(*substr)[i] == '@' && *((*substr)[i] + 1)
 		&& lstat((*substr)[i], &a) == -1) {
 			mime_type_array[mime_type_n] = (int)i;
@@ -1954,7 +1918,7 @@ expand_mime_type(char ***substr)
 	}
 
 	size_t old_mt = 0;
-	for (i = 0; i < mime_type_n; i++) {
+	for (size_t i = 0; i < mime_type_n; i++) {
 		int index = mime_type_array[i] + (int)old_mt;
 
 		char **p = *((*substr)[index] + 1)
@@ -1996,13 +1960,12 @@ expand_mime_type(char ***substr)
 static void
 expand_bookmarks(char ***substr)
 {
-	size_t i = 0;
 	struct stat a;
 
 	int *bm_array = xnmalloc(INT_ARRAY_MAX, sizeof(int));
 	size_t bn = 0;
 
-	for (i = 0; (*substr)[i] && bn < INT_ARRAY_MAX; i++) {
+	for (size_t i = 0; (*substr)[i] && bn < INT_ARRAY_MAX; i++) {
 		if (*(*substr)[i] == 'b' && *((*substr)[i] + 1) == ':'
 		&& !*((*substr)[i] + 2) && lstat((*substr)[i], &a) == -1) {
 			bm_array[bn] = (int)i;
@@ -2011,7 +1974,7 @@ expand_bookmarks(char ***substr)
 	}
 
 	size_t old_bm = 0;
-	for (i = 0; i < bn; i++) {
+	for (size_t i = 0; i < bn; i++) {
 		int index = bm_array[i] + (int)old_bm;
 		char **p = get_bm_paths();
 		size_t c = 0;
@@ -2021,8 +1984,7 @@ expand_bookmarks(char ***substr)
 			free(p);
 
 			if (ret) {
-				size_t n;
-				for (n = 0; n <= args_n; n++)
+				for (size_t n = 0; n <= args_n; n++)
 					free((*substr)[n]);
 				free((*substr));
 
@@ -2044,8 +2006,7 @@ expand_glob(char ***substr, const int *glob_array, const size_t glob_n)
 	size_t old_pathc = 0;
 	size_t i = 0;
 
-	size_t g = 0;
-	for (g = 0; g < (size_t)glob_n; g++) {
+	for (size_t g = 0; g < (size_t)glob_n; g++) {
 		glob_t globbuf;
 
 		if (is_quoted_word((size_t)glob_array[g] + old_pathc))
@@ -2123,12 +2084,12 @@ static int
 expand_word(char ***substr, const int *word_array, const size_t word_n)
 {
 	size_t old_pathc = 0;
-	size_t w = 0, i = 0;
+	size_t i = 0;
 
 	const int is_sel_cmd =
 		(strcmp((*substr)[0], "s") == 0 || strcmp((*substr)[0], "sel") == 0);
 
-	for (w = 0; w < word_n; w++) {
+	for (size_t w = 0; w < word_n; w++) {
 		if (is_sel_cmd == 1) {
 			/* If the command is 'sel', perform only command substitution
 			 * and environment variables expansion. Otherwise, wordexp(3)
@@ -2166,14 +2127,13 @@ expand_word(char ***substr, const int *word_array, const size_t word_n)
 					xerror(_("%s: '%s': Error quoting filename\n"),
 						PROGRAM_NAME, wordbuf.we_wordv[i]);
 
-					size_t k = 0;
-					for (k = 0; k < j; k++)
+					for (size_t k = 0; k < j; k++)
 						free(word_cmd[k]);
 					free(word_cmd);
 
 					word_cmd = (char **)NULL;
 
-					for (k = 0; k <= args_n; k++)
+					for (size_t k = 0; k <= args_n; k++)
 						free((*substr)[k]);
 					free((*substr));
 					return (-1);
@@ -2207,16 +2167,16 @@ expand_word(char ***substr, const int *word_array, const size_t word_n)
 static size_t
 check_ranges(char ***substr, int **range_array)
 {
-	size_t i = 0, j = 0, n = 0;
+	size_t n = 0;
 	struct stat a;
 
-	for (i = 0; i <= args_n; i++) {
+	for (size_t i = 0; i <= args_n; i++) {
 		if (!(*substr)[i] || is_quoted_word(i) || lstat((*substr)[i], &a) != -1)
 			continue;
 
 		const size_t len = strlen((*substr)[i]);
 
-		for (j = 0; (*substr)[i][j]; j++) {
+		for (size_t j = 0; (*substr)[i][j]; j++) {
 			/* If some alphabetic char, besides '-', is found in the
 			 * string, we have no range. */
 			if ((*substr)[i][j] != '-' && !IS_DIGIT((*substr)[i][j]))
@@ -2288,8 +2248,7 @@ expand_range(char *str, int listdir)
 
 	filesn_t *buf = xcalloc((size_t)(asecond - afirst) + 2, sizeof(filesn_t));
 
-	filesn_t i, j = 0;
-	for (i = afirst; i <= asecond; i++) {
+	for (filesn_t i = afirst, j = 0; i <= asecond; i++) {
 		buf[j] = i;
 		j++;
 	}
@@ -2311,9 +2270,8 @@ expand_ranges(char ***substr)
 	}
 
 	size_t old_ranges_n = 0;
-	size_t r = 0;
 
-	for (r = 0; r < ranges_ok; r++) {
+	for (size_t r = 0; r < ranges_ok; r++) {
 		size_t ranges_n = 0;
 		filesn_t *ranges = expand_range((*substr)[range_array[r] +
 			(int)old_ranges_n], 1);
@@ -2435,8 +2393,8 @@ expand_regex(char ***substr)
 				continue;
 
 			/* Make sure the matching filename is not already in the tmp array */
-			filesn_t m = (filesn_t)n, found = 0;
-			while (--m >= 0) {
+			size_t m = n, found = 0;
+			for (; m-- > 0;) {
 				if (*file_info[j].name == *tmp[m]
 				&& strcmp(file_info[j].name, tmp[m]) == 0)
 					found = 1;
@@ -2653,14 +2611,13 @@ check_chained_cmds(char *str)
 		return 1;
 	}
 
-	size_t i = 0;
 	const size_t str_len = strlen(str);
 	size_t len = 0, internal_ok = 0;
 	char *buf = (char *)NULL;
 
 	/* Get each word (cmd) in STR */
 	buf = xnmalloc(str_len + 1, sizeof(char));
-	for (i = 0; i < str_len; i++) {
+	for (size_t i = 0; i < str_len; i++) {
 		while (str[i] && str[i] != ' ' && str[i] != ';' && str[i] != '&') {
 			buf[len] = str[i];
 			len++;
@@ -2712,7 +2669,6 @@ parse_input_str(char *str)
 	if (!str)
 		return (char **)NULL;
 
-	size_t i = 0;
 	int fusedcmd_ok = 0;
 
 	flags &= ~FIRST_WORD_IS_ELN;
@@ -2744,7 +2700,7 @@ parse_input_str(char *str)
 		send_shell = 1;
 
 	if (send_shell == 0) {
-		for (i = 0; str[i]; i++) {
+		for (size_t i = 0; str[i]; i++) {
 
 				/* ##################################
 				 * #   0.2) CONDITIONAL EXECUTION   #
@@ -2754,7 +2710,7 @@ parse_input_str(char *str)
 			if (chaining == 0 && str[i] == ';' && i > 0 && str[i - 1] != '\\')
 				chaining = 1;
 
-			/* Check for conditional execution (cmd1 && cmd 2). */
+			/* Check for conditional execution (cmd1 && cmd2). */
 			if (cond_cmd == 0 && str[i] == '&' && i > 0 && str[i - 1] != '\\'
 			&& str[i + 1] == '&')
 				cond_cmd = 1;
@@ -2847,7 +2803,7 @@ parse_input_str(char *str)
 	 * will be expanded into the corresponding filenames by eln_expand() below. */
 	expand_ranges(&substr);
 
-	for (i = 0; i <= args_n; i++) {
+	for (size_t i = 0; i <= args_n; i++) {
 		if (!substr[i] || (is_quoted_word(i)
 		&& (virtual_dir == 0 || is_file_in_cwd(substr[i]) == 0)))
 			continue;
@@ -2922,9 +2878,10 @@ parse_input_str(char *str)
 		if ((*substr[i] == '.' && (!substr[i][1] || (substr[i][1] == '.'
 		&& (!substr[i][2] || substr[i][2] == '/'))))
 		|| strstr(substr[i], "/..")) {
-			char *tmp = (is_int_cmd == 1
-			&& (*substr[0] != 'l' || substr[0][1])) /* Exclude 'l' command. */
-				? normalize_path(substr[i], strlen(substr[i])) : NULL;
+			char *tmp = (i == 0 /* autocd/auto-open (no command name) */
+				/* Exclude 'l' command. */
+				|| (is_int_cmd == 1 && (*substr[0] != 'l' || substr[0][1])))
+					? normalize_path(substr[i], strlen(substr[i])) : NULL;
 			if (tmp) {
 				free(substr[i]);
 				substr[i] = tmp;
@@ -3050,7 +3007,7 @@ parse_input_str(char *str)
 	size_t word_n = 0;
 #endif /* HAVE_WORDEXP */
 
-	for (i = 0; substr[i]; i++) {
+	for (size_t i = 0; substr[i]; i++) {
 		if ((is_action == 1 && i == 0) || is_quoted_word(i))
 			continue;
 		/* Do not perform any of the expansions below for selected
@@ -3079,8 +3036,7 @@ parse_input_str(char *str)
 		const int is_escaped = strchr(substr[i], '\\') ? 1 : 0;
 #endif /* HAVE_WORDEXP */
 
-		size_t j = 0;
-		for (j = 0; substr[i][j]; j++) {
+		for (size_t j = 0; substr[i][j]; j++) {
 			/* Brace and wildcard expansion is made by glob(3). */
 			if (IS_GLOB(substr[i][j], substr[i][j + 1])) {
 				/* Strings containing these characters are taken as wildacard
@@ -3286,12 +3242,11 @@ get_substr(char *str, const char ifs, const int fproc)
 	}
 
 	char **dstr = (char **)NULL;
-	size_t i, j;
 	size_t n = 0;
 
-	for (i = 0; i < substr_n; i++) {
+	for (size_t i = 0; i < substr_n; i++) {
 		int dup = 0;
-		for (j = (i + 1); j < substr_n; j++) {
+		for (size_t j = (i + 1); j < substr_n; j++) {
 			if (*substr[i] == *substr[j] && strcmp(substr[i], substr[j]) == 0) {
 				dup = 1;
 				break;
