@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* suggestions.c -- functions to manage the suggestions system */
@@ -37,6 +22,7 @@
 
 #if defined(__OpenBSD__)
 typedef char *rl_cpvfunc_t;
+typedef void rl_macro_print_func_t (const char *, const char *, int, const char *);
 # include <ereadline/readline/readline.h>
 #else
 # include <readline/readline.h>
@@ -99,7 +85,7 @@ change_word_color(const char *_last_word, const int offset, const char *color)
 #endif // !_NO_HIGHLIGHT */
 
 /* Return a brief description for the command S, whose length is L. */
-static char *
+static const char *
 check_int_cmd_desc(const char *s, const size_t l)
 {
 	if (!s || !*s)
@@ -1046,8 +1032,8 @@ check_history(const char *str, const size_t len)
 	if (!history || !str || !*str || len == 0)
 		return NO_MATCH;
 
-	int i = (int)current_hist_n;
-	while (--i >= 0) {
+	size_t i = current_hist_n;
+	for (; i-- > 0;) {
 		if (!history[i].cmd || TOUPPER(*str) != TOUPPER(*history[i].cmd))
 			continue;
 
@@ -1203,8 +1189,8 @@ check_jumpdb(const char *str, const size_t len, const int print)
 {
 	char *color = (conf.suggest_filetype_color == 1) ? di_c : sf_c;
 
-	int i = (int)jump_n;
-	while (--i >= 0) {
+	size_t i = jump_n;
+	for (; i-- > 0;) {
 		if (!jump_db[i].path || TOUPPER(*str) != TOUPPER(*jump_db[i].path)
 		|| jump_db[i].rank == JUMP_ENTRY_PURGED)
 			continue;
@@ -1301,8 +1287,8 @@ check_aliases(const char *str, const size_t len, const int print)
 
 	char *color = sc_c;
 
-	int i = (int)aliases_n;
-	while (--i >= 0) {
+	size_t i = aliases_n;
+	for (; i-- > 0;) {
 		if (!aliases[i].name)
 			continue;
 		char *p = aliases[i].name;
@@ -1573,7 +1559,7 @@ check_sort_methods(const char *str, const size_t len)
 static int
 check_prompts(char *word, const size_t len)
 {
-	int i = (int)prompts_n;
+	size_t i = prompts_n;
 
 	char *q = (char *)NULL, *w = word;
 	size_t l = len;
@@ -1584,7 +1570,7 @@ check_prompts(char *word, const size_t len)
 		l = w == q ? strlen(w) : len;
 	}
 
-	while (--i >= 0) {
+	for (; i-- > 0;) {
 		if (TOUPPER(*w) == TOUPPER(*prompts[i].name)
 		&& (conf.case_sens_list ? strncmp(prompts[i].name, w, l)
 		: strncasecmp(prompts[i].name, w, l)) == 0) {
@@ -1650,8 +1636,8 @@ check_workspaces(char *word, size_t wlen, const int type)
 		l = w == q ? strlen(w) : wlen;
 	}
 
-	int i = MAX_WS;
-	while (--i >= 0) {
+	size_t i = MAX_WS;
+	for (; i-- > 0;) {
 		if (!workspaces[i].name)
 			continue;
 
@@ -2053,7 +2039,7 @@ rl_suggestions(const unsigned char c)
 		goto SUCCESS;
 
 	/* 3.a) Internal command description */
-	char *cdesc = (char *)NULL;
+	const char *cdesc = (char *)NULL;
 	if (conf.cmd_desc_sug == 1 && c != ' ' && words_num == 1
 	&& (!rl_line_buffer || (rl_end > 0 && rl_line_buffer[rl_end - 1] != ' '))
 	&& (cdesc = check_int_cmd_desc(word, wlen)) != NULL) {
@@ -2473,7 +2459,7 @@ CHECK_FIRST_WORD:
 
 	word = first_word ? first_word : last_word;
 
-	/* Skip 'b:' (bookmarks), 's:' (sel files) 't:' (tags) and 'w:'
+	/* Skip 'b:' (bookmarks), 's:' (sel files), 't:' (tags), and 'w:'
 	 * (workspaces) constructs. */
 	if ((*word == 'b' || *word == 's' || *word == 't' || *word == 'w')
 	&& word[1] == ':')
