@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* tabcomp.c -- functions for tab completion */
@@ -39,6 +24,7 @@
 
 #ifdef __OpenBSD__
 typedef char *rl_cpvfunc_t;
+typedef void rl_macro_print_func_t (const char *, const char *, int, const char *);
 # include <ereadline/readline/readline.h>
 #else
 # include <readline/readline.h>
@@ -277,6 +263,9 @@ fzftab_color(char *filename, const struct stat *attr)
 		return get_dir_color(filename, attr, -1);
 
 	case S_IFREG: {
+		if (conf.light_mode == 1)
+			return fi_c;
+
 		if (*nf_c
 		&& check_file_access(attr->st_mode, attr->st_uid, attr->st_gid) == 0)
 			return nf_c;
@@ -308,7 +297,8 @@ fzftab_color(char *filename, const struct stat *attr)
 	case S_IFIFO: return pi_c;
 	case S_IFBLK: return bd_c;
 	case S_IFCHR: return cd_c;
-	case S_IFLNK: return stat(filename, &a) == -1 ? or_c : ln_c;
+	case S_IFLNK: return conf.light_mode == 1 ? ln_c
+		: (stat(filename, &a) == -1 ? or_c : ln_c);
 	default: return uf_c;
 	}
 }
@@ -725,11 +715,13 @@ get_preview_win_width(const int offset)
 		 * double, or vertical): this takes 4 extra columns. */
 		: (fzf_border_type == 1 ? 2 : 4));
 	const int total_win_width = term_cols - offset;
+	const size_t s_total_win_width = total_win_width < 0 ? 0
+		: (size_t)total_win_width;
 
-	if (l < (size_t)total_win_width)
-		w = (size_t)total_win_width - l;
+	if (l < s_total_win_width)
+		w = s_total_win_width - l;
 
-	if (w > (size_t)total_win_width / 2)
+	if (w > s_total_win_width / 2)
 		return w;
 
 	return (size_t)-1;
@@ -1263,9 +1255,8 @@ static size_t
 count_quote_chars(const char *str, const size_t len)
 {
 	size_t n = 0;
-	int i = (int)len;
 
-	while (--i >= 0) {
+	for (size_t i = len; i-- > 0;) {
 		if (is_quote_char(str[i]))
 			n++;
 	}
@@ -1721,7 +1712,7 @@ do_completion(char *buf, const size_t prefix_len, const int multi)
 {
 	/* Some further buffer clean up: remove new line char and ending spaces. */
 	const size_t blen = strlen(buf);
-	int j = (int)blen;
+	int j = blen > INT_MAX ? INT_MAX : (int)blen;
 
 	if (j > 0 && buf[j - 1] == '\n') {
 		j--;
@@ -2232,7 +2223,7 @@ AFTER_USUAL_COMPLETION:
 				start += 2;
 			else if (c == TCMP_FILE_TEMPLATES) {
 				char *p = strrchr(text, '@');
-				if (p && p[1])
+				if (p)
 					start = rl_point - (int)strlen(p + 1);
 			}
 
@@ -2517,7 +2508,7 @@ DISPLAY_MATCHES:
 
 			char *norm_dir = (char *)NULL;
 			/* MATCHES[0] SHOULD BE DIR!! */
-			if (strstr(matches[0], "/..")) {
+			if (strstr(matches[0], "..")) {
 				norm_dir = normalize_path(matches[0], strlen(matches[0]));
 				if (norm_dir) {
 					size_t norm_dir_len = strlen(norm_dir) + 2;
