@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* tags.c -- functions to handle the file tagging system */
@@ -191,9 +176,9 @@ list_files_in_tag(char *name)
 static size_t
 get_longest_tag(void)
 {
-	size_t i, longest_tag = 0;
+	size_t longest_tag = 0;
 
-	for (i = 0; i < tags_n; i++) {
+	for (size_t i = 0; i < tags_n; i++) {
 		const size_t l = strlen(tags[i]);
 		if (l > longest_tag)
 			longest_tag = l;
@@ -210,8 +195,7 @@ list_tags_having_file(const dev_t dev, const ino_t ino)
 	if (!tags_dir || !tags)
 		return;
 
-	size_t i;
-	for (i = 0; tags[i]; i++) {
+	for (size_t i = 0; tags[i]; i++) {
 		char tmp[PATH_MAX + 1];
 		snprintf(tmp, sizeof(tmp), "%s/%s", tags_dir, tags[i]);
 
@@ -254,8 +238,7 @@ is_tag(char *name)
 		}
 	}
 
-	int i = (int)tags_n;
-	while (--i >= 0) {
+	for (size_t i = tags_n; i-- > 0;) {
 		if (*name == *tags[i] && strcmp(name, tags[i]) == 0)
 			return 1;
 	}
@@ -272,10 +255,9 @@ list_tags_full(void)
 		return FUNC_SUCCESS;
 	}
 
-	size_t i;
 	int exit_status = FUNC_SUCCESS;
 
-	for (i = 0; tags[i]; i++) {
+	for (size_t i = 0; tags[i]; i++) {
 		printf(_("Files tagged as %s%s%s:\n"), conf.colorize == 1
 			? BOLD : "'", tags[i], conf.colorize == 1 ? NC : "'");
 		if (list_files_in_tag(tags[i]) != FUNC_SUCCESS)
@@ -363,10 +345,9 @@ create_tags(char **args)
 	if (!args || !args[1] || !args[2])
 		return print_usage(FUNC_FAILURE);
 
-	size_t i;
 	int exit_status = FUNC_SUCCESS;
 
-	for (i = 2; args[i]; i++) {
+	for (size_t i = 2; args[i]; i++) {
 		char dir[PATH_MAX + 1];
 		char *p = strchr(args[i], '\\');
 		if (p) {
@@ -408,8 +389,8 @@ remove_tags(char **args)
 		return print_no_tags();
 
 	int exit_status = FUNC_SUCCESS;
-	size_t i;
-	for (i = 2; args[i]; i++) {
+
+	for (size_t i = 2; args[i]; i++) {
 		char *p = strchr(args[i], '\\');
 		if (p) {
 			char *deq = unescape_str(args[i], 0);
@@ -500,12 +481,12 @@ tag_file(char *name, char *tag)
 static int *
 get_tags(char **args)
 {
-	int n, i, c = 0;
+	int n, c = 0;
 
 	for (n = 0; args[n]; n++);
 	int *t = xnmalloc((size_t)n + 1, sizeof(int));
 
-	for (i = 0; i < n; i++) {
+	for (int i = 0; i < n; i++) {
 		if (*args[i] == ':' && *(args[i] + 1)) {
 			t[c] = i;
 			c++;
@@ -572,8 +553,8 @@ untag(char **args, const size_t n, size_t *t)
 		return FUNC_FAILURE;
 
 	int exit_status = FUNC_SUCCESS;
-	size_t i;
-	for (i = 2; args[i]; i++) {
+
+	for (size_t i = 2; args[i]; i++) {
 		if (i == n || (*args[i] == ':' && *(args[1] + 1)))
 			continue;
 
@@ -623,9 +604,9 @@ static int
 untag_files(char **args)
 {
 	int exit_status = FUNC_SUCCESS;
-	size_t i, n = 0;
+	size_t n = 0;
 
-	for (i = 1; args[i]; i++) {
+	for (size_t i = 1; args[i]; i++) {
 		if (*args[i] == ':' && *(args[i] + 1)
 		&& untag(args, i, &n) == FUNC_FAILURE)
 			exit_status = FUNC_FAILURE;
@@ -674,7 +655,7 @@ rename_tag(char **args)
 static int
 recursive_mv_tags(const char *src, const char *dst)
 {
-	int i, n, exit_status = FUNC_SUCCESS, ret;
+	int n, exit_status = FUNC_SUCCESS, ret;
 	char src_dir[PATH_MAX + 1];
 	char dst_dir[PATH_MAX + 1];
 	struct dirent **a = (struct dirent **)NULL;
@@ -689,7 +670,7 @@ recursive_mv_tags(const char *src, const char *dst)
 
 	snprintf(dst_dir, sizeof(dst_dir), "%s/%s", tags_dir, dst);
 
-	for (i = 0; i < n; i++) {
+	for (int i = 0; i < n; i++) {
 		if (SELFORPARENT(a[i]->d_name)) {
 			free(a[i]);
 			continue;
@@ -793,8 +774,7 @@ end_tag_function(const int exit_status, char **a, const int free_args)
 	if (free_args == 0)
 		return exit_status;
 
-	size_t i;
-	for (i = 0; a[i]; i++)
+	for (size_t i = 0; a[i]; i++)
 		free(a[i]);
 	free(a);
 
