@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* trash.c -- functions to manage the trash system */
@@ -54,7 +39,7 @@ count_trashed_files(void)
 {
 	size_t n = 0;
 	if (trash_ok == 1 && trash_files_dir != NULL) {
-		filesn_t ret = count_dir(trash_files_dir, NO_CPOP);
+		const filesn_t ret = count_dir(trash_files_dir, NO_CPOP);
 		n = ret <= 2 ? 0 : (size_t)ret - 2;
 	}
 
@@ -233,7 +218,7 @@ gen_dest_file(const char *file, const char *suffix, char **file_suffix)
 	char *filename = strrchr(file, '/');
 	if (!filename || !*(++filename)) {
 		xerror(_("trash: '%s': Error getting file base name\n"), file);
-		return (char *)NULL;
+		return NULL;
 	}
 
 	/* If the length of the trashed filename (orig_filename.suffix) is
@@ -250,7 +235,7 @@ gen_dest_file(const char *file, const char *suffix, char **file_suffix)
 		/* If SIZE is a positive value, that is, the trashed filename
 		 * exceeds NAME_MAX by SIZE bytes, reduce the original filename
 		 * SIZE bytes. Terminate the original filename (FILENAME) with
-		 * a tilde (~), to let the user know it was trimmed. */
+		 * a tilde (~), to let the user know it was truncated. */
 		filename[filename_len - (size_t)size - 1] = '~';
 		filename[filename_len - (size_t)size] = '\0';
 	}
@@ -268,11 +253,20 @@ gen_dest_file(const char *file, const char *suffix, char **file_suffix)
 	/* If the destination file exists (there's already a trashed file with
 	 * this name), append an integer until it is made unique. */
 	struct stat a;
-	int inc = 1;
-	while (lstat(dest, &a) == 0 && inc > 0) {
-		snprintf(*file_suffix, slen, "%s.%s-%d", filename, suffix, inc);
-		snprintf(dest, dlen, "%s/%s", trash_files_dir, *file_suffix);
+	size_t inc = 0;
+	while (lstat(dest, &a) == 0) {
 		inc++;
+		if (inc > MAX_FILE_CREATION_TRIES) {
+			xerror(_("trash: Cannot create trashinfo file for '%s': max "
+				"attempts (%d) reached\n"), filename, MAX_FILE_CREATION_TRIES);
+			free(dest);
+			free(*file_suffix);
+			*file_suffix = NULL;
+			return NULL;
+		}
+
+		snprintf(*file_suffix, slen, "%s.%s-%zu", filename, suffix, inc);
+		snprintf(dest, dlen, "%s/%s", trash_files_dir, *file_suffix);
 	}
 
 	return dest;
@@ -401,8 +395,7 @@ print_trashfiles(struct dirent ***ent, const int files_n)
 	cur_comp_type = TCMP_UNTRASH;
 
 	const uint8_t tpad = DIGINUM(files_n);
-	size_t i;
-	for (i = 0; i < (size_t)files_n; i++) {
+	for (size_t i = 0; i < (size_t)files_n; i++) {
 		printf("%s%*zu%s ", el_c, tpad, i + 1, df_c);
 		colors_list((*ent)[i]->d_name, NO_ELN, NO_PAD, PRINT_NEWLINE);
 	}
@@ -468,7 +461,6 @@ remove_from_trash_all(struct dirent ***tfiles, const int tfiles_n,
 	int *status)
 {
 	int n = 0;
-	size_t i;
 
 	if (tfiles_n > 0 && confirm_removal((size_t)tfiles_n) == 0) {
 		if (conf.autols == 1)
@@ -476,7 +468,7 @@ remove_from_trash_all(struct dirent ***tfiles, const int tfiles_n,
 		return (-1);
 	}
 
-	for (i = 0; i < (size_t)tfiles_n; i++) {
+	for (size_t i = 0; i < (size_t)tfiles_n; i++) {
 		int ret = remove_file_from_trash((*tfiles)[i]->d_name);
 		if (ret != FUNC_SUCCESS)
 			*status = FUNC_FAILURE;
@@ -580,7 +572,7 @@ remove_from_trash(char **args)
 		return FUNC_SUCCESS;
 	}
 
-	/* At this point we now all input fields are valid ELNs. */
+	/* At this point we know all input fields are valid ELNs. */
 	size_t removed = 0;
 	for (i = 0; input[i]; i++) {
 		const int num = atoi(input[i]);
@@ -771,11 +763,10 @@ untrash_file(char *file)
 static int
 untrash_all(struct dirent ***tfiles, const int tfiles_n, const int free_files)
 {
-	size_t i;
 	size_t untrashed = 0;
 	int status = FUNC_SUCCESS;
 
-	for (i = 0; i < (size_t)tfiles_n; i++) {
+	for (size_t i = 0; i < (size_t)tfiles_n; i++) {
 		if (untrash_file((*tfiles)[i]->d_name) != 0)
 			status = FUNC_FAILURE;
 		else
@@ -804,10 +795,9 @@ static int
 untrash_files(char **args)
 {
 	int status = FUNC_SUCCESS;
-	size_t i;
 	size_t untrashed = 0;
 
-	for (i = 0; args[i]; i++) {
+	for (size_t i = 0; args[i]; i++) {
 		char *d = (char *)NULL;
 		if (strchr(args[i], '\\'))
 			d = unescape_str(args[i], 0);
@@ -883,12 +873,12 @@ untrash_function(char **args)
 		}
 
 		if (strcmp(input[i], "*") == 0) {
-			int ret = untrash_all(&trash_files, files_n, 0);
+			const int ret = untrash_all(&trash_files, files_n, 0);
 			free_files_and_input(&input, &trash_files, files_n);
 			return ret;
 		}
 
-		int num = atoi(input[i]);
+		const int num = atoi(input[i]);
 		if (!is_number(input[i]) || num <= 0 || num > files_n) {
 			xerror(_("untrash: %s: Invalid ELN\n"), input[i]);
 			exit_status = FUNC_FAILURE;
@@ -905,7 +895,7 @@ untrash_function(char **args)
 
 	/* Untrash files */
 	for (i = 0; input[i]; i++) {
-		int num = atoi(input[i]);
+		const int num = atoi(input[i]);
 		if (untrash_file(trash_files[num - 1]->d_name) != FUNC_SUCCESS)
 			exit_status = FUNC_FAILURE;
 	}
@@ -916,6 +906,7 @@ untrash_function(char **args)
 	const size_t n = count_trashed_files();
 	if (n > 0) {
 		if (conf.clear_screen > 0) CLEAR;
+		trash_n = n;
 		untrash_function(args);
 	} else {
 		if (conf.autols == 1)
@@ -1052,8 +1043,7 @@ list_ok_trashed_files(char **args, const int *trashed, const size_t trashed_n)
 	if (print_removed_files == 0)
 		return;
 
-	size_t i;
-	for (i = 0; i < trashed_n; i++) {
+	for (size_t i = 0; i < trashed_n; i++) {
 		if (!args[trashed[i]] || !*args[trashed[i]])
 			continue;
 
