@@ -2,22 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * Copyright (C) 2016-2025, L. Abramovich <leo.clifm@outlook.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* workspaces.c -- handle workspaces ('ws' command) */
@@ -148,7 +133,7 @@ save_workspace_opts(const int n)
 	workspace_opts[n].filter.env = filter.env;
 
 	workspace_opts[n].color_scheme = cur_cscheme;
-	workspace_opts[n].files_counter = conf.files_counter;
+	workspace_opts[n].file_counter = conf.file_counter;
 	workspace_opts[n].light_mode = conf.light_mode;
 	workspace_opts[n].list_dirs_first = conf.list_dirs_first;
 	workspace_opts[n].long_view = conf.long_view;
@@ -208,7 +193,7 @@ set_workspace_opts(const int n)
 	conf.light_mode = workspace_opts[n].light_mode;
 	conf.list_dirs_first = workspace_opts[n].list_dirs_first;
 	conf.long_view = workspace_opts[n].long_view;
-	conf.files_counter = workspace_opts[n].files_counter;
+	conf.file_counter = workspace_opts[n].file_counter;
 	conf.max_files = workspace_opts[n].max_files;
 	conf.max_name_len = workspace_opts[n].max_name_len;
 	conf.only_dirs = workspace_opts[n].only_dirs;
